@@ -763,13 +763,9 @@ void wxVTKRenderWindowInteractor::OnKeyDown(wxKeyEvent &event)
     event.GetKeyCode(), 1);
 #endif
 	TransformarEvento(event);
-	if (propagar) {
-		event.Skip(true);
+	if (event.GetSkipped() || propagar) {
 		event.ResumePropagation(2);
 	}
-	else {
-		event.Skip(false);
-	}
 }
 //---------------------------------------------------------------------------
 void wxVTKRenderWindowInteractor::OnKeyUp(wxKeyEvent &event)
