@@ -26,10 +26,13 @@
 	#endif
 #else
 	#if defined(APIEXPORT)
-		#define EXTAPI __attribute__ ((visibility("default")))
+		#define EXTAPI __attribute__((visibility("default")))
 		#define EXTAPI_TEMPLATE
 	#else
 		#define EXTAPI
 		#define EXTAPI_TEMPLATE extern
 	#endif
 #endif
+
+#include <api/internacionalization/internacionalization.h>
+#include <api/iexception.h>
