@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: icontextoestudio.cpp 3995 2011-07-13 18:24:42Z tovar $
+ *  $Id: icontextoestudio.cpp 4076 2011-08-11 06:37:52Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -45,6 +45,7 @@
 #include <vtkInformationVector.h>
 #include <vtkUnsignedCharArray.h>
 #include <vtkPointData.h>
+#include <vtkCharArray.h>
 
 #define TAG_WIDGETS					    0xb
 #define UID_TAGS_PRIVADOS_COMUNES	 "100"
@@ -1198,6 +1199,49 @@ void GNC::GCS::IContextoEstudio::CrearMapaValoracionUnsignedChar(vtkSmartPointer
 	UnLock("CrearMapaValoracion");
 }
 
+void GNC::GCS::IContextoEstudio::CrearMapaValoracionChar(vtkSmartPointer<vtkImageData>& pMapa, GnkPtr<GIL::DICOM::TipoPrivateTags> pTagsPrivados, const unsigned char tag, const int indice, char valorInicial)
+{
+	Lock("CrearMapaValoracion");
+	//se crea la imagen
+	if (pMapa == NULL) {
+		pMapa = vtkSmartPointer<vtkImageData>::New();
+
+		double spacing[3] = {1.0f,1.0f,1.0f};
+		double origin[3] = {0.0f,0.0f,0.0f};
+		int dimensions[3] = {0.0f,0.0f,0.0f};
+		GetSpacing(indice,spacing[0],spacing[1],spacing[2]);
+		GetOrigin(indice,origin[0],origin[1],origin[2]);
+		GetDimensionsImagen(indice,dimensions[0],dimensions[1], dimensions[2]);
+
+		//se inicializan valores de dimensions, scalartype...
+		pMapa->SetDimensions(dimensions[0],dimensions[1],1);
+		pMapa->SetScalarTypeToChar();
+		pMapa->SetNumberOfScalarComponents(1);
+		pMapa->SetSpacing(spacing[0],spacing[1],spacing[2]);
+		pMapa->SetOrigin(origin[0],origin[1],origin[2]);
+
+		GIL::DICOM::TagPrivadoUndefined* pTagPrivado = pTagsPrivados->GetTagUndefined(tag);
+		if(pTagPrivado == NULL) {
+			const unsigned int size = dimensions[0] * dimensions[1];
+			pTagPrivado = pTagsPrivados->NewTagUndefined(tag,size);
+			//se hace un fill 0
+			const char* fin = size + (char*)pTagPrivado->GetValor();
+			for( char* pData = (char*)pTagPrivado->GetValor(); pData < fin; ++pData)
+			{
+				(*pData) = valorInicial;
+			}
+		}
+
+		vtkSmartPointer<vtkCharArray> dataImagen = vtkSmartPointer<vtkCharArray>::New();
+		dataImagen->SetNumberOfComponents(1);
+		unsigned int size = pMapa->GetDimensions()[0] * pMapa->GetDimensions()[1];
+		dataImagen->SetArray((char*)pTagPrivado->GetValor(),size,1);
+
+		pMapa->GetPointData()->SetScalars(dataImagen);
+	}
+	UnLock("CrearMapaValoracion");
+}
+
 GNC::GCS::IContextoEstudioReferido::IContextoEstudioReferido()
 {
 	GTRACE(">> IContextoEstudio::IContextoEstudioReferido() " << this);
