@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ientorno.h 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: ientorno.h 4327 2011-10-25 06:55:31Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -74,12 +74,14 @@ namespace GNC {
 			virtual const std::string& GetGinkgoVersion() = 0;
 			virtual void GetGinkgoVersionAsTuple(int* version, int* subversion, int* relase, int* build, std::string* codename) = 0;
 			virtual const std::string& GetGinkgoCopyRight() = 0;
+			virtual int ParseSVNBuild(const char* str) = 0;
 			virtual std::string GetGinkgoDicomDir(bool barraAlFinal = false) = 0;
 			virtual std::string GetPathAbsolutoFichero(const std::string& pathRelativo) = 0;
 			virtual std::string GetPathRelativoFichero(const std::string& pathAbsoluto) = 0;
 			virtual const std::string& GetPluginsPath() = 0;
 			virtual const std::string& GetGinkgoUserDir() = 0;
 			virtual const std::string& GetGinkgoTempDir() = 0;
+			virtual std::string CreateGinkgoTempDir() = 0;
 			virtual const std::string& GetGinkgoResourcesDir() = 0;
 			virtual std::string CrearDirectorioTemporal() = 0;
 			virtual std::string GetDicomLocalAET() = 0;
