@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: imgproxy.h 3894 2011-06-21 13:24:13Z seph $
+ *  $Id: imgproxy.h 4069 2011-08-09 09:42:05Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -117,6 +117,10 @@ public:
 typedef unsigned char UCHAR;
 #endif
 
+#ifndef CHAR
+typedef char CHAR;
+#endif
+
 typedef struct UCHAR3 {
 	unsigned char v1, v2, v3;
 
