@@ -596,16 +596,19 @@ namespace GIL {
 		std::string       Titulo;						
 		std::string       Ruta;
 		std::string       Descripcion;
+		bool					Monitorize;
+		bool					CleanBefore;
+		bool					CleanAfter;
 
 		Ubicacion()
 		{
 
 		}
 
-		Ubicacion(const std::string& titulo, const std::string& ruta, const std::string& descripcion)
+		Ubicacion(const std::string& titulo, const std::string& ruta, const std::string& descripcion, bool monitorize, bool cleanbefore, bool cleanafter)
 		{
 			this->Titulo = titulo;
-			Update(ruta, descripcion);
+			Update(ruta, descripcion, monitorize, cleanbefore, cleanafter);
 
 		}
 
@@ -619,10 +622,13 @@ namespace GIL {
 
 		}
 
-		void Update(const std::string& ruta, const std::string& desc)
+		void Update(const std::string& ruta, const std::string& desc, bool monitorize, bool cleanbefore, bool cleanafter)
 		{
 			this->Ruta        = ruta;
 			this->Descripcion = desc;
+			this->Monitorize = monitorize;
+			this->CleanBefore = cleanbefore;
+			this->CleanAfter = cleanafter;
 		}
 
 		Ubicacion& operator=(const Ubicacion& otro)
@@ -630,6 +636,9 @@ namespace GIL {
 			this->Titulo      = otro.Titulo;
 			this->Ruta        = otro.Ruta;
 			this->Descripcion = otro.Descripcion;
+			this->Monitorize	= otro.Monitorize;
+			this->CleanBefore	= otro.CleanBefore;
+			this->CleanAfter	= otro.CleanAfter;
 
 			return *this;
 		}
