@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: initwx.cpp 4188 2011-09-23 08:13:40Z carlos $
+ *  $Id: initwx.cpp 4406 2011-11-16 09:53:14Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -315,12 +315,13 @@ bool Ginkgo::OnInit()
 		GNC::GCS::ControladorInternacionalizacion::Instance()->AddCatalog("ginkgocadxcore");
 	}
 	//permisos del core
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx Restrictions"), "anonymous_history", _Std("Anonymous mode (history is cleaned)"), false, "", false);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx Restrictions"), "max_tabs", _Std("Max number of tabs opened"), false, "2", false);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx Restrictions"), "inactivity_time", _Std("Max seconds of Ginkgo CADx application inactivity"), false, "600", false);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online Manual"), "url_manual", _Std("URL of online manual"), true, "http://doc.ginkgo-cadx.com/", true);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online Support"), "url_support", _Std("URL of online support"), true, _Std("http://ginkgo-cadx.com/en/services/"), true);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Extensions Support"), "extensions_support", _Std("URL for new extensions"), true, _Std("http://ginkgo-cadx.com/en/extensions/"), true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "anonymous_history", _Std("Anonymous mode (history is cleaned)"), false, "", false);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "max_tabs", _Std("Max number of tabs opened"), false, "2", false);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "inactivity_time", _Std("Max seconds of Ginkgo CADx application inactivity"), false, "600", false);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.restrictions", _Std("Ginkgo CADx restrictions"), "export", _Std("Export images"), false, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online manual"), "url_manual", _Std("URL of online manual"), true, "http://doc.ginkgo-cadx.com/", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online support"), "url_support", _Std("URL of online support"), true, _Std("http://ginkgo-cadx.com/en/services/"), true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Extensions Support"), "extensions_support_1", _Std("URL for new extensions"), true, _Std("http://ginkgo-cadx.com/"), true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.update", _Std("Program Updates"), "check_updates", _Std("Warn about newest Ginkgo CADx updates"), false, "http://updates.ginkgo-cadx.com/version.xml", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.update", _Std("Program Updates"), "update_period", _Std("Update period (days)"), false, "2", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.seguridad",_Std("Security"), "setup_security", _Std("Setup Security"), false, "", false);
@@ -338,7 +339,7 @@ bool Ginkgo::OnInit()
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "study_size", _Std("Restrict study retrieval by maximum size (KB)"), false, "16384", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "force_lossless", _Std("Force lossless when upload"), false, "", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "quality", _Std("Set compression, 0 implies no compression (0..14)"), false, "1", true);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "codec", _Std("Recompression Codec (0=JPEG Baseline(default), 1=JPEG Progressive, 2=JPEG Lossless)"), false, "0", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "codec", _Std("Recompression codec (0=JPEG Baseline(default), 1=JPEG Progressive, 2=JPEG Lossless)"), false, "0", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "mantener", _Std("Don't change image codec (if possible)"), false, "", true);
 
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.hl7", _Std("HL7 Service"), "autostart", _Std("Automatically start HL7 Sender service"), false, "", true);
@@ -442,6 +443,7 @@ bool Ginkgo::OnInit()
 		GNC::ControladorHerramientas* cH = GNC::ControladorHerramientas::Instance();
 		try {
 			cH->RegistrarHerramienta(new GNC::HerramientaPuntero());
+			cH->RegistrarHerramienta(new GNC::HerramientaSlider());
 			cH->RegistrarHerramienta(new GNC::HerramientaWindowLevel());
 			cH->RegistrarHerramienta(new GNC::HerramientaRegla());
 			cH->RegistrarHerramienta(new GNC::HerramientaAngulo());
@@ -555,6 +557,7 @@ int Ginkgo::OnExit()
 	//desregistrar herramientas
 	GNC::GCS::IControladorHerramientas* cH = GNC::ControladorHerramientas::Instance();
 	GNC::GCS::IHerramientaPuntero*          hPuntero        = NULL;
+	GNC::GCS::IHerramientaSlider*           hSlider         = NULL;
 	GNC::GCS::IHerramientaWindowLevel*      hwl             = NULL;
 	GNC::GCS::IHerramientaRegla*            hregla          = NULL;
 	GNC::GCS::IHerramientaAngulo*           hAngulo         = NULL;
@@ -577,6 +580,11 @@ int Ginkgo::OnExit()
 			cH->DesRegistrarHerramienta(hPuntero);
 			delete hPuntero;
 		}
+		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaSlider>(GNC::GCS::IHerramientaSlider::ID);
+		if (hSlider != NULL) {
+			cH->DesRegistrarHerramienta(hSlider);
+			delete hSlider;
+		}
 		hwl = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaWindowLevel>(GNC::GCS::IHerramientaWindowLevel::ID);
 		if (hwl != NULL) {
 			cH->DesRegistrarHerramienta(hwl);
@@ -743,7 +751,7 @@ void Ginkgo::WriteHeaderLog(){
 	version << versionNumber;
 	version << ".";
 
-	versionNumber = GINKGO_BUILD;
+	versionNumber = GNC::Entorno::Instance()->ParseSVNBuild(GINKGO_BUILD);
 	version << versionNumber;
 	version << " ";
 
