@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: comandoavisarficheros.cpp 3527 2011-03-16 21:45:37Z carlos $
+*  $Id: comandoavisarficheros.cpp 3839 2011-05-11 08:47:59Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -21,9 +21,10 @@
 
 // Singleton de persistencia
 namespace GADAPI {
-	ComandoAvisarFicherosParams::ComandoAvisarFicherosParams(const TipoListaFicheros& listaFicheros)
+	ComandoAvisarFicherosParams::ComandoAvisarFicherosParams(const TipoListaFicheros& listaFicheros, bool openAfter)
 	{
 		m_listaFicheros = listaFicheros;
+		m_openAfter = openAfter;
 	}
 
 	ComandoAvisarFicheros::ComandoAvisarFicheros(ComandoAvisarFicherosParams* pParams):IComando(pParams)
@@ -43,7 +44,7 @@ namespace GADAPI {
 		for(ComandoAvisarFicherosParams::TipoListaFicheros::iterator it=m_pAvisarParams->m_listaFicheros.begin(); it!=m_pAvisarParams->m_listaFicheros.end(); it++) {
 			listaRutas.push_back((*it));
 		}
-		GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Eventos::EventoAddFicheroHistorial(listaRutas,false));
+		GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Eventos::EventoAddFicheroHistorial(listaRutas,m_pAvisarParams->m_openAfter));
 	}
 
 	void ComandoAvisarFicheros::LiberarRecursos()
