@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: comandogenerarthumbnails.cpp 3899 2011-06-24 13:19:30Z tovar $
+*  $Id: comandogenerarthumbnails.cpp 4398 2011-11-11 12:08:38Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -61,6 +61,7 @@
 #define UID_MPEG2MainProfileAtHighLevelTransferSyntax "1.2.840.10008.1.2.4.101"
 
 #define IDC_GENERAR_THUMBNAILS       81
+#define IDC_CARGA       91
 #define SIZE_THUMBNAILS 96
 
 namespace GADAPI {
@@ -95,11 +96,13 @@ namespace GADAPI {
 		m_pParams = m_pThumbParams;
 		SetId(IDC_GENERAR_THUMBNAILS);
 		EsperaA(IDC_GENERAR_THUMBNAILS);
+		EsperaA(IDC_CARGA);
 		GTRACE("<< ComandoGenerarThumbnails::ComandoGenerarThumbnails(): " << this);
 	}
 
 	void ComandoGenerarThumbnails::Execute()
 	{
+		NotificarProgreso(0.05f,_Std("Creating Thumbnail..."));
 		m_Error = true;
 		GTRACE("Arrancando comando generar thumbnails  " << m_pThumbParams->m_ruta)
 		//std::string tarea_Std("Generando thumbnails...");
@@ -107,7 +110,15 @@ namespace GADAPI {
 		m_pThumbParams->m_modeloDCM = GNC::GCS::ControladorHistorial::Instance()->GetModeloDCM(m_pThumbParams->m_ruta);
 		if(m_pThumbParams->m_modeloDCM.m_uidImagen == "") {
 			GTRACE("Saliendo generar thumbnails salida1  " << m_pThumbParams->m_ruta);
-
+			if (m_pThumbParams->m_modeloDCM.m_uidTransferSyntax == UID_MPEG2MainProfileAtMainLevelTransferSyntax || 
+				m_pThumbParams->m_modeloDCM.m_uidTransferSyntax == UID_MPEG2MainProfileAtHighLevelTransferSyntax) 
+			{
+				wxBitmap bmp = GinkgoResourcesManager::PanelHistorial::GetMoviePreview();
+				m_pThumbParams->m_wxImg = new wxImage();
+				(*m_pThumbParams->m_wxImg) = bmp.ConvertToImage();
+				m_Error = false;
+				return;
+			}
 			return;
 		}
 		//comprobar si el thumbnail ya estaba generado
@@ -166,7 +177,7 @@ namespace GADAPI {
 			outputSize[1] = size[1];
 
 			unsigned long imgsize = outputSize[0] * outputSize[1] * sizeof(unsigned char) * 3;
-			unsigned char* data = (unsigned char*) malloc (imgsize * sizeof(unsigned char));
+			unsigned char* data = (unsigned char*) malloc (imgsize);
 
 			try {
 
@@ -231,10 +242,12 @@ namespace GADAPI {
 					double dInputSize[3];
 					dInputSize[0] = (double)dimensions[0];
 					dInputSize[1] = (double)dimensions[1];
+					dInputSize[2] = 1.0;
 
-					double dOutputSize[2];
+					double dOutputSize[3];
 					dOutputSize[0] = (double)outputSize[0];
 					dOutputSize[1] = (double)outputSize[1];
+					dOutputSize[2] = 1.0;
 
 					double sX = dOutputSize[0] / dInputSize[0];
 					double sY = dOutputSize[1] / dInputSize[1];
