@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: comandoincluirhistorial.cpp 3995 2011-07-13 18:24:42Z tovar $
+*  $Id: comandoincluirhistorial.cpp 4398 2011-11-11 12:08:38Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -111,6 +111,7 @@ namespace GADAPI {
 			m_forzarSobreescribir = forzarSobreescribir;
 			m_borrarDespuesDeIncluir = false;
 			m_informar = true;
+			m_recursivo = true;
 		}
 
 		ComandoIncluirHistorialParams::~ComandoIncluirHistorialParams()
@@ -204,6 +205,15 @@ namespace GADAPI {
 
 		void  ComandoIncluirHistorial::LeerDirectorioRecursivo(wxString& dirPath, TListaListas& listaListasPaths, int profundidadMaxima, const int profundidadActual)
 		{
+			{
+				std::ostringstream ostr;
+				ostr << _Std("Exploring directory ") << dirPath.ToUTF8();
+				NotificarProgreso(0.0f, ostr.str());
+				if (EstaAbortado())
+				{
+					return;
+				}
+			}
 			TListaPaths listaCurrentPaths;
 			wxArrayString listaDirectoriosCurrent;
 			bool dicomEncontrado = false;
@@ -258,7 +268,9 @@ namespace GADAPI {
 		{
 			wxString message = wxT("");
 			message += _("Image acquisition finished.");
-			message += wxString::Format(_("\nThere have been included %d studies, %d series and %d images"),m_pIncluirParams->m_listaEstudios.size(), m_pIncluirParams->m_listaSeries.size(), m_pIncluirParams->m_listaImagenes.size());		
+			message += wxT(" ");
+			message += wxString::Format(_("There have been included %d studies, %d series and %d images."),m_pIncluirParams->m_listaEstudios.size(), m_pIncluirParams->m_listaSeries.size(), m_pIncluirParams->m_listaImagenes.size());		
+			message += wxT("\n");
 			if (m_pIncluirParams->m_ErrorList.size() > 0)
 				message += wxString::Format(_("\nThere are %d errors (see log for more detailed description)"), m_pIncluirParams->m_ErrorList.size());
 			if (m_pIncluirParams->m_listaPathsSobreescriben.size() > 0) 
