@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: comandomergediagnosticwithimage.cpp 3995 2011-07-13 18:24:42Z tovar $
+*  $Id: comandomergediagnosticwithimage.cpp 4404 2011-11-15 09:41:03Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -39,59 +39,35 @@
 
 namespace GADAPI {
 
+	ComandoMergeDiagnosticWithImageParams::ComandoMergeDiagnosticWithImageParams(const std::string& targetPath, const std::string& diagnosticStudyInstanceUID, const GIL::DICOM::TipoJerarquia& anonymizedTags, bool incluirTagsGinkgo)
+	{
+		m_tempPath = FROMPATH(targetPath);
+
+		m_uidDiagnosticStudy = diagnosticStudyInstanceUID;
+		
+		m_diagnosticMode = GNC::GCS::IContextoEstudio::TMF_UNDiagnostico;
+
+		FindModule();
+
+		m_includeGinkgoTags = incluirTagsGinkgo;
+		m_anonymizedTags = anonymizedTags;
+
+		m_commandType = TC_EXPORT;
+	}
+
 	ComandoMergeDiagnosticWithImageParams::ComandoMergeDiagnosticWithImageParams(const std::string& serverSeleccionado, const std::string& diagnosticStudyInstanceUID, GIL::DICOM::TipoTransferSyntaxEnvio transferSyntax)
 	{
 		m_ServerSeleccionado = serverSeleccionado;
 
-/*
-			std::list<std::string> pathsOriginal;
-			GNC::GCS::ControladorHistorial::Instance()->GetReferencedFiles(uidDiagnosticSeries, pathsOriginal);
-			for (std::list<std::string>::iterator it = pathsOriginal.begin(); it != pathsOriginal.end(); ++it)
-			{
-				T_File file;
-				file.m_path = (*it);
-				m_oldImages.push_back(file);
-			}*/
-		
 		m_uidDiagnosticStudy = diagnosticStudyInstanceUID;
 		
 		m_diagnosticMode = GNC::GCS::IContextoEstudio::TMF_UNDiagnostico;
 		
 		m_transferSyntax = transferSyntax;
+		
+		FindModule();
 
-		//search module and tags replace...
-		std::string uidImportater = GNC::GCS::ControladorHistorial::Instance()->GetUIDImporterFromDiagnosticStudy(m_uidDiagnosticStudy);
-		GNC::ControladorExtensiones::ListaModulos listaModulos = GNC::ControladorExtensiones::Instance()->Modulos();
-		bool salir = false;
-		for(GNC::ControladorExtensiones::IteradorListaModulos itModulos = listaModulos.begin(); itModulos!= listaModulos.end() && !salir; ++itModulos){
-			for (GNC::GCS::IControladorModulo::IteradorListaModos itModos = (*itModulos).second->GetListaModos().begin(); itModos != (*itModulos).second->GetListaModos().end(); ++itModos) {
-				if ((*itModos)->SupportsImportationUID(uidImportater)) {
-					//get all files of series included in this diagnostic
-					std::list<std::string> pathsOriginal;
-					GNC::GCS::ControladorHistorial::Instance()->GetReferencedFiles(m_uidDiagnosticStudy, pathsOriginal);
-					for (std::list<std::string>::iterator it = pathsOriginal.begin(); it != pathsOriginal.end(); ++it)
-					{
-						T_File file;
-						file.m_path = (*it);
-						m_oldImages.push_back(file);
-					}
-					
-					(*itModulos).second->GetTagsPrivadosReplace(m_mapTagsPrivadosReplace);
-					m_diagnosticMode = (*itModulos).second->GetDiagnosticMode();
-					salir = true;
-					break;
-				}
-			}
-		}
-		do {
-			m_tempPath = FROMPATH(GNC::Entorno::Instance()->GetGinkgoTempDir()) + wxFileName::GetPathSeparator(wxPATH_NATIVE) + wxT("_gnktmp_") + wxString::Format(wxT("%d"), rand());
-		} while(wxDir::Exists(m_tempPath));
-
-		#ifdef _WIN32
-				wxFileName::Mkdir(m_tempPath);
-		#else
-				wxFileName::Mkdir(m_tempPath.c_str(), 0777);
-		#endif
+		m_tempPath = FROMPATH(GNC::Entorno::Instance()->CrearDirectorioTemporal());
 
 		m_commandType = TC_UPLOAD;
 
@@ -127,6 +103,34 @@ namespace GADAPI {
 		m_commandType = TC_EXPORT;
 	}
 
+	void ComandoMergeDiagnosticWithImageParams::FindModule()
+	{
+		//search module and tags replace...
+		std::string uidImportater = GNC::GCS::ControladorHistorial::Instance()->GetUIDImporterFromDiagnosticStudy(m_uidDiagnosticStudy);
+		GNC::ControladorExtensiones::ListaModulos listaModulos = GNC::ControladorExtensiones::Instance()->Modulos();
+		bool salir = false;
+		for(GNC::ControladorExtensiones::IteradorListaModulos itModulos = listaModulos.begin(); itModulos!= listaModulos.end() && !salir; ++itModulos){
+			for (GNC::GCS::IControladorModulo::IteradorListaModos itModos = (*itModulos).second->GetListaModos().begin(); itModos != (*itModulos).second->GetListaModos().end(); ++itModos) {
+				if ((*itModos)->SupportsImportationUID(uidImportater)) {
+					//get all files of series included in this diagnostic
+					std::list<std::string> pathsOriginal;
+					GNC::GCS::ControladorHistorial::Instance()->GetReferencedFiles(m_uidDiagnosticStudy, pathsOriginal);
+					for (std::list<std::string>::iterator it = pathsOriginal.begin(); it != pathsOriginal.end(); ++it)
+					{
+						T_File file;
+						file.m_path = (*it);
+						m_oldImages.push_back(file);
+					}
+					
+					(*itModulos).second->GetTagsPrivadosReplace(m_mapTagsPrivadosReplace);
+					m_diagnosticMode = (*itModulos).second->GetDiagnosticMode();
+					salir = true;
+					break;
+				}
+			}
+		}
+	}
+
 	/////////
 	ComandoMergeDiagnosticWithImage::ComandoMergeDiagnosticWithImage(ComandoMergeDiagnosticWithImageParams* pParams):GNC::GCS::IComando(pParams, _Std("Merge diagnostic"))
 	{
@@ -401,11 +405,11 @@ namespace GADAPI {
 								//replaces...
 								for (std::map<wxString, wxString>::iterator itMapa = m_pMergeParams->m_mapSeriesUIDs.begin(); itMapa != m_pMergeParams->m_mapSeriesUIDs.end(); ++itMapa)
 								{
-									wxTmp.Replace((*itMapa).first, (*itMapa).second);
+									wxTmp.Replace(wxT("\"") + (*itMapa).first + wxT("\""), wxT("\"") + (*itMapa).second + wxT("\""));
 								}
 								for (std::map<wxString, wxString>::iterator itMapa = m_pMergeParams->m_mapSopUIDs.begin(); itMapa != m_pMergeParams->m_mapSopUIDs.end(); ++itMapa)
 								{
-									wxTmp.Replace((*itMapa).first, (*itMapa).second);
+									wxTmp.Replace(wxT("\"") + (*itMapa).first + wxT("\""), wxT("\"") + (*itMapa).second + wxT("\""));
 								}
 								//writes
 								{
