@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: comandopacs.cpp 4150 2011-09-14 08:55:21Z tovar $
+*  $Id: comandopacs.cpp 4338 2011-10-27 08:01:08Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -188,7 +188,7 @@ namespace GADAPI
 				if(rutas.size()==0){
 					LOG_WARN("C-MOVE/C-GET", _Std("No results obtained. Maybe you have a wrong PACS server configuration"));
 					if (m_pPACSParams->m_informar) {
-						GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Eventos::EventoMensajes(NULL, _Std("No results obtained"), GNC::GCS::Eventos::EventoMensajes::PopUpMessage,false, GNC::GCS::Eventos::EventoMensajes::Error));
+						GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Eventos::EventoMensajes(NULL, _Std("No results obtained in PACS retrieve.\nMaybe study doesn't exist or you have a wrong PACS server configuration."), GNC::GCS::Eventos::EventoMensajes::PopUpMessage,false, GNC::GCS::Eventos::EventoMensajes::Error));
 					}
 					return;
 				}
