@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: commandsynchronizewithgui.cpp 3655 2011-04-06 12:26:00Z tovar $
+*  $Id: commandsynchronizewithgui.cpp 4078 2011-08-16 10:19:52Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -21,10 +21,19 @@
 
 // Singleton de persistencia
 namespace GADAPI {
-	CommandSynchronizeWithGUI::CommandSynchronizeWithGUI(ISynchronizedWithGUI* pParams):IComando(NULL)
+	CommandSynchronizeWithGUI::CommandSynchronizeWithGUI(ISynchronizedWithGUI* pParams, ISynchronizedData* pData, bool clearData):IComando(NULL)
 	{
 		SetId(IDC_COMANDO_SYNCHRONIZE_WITH_GUI);
 		m_pListener = pParams;
+		m_pData = pData;
+		m_clearData = clearData;
+	}
+	
+	CommandSynchronizeWithGUI::~CommandSynchronizeWithGUI()
+	{
+		if (m_clearData && m_pData != NULL) {
+			delete m_pData;
+		}
 	}
 
 	void CommandSynchronizeWithGUI::Execute()
@@ -33,7 +42,7 @@ namespace GADAPI {
 
 	void CommandSynchronizeWithGUI::Update()
 	{
-		m_pListener->ExecuteSynchronized();
+		m_pListener->ExecuteSynchronized(m_pData);
 	}
 
 }
