@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: incomingdicomassociationcommand.cpp 3911 2011-07-04 07:58:00Z carlos $
+*  $Id: incomingdicomassociationcommand.cpp 4305 2011-10-18 11:28:18Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -56,10 +56,10 @@ struct StoreCallbackData
 *                   the status information which is captured in the status element (0000,0900). Note
 *                   that this function does specify any such information, the pointer will be set to NULL.
 */
-static void storeSCPCallback( void * callbackData, T_DIMSE_StoreProgress * progress, T_DIMSE_C_StoreRQ * req, char * imageFileName, DcmDataset ** imageDataSet, T_DIMSE_C_StoreRSP * rsp, DcmDataset ** statusDetail)
+static void storeSCPCallback( void * callbackData, T_DIMSE_StoreProgress * progress, T_DIMSE_C_StoreRQ * /*req*/, char * /*imageFileName*/, DcmDataset ** imageDataSet, T_DIMSE_C_StoreRSP * rsp, DcmDataset ** statusDetail)
 {
-	DIC_UI sopClass;
-	DIC_UI sopInstance;
+	//DIC_UI sopClass;
+	//DIC_UI sopInstance;
 
 	std::string ambitoLog = "storeSCPCallback";
 
