@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: iherramientaanotacionesesquina.h 3696 2011-04-14 08:40:28Z carlos $
+*  $Id: iherramientaanotacionesesquina.h 4090 2011-08-25 12:17:45Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -23,7 +23,7 @@ namespace GNC {
 			typedef GNC::GCS::IContratable<TContratoWidgets> TContratableWidgets;
 
 			static const IHerramienta::UID ID = HCore_AnotacionesEsquina;
-			IHerramientaAnotacionesEsquina() : IHerramienta(HCore_AnotacionesEsquina,TMenuImagen, "Activar/desactivar las anotaciones de las esquinas", SubFamiliaImagenDisposicion) {}
+			IHerramientaAnotacionesEsquina() : IHerramienta(HCore_AnotacionesEsquina,TMenuImagen, "Activar/desactivar las anotaciones de las esquinas") {}
 			virtual ~IHerramientaAnotacionesEsquina() {}
 
 			virtual void SetVistaActiva(GNC::GCS::IVista* pVista) = 0;
