@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorcomandos.cpp 3849 2011-05-16 13:26:20Z carlos $
+ *  $Id: controladorcomandos.cpp 4078 2011-08-16 10:19:52Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -563,6 +563,46 @@ void GNC::GCS::ControladorComandos::AbortarComandosDeOwnerAsincrono(void * owner
 	GTRACE("<< ControladorComandos::AbortarComandosDeOwner(owner) : CS");
 }
 
+void GNC::GCS::ControladorComandos::WaitToOwnerCommands(void* owner)
+{
+	GNC::GCS::WaitQueue wqueue;
+
+	{
+		GNC::GCS::ILocker locker(this, GLOC());
+		GTRACE(">> ControladorComandos::AbortarComandosDeOwner(owner) : CS");
+		// Recorremos la lista de threads_ids de la vista
+		MapaOwners::iterator it1 = m_MapaOwners.find(owner);
+		MapaComandos::iterator itcl;
+		if (it1 != m_MapaOwners.end()) {
+			for (ListaHilos::iterator it2 = (*it1).second.begin(); it2 != (*it1).second.end(); it2++) {
+				long threadId = (*it2);
+				// Buscamos el id en la lista de comandos lanzados
+				itcl = m_ComandosLanzados.find(threadId);
+				if (itcl != m_ComandosLanzados.end()) { // El comando esta lanzado
+					LanzadorComandos* pLanzador = (*itcl).second;
+					if (pLanzador != NULL) { //
+
+						wqueue.RegistrarEspera(pLanzador, GLOC());
+						pLanzador->Terminar();
+
+						std::cerr << "Registrando espera para tarea: threadId = " << (unsigned long) threadId << " ptr = " << pLanzador << std::endl;
+					} else {
+						std::cerr << "Detectada inconsistencia en el controlador de comandos: Comando lanzado desreferenciado. Flujo de comando perdido." << std::endl;
+					}
+				}
+			}
+		}
+		GTRACE("<< ControladorComandos::WaitToOwnerCommands(owner) : CS");
+	}
+
+	GTRACE("GNC::GCS::ControladorComandos::WaitToOwnerCommands( " << owner << ") : Esperando " << wqueue.Size(GLOC()) << " tareas");
+	while (wqueue.NotEmpty(GLOC())) {
+		if (!wqueue.Wait(500, GLOC())) {
+		}
+	}
+	GTRACE("GNC::GCS::ControladorComandos::WaitToOwnerCommands( " << owner << ") : Espera terminada");
+}
+
 void GNC::GCS::ControladorComandos::OnComandoLanzado(long threadId)
 {
 
