@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorenviohl7.h 3787 2011-04-29 06:38:01Z tovar $
+ *  $Id: controladorenviohl7.h 4099 2011-08-29 11:27:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,6 +13,7 @@
  */
 #pragma once
 #include <api/api.h>
+#include <api/icontroladoreventos.h>
 #include <api/icontroladorhl7.h>
 #include <wx/thread.h>
 
@@ -21,7 +22,7 @@ class wxCriticalSection;
 
 namespace GIL {
 	namespace HL7 {
-		class EXTAPI ControladorEnvioHl7:  protected wxThread
+		class EXTAPI ControladorEnvioHl7:  protected wxThread, public GNC::GCS::IObservador
 		{
 		public:
 			static void FreeInstance();
@@ -39,11 +40,8 @@ namespace GIL {
 
 			virtual void* Entry();
 
-			/* Envia el mensaje por MLLP */
-			void EnviarMensajeMLLP(const std::string& msg, const std::string& url, bool procesarACK=true, const std::string& msgControlId="") const;
-
-			bool ProcesarMensajes();
-			
+			virtual void ProcesarEvento(GNC::GCS::Eventos::IEvento *evt) ;
+			wxSemaphore		m_semaphore;
 			bool m_Abortado;
 		};
 	}
