@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorhl7.cpp 4034 2011-07-21 09:44:05Z tovar $
+ *  $Id: controladorhl7.cpp 4303 2011-10-18 10:31:44Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -104,6 +104,64 @@ void GIL::HL7::ControladorHL7::ParsearModeloIntegracion(GNC::GCS::IEntorno::List
 
 	if (m_mapParsers.find(parserKey) != m_mapParsers.end()) {
 		m_mapParsers.find(parserKey)->second->ParseIntegrationXML(modelos, raiz);
+
+		//"Metadatos" tags could overwrite other specified properties like patient name
+		for (GNC::GCS::IEntorno::ListaModelosIntegracion::iterator itModelos = modelos.begin(); itModelos != modelos.end(); ++itModelos) {
+			GIL::IModeloIntegracion::ListaTuplas& tuplas = (*itModelos)->Metadatos;					
+			for (GIL::IModeloIntegracion::ListaTuplas::iterator itMetadatos = tuplas.begin(); itMetadatos != tuplas.end(); itMetadatos++) {
+				GIL::IModeloTupla& tupla = *itMetadatos;
+				std::locale locale;
+				std::string& codigo = tupla.codigo;
+				//code must be upper
+				for (std::string::iterator p = codigo.begin(); p != codigo.end(); ++p) {
+					*p = std::use_facet<std::ctype<char> >(locale).toupper(*p);
+				}
+				
+				if (codigo == "DICOM") {
+					std::string& key = tupla.clave;
+					//key must be lower
+					for (std::string::iterator p = key.begin(); p != key.end(); ++p) {
+						*p = std::use_facet<std::ctype<char> >(locale).tolower(*p);
+					}
+
+					if (key == "0008|0080") {
+						//medical center
+						(*itModelos)->Medico.nombreCentro = tupla.valor;
+					}
+					else if (key == "0008|0090") {
+						//physician's name
+						wxStringTokenizer tknz(wxString::FromUTF8(tupla.valor.c_str()));
+						if (tknz.HasMoreTokens()) {
+							(*itModelos)->Medico.nombre = tknz.GetNextToken().ToUTF8();
+							if (tknz.HasMoreTokens()) {
+								(*itModelos)->Medico.apellido1 = tknz.GetNextToken().ToUTF8();
+								if (tknz.HasMoreTokens()) {
+									(*itModelos)->Medico.apellido2 = tknz.GetNextToken().ToUTF8();
+								}
+							}
+						}
+					}
+					else if (key == "0008|0050") {
+						//accesssion number
+						(*itModelos)->accessionNumber = key;
+					}
+					else if (key == "0010|0010") {
+						//patient's name
+						wxStringTokenizer tknz(wxString::FromUTF8(tupla.valor.c_str()));
+						if (tknz.HasMoreTokens()) {
+							(*itModelos)->Paciente.nombre = tknz.GetNextToken().ToUTF8();
+							if (tknz.HasMoreTokens()) {
+								(*itModelos)->Paciente.apellido1 = tknz.GetNextToken().ToUTF8();
+								if (tknz.HasMoreTokens()) {
+									(*itModelos)->Paciente.apellido2 = tknz.GetNextToken().ToUTF8();
+								}
+							}
+						}
+					}
+				}
+			}
+		}
+
 	} else {
 		std::ostringstream ostr;
 		ostr << _Std("XML Parser Not Found. Key=") << parserKey; 
