@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorvistas.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: controladorvistas.cpp 4044 2011-07-22 12:21:07Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -31,6 +31,8 @@
 
 #include <main/controllers/controladorcomandos.h>
 #include <main/controllers/controladorlog.h>
+#include <main/controllers/controladorpermisos.h>
+#include <main/gui/countdownmessage/countdownmessage.h>
 
 
 #include <iostream>
@@ -40,6 +42,57 @@
 #include <main/panelgrid.h>
 #include <api/icontextoestudio.h>
 
+//this timer is to controlate user inactivity
+namespace GNC {
+	namespace GCS {
+		class TimerInactivity: public wxTimer {
+		public:
+			TimerInactivity() 
+			{
+				GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions", "inactivity_time");
+				if (estado) {
+					m_maxInactivity = estado.ObtenerValor<long>() * 1000;
+					this->Start(m_maxInactivity, true);
+				} else {
+					m_maxInactivity = -1;
+				}
+			}
+
+			~TimerInactivity() 
+			{
+			}
+			
+			virtual void Notify()
+			{
+				if (m_maxInactivity > 0) {
+					GNC::GUI::CountdownMessage countdown(GNC::Entorno::Instance()->GetVentanaRaiz());
+					countdown.ShowModal();
+					if (countdown.Cancel()) {
+						this->Start(m_maxInactivity, true);
+						return;
+					}
+					GNC::Entorno::Instance()->GetVentanaPrincipal()->Close();
+				}
+			}
+
+			virtual void Reset() 
+			{
+				if (IsRunning()) {
+					Stop();
+				}
+				if (m_maxInactivity > 0) {
+					this->Start(m_maxInactivity, true);
+				}
+			}
+
+		protected:
+			long m_maxInactivity;	
+		};
+	}
+}
+//
+
+
 //region "Patron singleton"
 
 GNC::GCS::ControladorVistas* GNC::GCS::ControladorVistas::m_pInstance = 0;
@@ -51,10 +104,16 @@ GNC::GCS::ControladorVistas::ControladorVistas()
 	//se conecta el evento Ginkgo
 	GNC::GCS::Eventos::EventoModificacionFichero evtModificado;
 	GNC::Entorno::Instance()->GetControladorEventos()->Registrar(this, evtModificado);
+
+	m_pTimerInactivity = new TimerInactivity;
 }
 
 GNC::GCS::ControladorVistas::~ControladorVistas()
 {
+	if (m_pTimerInactivity != NULL) {
+		delete m_pTimerInactivity;
+		m_pTimerInactivity = NULL;
+	}
 	//DestruirTabs();
 }
 
@@ -107,6 +166,9 @@ void GNC::GCS::ControladorVistas::Thaw()
 }
 
 void GNC::GCS::ControladorVistas::SetTitulo(GNC::GCS::IVista* pVista, const std::string& tituloNuevo) {
+	//resets inactivity
+	ResetsInactivity();
+	//
 	wxWindow* pVentana = NULL;
 	int numConteo = 0;
 	bool cambia = true;
@@ -219,6 +281,10 @@ void GNC::GCS::ControladorVistas::SetTitulo(GNC::GCS::IVista* pVista, const std:
 
 std::string GNC::GCS::ControladorVistas::GetTitulo(GNC::GCS::IVista* pVista)
 {
+	//resets inactivity
+	ResetsInactivity();
+	//
+
 	wxWindow* pVentana = NULL;
 
 	pVentana = pVista->GetWindow();
@@ -267,8 +333,19 @@ void GNC::GCS::ControladorVistas::PropagarConfiguracionCambiada()
 	UnLock(GLOC());
 }
 
+void GNC::GCS::ControladorVistas::ResetsInactivity()
+{
+	//resets inactivity
+	m_pTimerInactivity->Reset();
+	//
+}
+
 void GNC::GCS::ControladorVistas::Registrar(GNC::GCS::IVista* pVista)
 {
+	//resets inactivity
+	ResetsInactivity();
+	//
+
 	Lock(GLOC());
 	if (pVista == NULL) {
 		LOG_WARN("Core/ControladorVistas", "No se puede registrar una vista nula");
@@ -293,6 +370,10 @@ void GNC::GCS::ControladorVistas::Registrar(GNC::GCS::IVista* pVista)
 
 void GNC::GCS::ControladorVistas::Destruir(GNC::GCS::IVista* pVista)
 {
+	//resets inactivity
+	ResetsInactivity();
+	//
+
 	Lock(GLOC());
 	GTRACE("ControladorVistas::DestruirVista(GNC::GCS::IVista* pVista = " << pVista << ")");
 
@@ -313,6 +394,10 @@ void GNC::GCS::ControladorVistas::Destruir(GNC::GCS::IVista* pVista)
 
 void GNC::GCS::ControladorVistas::Destruir(wxWindow* pVentana)
 {
+	//resets inactivity
+	ResetsInactivity();
+	//
+
 	Lock(GLOC());
 	GTRACE("ControladorVistas::DestruirVista(wxWindow* pVentana = " << pVentana << ")");
 
@@ -334,6 +419,10 @@ void GNC::GCS::ControladorVistas::Destruir(wxWindow* pVentana)
 //region "Gestion de carga y descarga de vistas"
 
 void GNC::GCS::ControladorVistas::SolicitarActivarVista(GNC::GCS::IVista* pVista) {
+	//resets inactivity
+	ResetsInactivity();
+	//
+
 	if (pVista == m_pVistaActiva) {
 		return;
 	}
@@ -372,6 +461,10 @@ void GNC::GCS::ControladorVistas::SolicitarActivarVista(GNC::GCS::IVista* pVista
 
 void GNC::GCS::ControladorVistas::PropagarVistaCreada(GNC::GCS::IVista* pVista)
 {
+	//resets inactivity
+	ResetsInactivity();
+	//
+
 	GNC::Entorno* pEntorno = GNC::Entorno::Instance();
 	Entorno::ListaObservadoresVistas::const_iterator it;
 	for (it = pEntorno->ObservadoresVistas.begin(); it != pEntorno->ObservadoresVistas.end(); it++) {
@@ -387,6 +480,9 @@ inline bool my_isnan(double x)
 
 void GNC::GCS::ControladorVistas::PropagarVistaDestruida(GNC::GCS::IVista* pVista)
 {
+	//resets inactivity
+	ResetsInactivity();
+	//
 
 	if (pVista == NULL) {
 		LOG_WARN("Core/ControladorVistas", "Error al propagar destruccion de vista. Vista nula. Inconsistencia interna");
@@ -558,6 +654,10 @@ void GNC::GCS::ControladorVistas::OcultarPanel(wxWindow* win)
 	vp->SuperThaw();
 }
 GNC::GCS::ControladorVistas::TipoListaVistas GNC::GCS::ControladorVistas::GetVistas(){
+	//resets inactivity
+	ResetsInactivity();
+	//
+
 	GNC::GCS::ControladorVistas::TipoListaVistas result;
 
 	for(MapaVentanas::iterator it = m_MapaVentanas.begin(); it!= m_MapaVentanas.end(); it++){
