@@ -1,6 +1,6 @@
 /*
 *
-*  $Id$
+*  $Id: dicomgetassociation.cpp 4424 2011-11-18 12:24:36Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,6 +16,7 @@
 #include <api/dicom/imodelodicom.h>
 #include <main/controllers/controladorpermisos.h>
 #include <api/controllers/ipacscontroller.h>
+#include <main/entorno.h>
 
 #include <api/icontextoestudio.h>
 
@@ -353,6 +354,7 @@ CONDITION GetAssociation::getSCU(DcmDataset *pdset) {
 	storeCallbackData.assoc = assoc;
 	//storeCallbackData.presId = presId;
 	storeCallbackData.pCaller = this;
+	storeCallbackData.lastTick = std::clock();
 
 	req.MessageID = msgId;
 	strcpy(req.AffectedSOPClassUID, sopClass);
@@ -411,7 +413,7 @@ void GetAssociation::subOpCallback(void *pCaller, T_ASC_Network *aNet, T_ASC_Ass
 	if (caller->GetNetwork() == NULL) {
 		return;
 	}
-
+	
 	wxString msg = wxString::Format(_("Downloading file %d"), ++caller->m_numeroImagenes);
 	caller->m_mensaje = std::string(msg.ToUTF8());
 	LOG_DEBUG(caller->ambitolog, caller->m_mensaje);
@@ -419,7 +421,7 @@ void GetAssociation::subOpCallback(void *pCaller, T_ASC_Network *aNet, T_ASC_Ass
 
 	if (*subAssoc == NULL) {
 		// negotiate association
-		LOG_DEBUG(caller->ambitolog, "Aceptando subAsociacin");
+		LOG_DEBUG(caller->ambitolog, "Aceptando subasociacion");
 		caller->acceptSubAssoc(aNet, subAssoc);
 	}
 	else {
@@ -477,10 +479,10 @@ CONDITION GetAssociation::subOpSCP(T_ASC_Association **subAssoc) {
 		return cond;
 	}
 	else if (cond == DUL_PEERABORTEDASSOCIATION) {
-		LOG_ERROR(ambitolog, "El PACS remoto abort la asociacin"  << cond.text());
+		LOG_ERROR(ambitolog, "El PACS remoto aborto la asociacion"  << cond.text());
 	}
 	else if (cond != EC_Normal) {
-		LOG_ERROR(ambitolog, "Ha ocurrido un error y se abortar la asociacin"  << cond.text());
+		LOG_ERROR(ambitolog, "Ha ocurrido un error y se abortara la asociacion"  << cond.text());
 		// some kind of error so abort the association
 		cond = ASC_abortAssociation(*subAssoc);
 	}
@@ -495,24 +497,37 @@ CONDITION GetAssociation::subOpSCP(T_ASC_Association **subAssoc) {
 CONDITION GetAssociation::storeSCP(T_ASC_Association *assoc, T_DIMSE_Message *msg, T_ASC_PresentationContextID presID) {
 	CONDITION cond;
 	T_DIMSE_C_StoreRQ* req;
-	DcmDataset *dset = new DcmDataset;
 
 	req = &msg->msg.CStoreRQ;
 
 	StoreCallbackInfo callbackData;
-	callbackData.dataset = dset;
 	callbackData.pCaller = this;
 	callbackData.assoc = assoc;
+	callbackData.lastTick = std::clock();
 
-	cond = DIMSE_storeProvider(assoc, presID, req, (char *) NULL, 1,
-		&dset, storeSCPCallback, (void*) & callbackData,
+	std::string fileName = GNC::Entorno::Instance()->CreateGinkgoTempFile();
+
+	cond = DIMSE_storeProvider(assoc, presID, req, fileName.c_str(), 1,
+		NULL, storeSCPCallback, (void*) & callbackData,
 		DIMSE_BLOCKING, 0);
 
-	delete dset;
+	if (cond.good()) {
+		//we are going to read received file dataset
+		DcmFileFormat ff;
+		ff.loadFile(fileName.c_str(), EXS_Unknown, EGL_noChange, DCM_TagInfoLength);
+		DcmDataset* imageDataSet = ff.getDataset();
+
+		if ((imageDataSet)) {
+			// do not duplicate the dataset, let the user do this
+			// if he wants to
+			OnFileReceived(fileName, imageDataSet);
+		}
+	}
+
 	return cond;
 }
 
-void GetAssociation::storeSCPCallback(void *callbackData, T_DIMSE_StoreProgress *progress, T_DIMSE_C_StoreRQ *req, char* /*imageFileName*/, DcmDataset **imageDataSet, T_DIMSE_C_StoreRSP *rsp, DcmDataset **statusDetail) {
+void GetAssociation::storeSCPCallback(void *callbackData, T_DIMSE_StoreProgress *progress, T_DIMSE_C_StoreRQ *req, char* imageFileName, DcmDataset ** /*imageDataSet*/, T_DIMSE_C_StoreRSP *rsp, DcmDataset **statusDetail) {
 	DIC_UI sopClass;
 	DIC_UI sopInstance;
 
@@ -560,26 +575,27 @@ void GetAssociation::storeSCPCallback(void *callbackData, T_DIMSE_StoreProgress
 				return;
 			}
 		}
+		cbdata->lastTick = std::clock();
 	}
-
-
-	if (progress->state == DIMSE_StoreProgressing) {
-		//si ha pasado medio segundo...
-		std::stringstream ostr;
-		ostr << caller->m_mensaje;
-		ostr.setf(std::ios::floatfield, std::ios::fixed );
-		ostr.precision(2);
-		ostr <<  " (" << caller->TasaTransferencia(progress->progressBytes) << " kb/s)";
-		std::string msg(ostr.str());
-		if(!caller->NotificarProgreso( partial + step * ((float)progress->progressBytes/(float)progress->totalBytes), msg) )
-		{
-			rsp->DimseStatus = STATUS_STORE_Refused_OutOfResources;
-			OFCondition cond = ASC_releaseAssociation(cbdata->assoc);
-			return;
+	else if (progress->state == DIMSE_StoreProgressing) {
+		std::clock_t curTick = std::clock();
+		if ( (curTick - cbdata->lastTick) > (CLOCKS_PER_SEC >> 1) ) {
+			cbdata->lastTick = curTick;
+			std::stringstream ostr;
+			ostr << caller->m_mensaje;
+			ostr.setf(std::ios::floatfield, std::ios::fixed );
+			ostr.precision(2);
+			ostr <<  " (" << caller->TasaTransferencia(progress->progressBytes) << " kb/s)";
+			std::string msg(ostr.str());
+			if(!caller->NotificarProgreso( partial + step * ((float)progress->progressBytes/(float)progress->totalBytes), msg) )
+			{
+				rsp->DimseStatus = STATUS_STORE_Refused_OutOfResources;
+				OFCondition cond = ASC_releaseAssociation(cbdata->assoc);
+				return;
+			}
 		}
 	}
-
-	if (progress->state == DIMSE_StoreEnd) {
+	else if (progress->state == DIMSE_StoreEnd) {
 		LOG_TRACE(caller->ambitolog, "storeSCPCallback(). DIMSE_StoreEnd");
 		caller->m_numeroImagenes++;
 		*statusDetail = NULL; /* no status detail */
@@ -588,19 +604,17 @@ void GetAssociation::storeSCPCallback(void *callbackData, T_DIMSE_StoreProgress
 		/* could save the image somewhere else, put it in database, etc */
 		rsp->DimseStatus = STATUS_Success;
 
-		if ((imageDataSet) && (*imageDataSet)) {
-			// do not duplicate the dataset, let the user do this
-			// if he wants to
-			caller->OnResponseReceived(cbdata->dataset);
-		}
-
+		//we are going to read received file dataset
+		DcmFileFormat ff;
+		ff.loadFile(imageFileName, EXS_Unknown, EGL_noChange, DCM_TagInfoLength);
+		DcmDataset* imageDataSet = ff.getDataset();
 		/* should really check the image to make sure it is consistent,
 		* that its sopClass and sopInstance correspond with those in
 		* the request.
 		*/
 		if (rsp->DimseStatus == STATUS_Success) {
 			/* which SOP class and SOP instance ? */
-			if (!DU_findSOPClassAndInstanceInDataSet(cbdata->dataset, sopClass, sopInstance)) {
+			if (!DU_findSOPClassAndInstanceInDataSet(imageDataSet, sopClass, sopInstance)) {
 				rsp->DimseStatus = STATUS_STORE_Error_DataSetDoesNotMatchSOPClass;
 				LOG_ERROR(caller->ambitolog, "No se pudo encontrar SOPClass o SOPInstanceUID en el dataset");
 			}
@@ -625,10 +639,7 @@ CONDITION GetAssociation::echoSCP(T_ASC_Association *assoc, T_DIMSE_Message *msg
 	return cond;
 }
 
-void GetAssociation::OnResponseReceived(DcmDataset* dset) {
-	if (m_pHandler != NULL) {
-		m_pHandler->Store(dset);
-	}
+void GetAssociation::OnFileReceived(const std::string& fileName, DcmDataset* dset) {
 	if (m_pModelo != NULL) {
 		OFString OFEstudioUId;
 		if (dset->findAndGetOFString(DCM_StudyInstanceUID, OFEstudioUId).good()) {
@@ -757,6 +768,9 @@ void GetAssociation::OnResponseReceived(DcmDataset* dset) {
 			}
 		}
 	}
+	if (m_pHandler != NULL) {
+		m_pHandler->Store(fileName, dset);
+	}
 }
 
 void GetAssociation::SetCallbackHandler(IStoreCallBack * handler) {
