@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: dicommanager.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: dicommanager.cpp 4313 2011-10-18 13:23:37Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,6 +15,7 @@
 //para la comprobacion de si esta correcto el fichero
 #include <wx/file.h>
 #include <wx/strconv.h>
+#include <wx/filename.h>
 
 #include <api/globals.h>
 #include "dicommanager.h"
@@ -23,6 +24,7 @@
 #include <stack>
 #include <cstdio>
 #include <api/icontextoestudio.h>
+#include <main/entorno.h>
 
 #ifdef verify
 #define MACRO_QUE_ESTORBA verify
@@ -49,15 +51,15 @@ namespace GIL
 
 		// Constructor
 		DICOMManager::DICOMManager() {
-			m_pDCMDataSet = NULL;
+			m_pDCMSource = NULL;
 			m_pConv = NULL;
 		}
 
 		// Destructor
 		DICOMManager::~DICOMManager() {
-			if (m_pDCMDataSet != NULL) {
-				delete m_pDCMDataSet;
-				m_pDCMDataSet = NULL;
+			if (m_pDCMSource != NULL) {
+				delete m_pDCMSource;
+				m_pDCMSource = NULL;
 			}
 			if (m_pConv != NULL) {
 				delete m_pConv;
@@ -70,16 +72,30 @@ namespace GIL
 		/*Almacena la jerarquia cargada en un fichero*/
 		bool DICOMManager::AlmacenarFichero(const std::string& inputFile, IInspectCallBack* , bool )
 		{
-			if (m_pDCMDataSet == NULL) {
+			if (m_pDCMSource == NULL) {
 				return false;
 			}
 			FindCharset();
-			DcmFileFormat dcmff(m_pDCMDataSet);
 			OFCondition cond;
-			cond = dcmff.saveFile(inputFile.c_str());
+
+			std::string tempDir = GNC::Entorno::Instance()->CreateGinkgoTempDir();
+			std::string tempFile;
+			{
+				std::ostringstream ostr;
+				ostr << tempDir;
+				ostr << wxFileName::GetPathSeparator();
+				ostr << "1.dcm";
+				tempFile = ostr.str();
+			}
+
+			cond = m_pDCMSource->saveFile(tempFile.c_str());
 			if (cond.bad()) {
 				std::cerr << "Error: " << cond.text() << std::endl;
+				wxRemoveFile(FROMPATH(tempFile));
 				return false;
+			} else {
+				wxRenameFile(FROMPATH(tempFile), FROMPATH(inputFile), true);
+				m_pDCMSource->loadFile(inputFile.c_str(), EXS_Unknown, EGL_noChange, DCM_TagInfoLength);
 			}
 			return true;
 		}
@@ -87,7 +103,7 @@ namespace GIL
 		/*Actualiza la jerarquia cargada*/
 		int DICOMManager::ActualizarJerarquia(TipoJerarquia& base)
 		{
-			if (m_pDCMDataSet == NULL) {
+			if (m_pDCMSource == NULL) {
 				return 0;
 			}
 
@@ -104,16 +120,16 @@ namespace GIL
 
 			for(;e<=0xFFFF;e++){
 				DcmTagKey key(g,e);
-				cond = m_pDCMDataSet->findAndGetElement(key,element,false);
+				cond = m_pDCMSource->getDataset()->findAndGetElement(key,element,false);
 				if(element!=NULL){
-					m_pDCMDataSet->remove(key);
+					m_pDCMSource->getDataset()->remove(key);
 				}
 			}
 		}
 
 		/*actualiza los tags privados*/
 		int DICOMManager::ActualizarTagsPrivados(TipoPrivateTags& tags){
-			if (m_pDCMDataSet == NULL) {
+			if (m_pDCMSource == NULL) {
 				return 0;
 			}
 
@@ -121,7 +137,7 @@ namespace GIL
 		}
 
 		int DICOMManager::CargarTagsPrivados(GIL::DICOM::TipoPrivateTags& tags) {
-			if (m_pDCMDataSet == NULL) {
+			if (m_pDCMSource == NULL) {
 				return 0;
 			}
 
@@ -140,7 +156,7 @@ namespace GIL
 			OFCondition cond;
 			DcmMetaInfo metaInfo;
 
-			cond = metaInfo.loadFile(inputFile.c_str(), EXS_Unknown, EGL_noChange, DCM_TagInfoLength);
+			cond = metaInfo.loadFile(inputFile.c_str(), EXS_Unknown, EGL_noChange);
 			//metaInfo.loadAllDataIntoMemory();
 			//metaInfo.print(std::cout);
 
@@ -187,37 +203,35 @@ namespace GIL
 			}
 			//
 
-			if (m_pDCMDataSet != NULL) {
-				delete m_pDCMDataSet;
-				m_pDCMDataSet = NULL;
+			if (m_pDCMSource != NULL) {
+				delete m_pDCMSource;
+				m_pDCMSource = NULL;
 			}
 			if (m_pConv != NULL) {
 				delete m_pConv;
 				m_pConv = NULL;
 			}
 
-			DcmFileFormat dcmff;
+			m_pDCMSource = new DcmFileFormat();
 			OFCondition cond;
 
-			if (cargarSoloTagsInfo) {
-				cond = dcmff.loadFile(inputFile.c_str(), EXS_Unknown, EGL_noChange, DCM_TagInfoLength);
+			if (true ||cargarSoloTagsInfo) { // FIXME Review
+				cond = m_pDCMSource->loadFile(inputFile.c_str(), EXS_Unknown, EGL_noChange, DCM_TagInfoLength);
 			}
 			else {
-				cond = dcmff.loadFile(inputFile.c_str(), EXS_Unknown, EGL_noChange, DCM_MaxReadLength);
+				//cond = dcmff.loadFile(inputFile.c_str(), EXS_Unknown, EGL_noChange, DCM_MaxReadLength);
 			}
-			dcmff.loadAllDataIntoMemory();
+			//dcmff.loadAllDataIntoMemory();
 
 			if (cond.bad()) {
 				// TODO: Lanzar excepción
 				return false;
 			}
 
-			m_pDCMDataSet = new DcmDataset(*(dcmff.getDataset()));
-
 			FindCharset();
 
 			if(cargarSoloTagsInfo) {
-				CargarJerarquia(jerarquia,DCM_OptPrintLineLength);
+				CargarJerarquia(jerarquia, DCM_OptPrintLineLength);
 			} else {
 				CargarJerarquia(jerarquia, 0);
 			}
@@ -226,8 +240,8 @@ namespace GIL
 
 
 		/******************/
-		//esto espara cargar el fichero sin llevar todo a memoria, solo lo que nos interese con el gettag
-		bool DICOMManager::CargarFichero(const std::string& inputFile, bool cargarSoloTagsInfo)
+		//esto es para cargar el fichero sin llevar todo a memoria, solo lo que nos interese con el gettag
+		bool DICOMManager::CargarFichero(const std::string& inputFile, bool /*cargarSoloTagsInfo*/)
 		{
 			//comprobamos que es dicom(numero magico, si no el load file a veces casca estrepitosamente)
 			if(!EsDicom(inputFile))
@@ -236,40 +250,38 @@ namespace GIL
 			}
 			//
 
-			if (m_pDCMDataSet != NULL) {
-				delete m_pDCMDataSet;
-				m_pDCMDataSet = NULL;
+			if (m_pDCMSource != NULL) {
+				delete m_pDCMSource;
+				m_pDCMSource = NULL;
 			}
 			if (m_pConv != NULL) {
 				delete m_pConv;
 				m_pConv = NULL;
 			}
 
-			DcmFileFormat dcmff;
+			m_pDCMSource = new DcmFileFormat();
 			OFCondition cond;
 
-			if (cargarSoloTagsInfo) {
-				cond = dcmff.loadFile(inputFile.c_str(),EXS_Unknown,EGL_noChange,DCM_TagInfoLength);
-			}
-			else {
-				cond = dcmff.loadFile(inputFile.c_str());
+			//if (true || cargarSoloTagsInfo) {
+				cond = m_pDCMSource->loadFile(inputFile.c_str(), EXS_Unknown, EGL_noChange, DCM_TagInfoLength);
+			//}
+			//else {
+			//	cond = dcmff.loadFile(inputFile.c_str());
 
-			}
+			//}
 
 			if (cond.bad()) {
 				// TODO: Lanzar excepción
 				return false;
 			}
 
-			cond = dcmff.loadAllDataIntoMemory();
+			//cond = dcmff.loadAllDataIntoMemory();
 
 			if (cond.bad()) {
 				// TODO: Lanzar excepción
 				return false;
 			}
 
-			m_pDCMDataSet = new DcmDataset(*(dcmff.getDataset()));
-
 			FindCharset();
 
 			return true;
@@ -277,7 +289,7 @@ namespace GIL
 
 		bool DICOMManager::GetTag(unsigned int grupo,unsigned int elemento, std::string & valor)
 		{
-			if(m_pDCMDataSet == NULL){
+			if(m_pDCMSource == NULL){
 				//TODO lanzar excepcion de que no esta cargado
 				return false;
 			}
@@ -286,7 +298,7 @@ namespace GIL
 
 			DcmTagKey key(grupo,elemento);
 			DcmElement* pElement;
-			m_pDCMDataSet->findAndGetElement(key,pElement);
+			m_pDCMSource->getDataset()->findAndGetElement(key,pElement);
 			if(pElement != NULL)
 			{
 			    if(pElement->containsUnknownVR()){
@@ -308,14 +320,14 @@ namespace GIL
 
 		bool DICOMManager::GetTag(unsigned int grupo,unsigned int elemento, TagPrivadoUndefined& tagBinario)
 		{
-			if(m_pDCMDataSet == NULL){
+			if(m_pDCMSource == NULL){
 				//TODO lanzar excepcion de que no esta cargado
 				return false;
 			}
 
 			if(grupo == 0x7fe0 && elemento == 0x0010) {
 				//es necesario para pillar el pixeldata en explicit little endian
-				OFCondition cond = m_pDCMDataSet->chooseRepresentation(EXS_DeflatedLittleEndianExplicit,NULL);
+				OFCondition cond = m_pDCMSource->getDataset()->chooseRepresentation(EXS_DeflatedLittleEndianExplicit,NULL);
 				if(cond.bad()) {
 					return false;
 				}
@@ -325,7 +337,7 @@ namespace GIL
 
 			DcmTagKey key(grupo,elemento);
 			DcmElement* pElement;
-			m_pDCMDataSet->findAndGetElement(key,pElement);
+			m_pDCMSource->getDataset()->findAndGetElement(key,pElement);
 			if(pElement != NULL)
 			{
 				OFCondition cond = pElement->loadAllDataIntoMemory();
@@ -356,13 +368,13 @@ namespace GIL
 				return true;
 			} else {
 			    //se intenta interpretar como US
-			    if(m_pDCMDataSet == NULL){
+			    if(m_pDCMSource == NULL){
                     //TODO lanzar excepcion de que no sta cargado
                     return false;
                 }
                 DcmTagKey key(grupo,elemento);
                 DcmElement* pElement;
-                m_pDCMDataSet->findAndGetElement(key,pElement);
+                m_pDCMSource->getDataset()->findAndGetElement(key,pElement);
                 if(pElement != NULL)
                 {
                     Uint8 * ptr;
@@ -397,13 +409,13 @@ namespace GIL
 				return true;
 			} else {
 			    //se intenta interpretar como US
-			    if(m_pDCMDataSet == NULL){
+			    if(m_pDCMSource == NULL){
                     //TODO lanzar excepcion de que no sta cargado
                     return false;
                 }
                 DcmTagKey key(grupo,elemento);
                 DcmElement* pElement;
-                m_pDCMDataSet->findAndGetElement(key,pElement);
+                m_pDCMSource->getDataset()->findAndGetElement(key,pElement);
                 if(pElement != NULL)
                 {
                     Uint8 * ptr;
@@ -431,14 +443,14 @@ namespace GIL
 
 		bool DICOMManager::GetTag(unsigned int grupo,unsigned int elemento, GIL::DICOM::TipoJerarquia& secuencia)
 		{
-			if(m_pDCMDataSet == NULL){
+			if(m_pDCMSource == NULL){
 				//TODO lanzar excepcion de que no sta cargado
 				return false;
 			}
 
 			DcmTagKey key(grupo,elemento);
 			DcmElement* pSequence;
-			m_pDCMDataSet->findAndGetElement(key,pSequence);
+			m_pDCMSource->getDataset()->findAndGetElement(key,pSequence);
 			if(pSequence != NULL)
 			{
 				CargarJerarquia(secuencia,DCM_OptPrintLineLength,pSequence);
@@ -450,14 +462,14 @@ namespace GIL
 
 		bool DICOMManager::FindTag(unsigned int grupo,unsigned int elemento, TagPrivadoUndefined& tagBinario)
 		{
-			if(m_pDCMDataSet == NULL){
+			if(m_pDCMSource == NULL){
 				//TODO lanzar excepcion de que no sta cargado
 				return false;
 			}
 
 			if( (grupo == 0x7fe0 && elemento == 0x0010) || (grupo == 0x5400 && elemento == 0x1010) ) {
 				//es necesario para pillar el pixeldata en explicit little endian
-				OFCondition cond = m_pDCMDataSet->chooseRepresentation(EXS_DeflatedLittleEndianExplicit,NULL);
+				OFCondition cond = m_pDCMSource->getDataset()->chooseRepresentation(EXS_DeflatedLittleEndianExplicit,NULL);
 				if(cond.bad()) {
 					return false;
 				}
@@ -465,7 +477,7 @@ namespace GIL
 
 			DcmTagKey key(grupo,elemento);
 			DcmElement* pElement;
-			m_pDCMDataSet->findAndGetElement(key, pElement, OFTrue);
+			m_pDCMSource->getDataset()->findAndGetElement(key, pElement, OFTrue);
 			if(pElement != NULL)
 			{
 				OFCondition cond = pElement->loadAllDataIntoMemory();
@@ -641,7 +653,7 @@ namespace GIL
 			int numItemsInsertados = 0;
 			int numSeqsInsertadas  = 0;
 
-			if (m_pDCMDataSet == NULL) {
+			if (m_pDCMSource == NULL) {
 				// TODO: Lanzar excepcion
 				return 0;
 			}
@@ -654,7 +666,7 @@ namespace GIL
 					e->putString( wxString( (*it).second.c_str(), wxConvUTF8).mb_str(*m_pConv) );
 					OFCondition cond;
 					if (itemPadre == NULL) {
-						cond = m_pDCMDataSet->insert(e, true, false);
+						cond = m_pDCMSource->getDataset()->insert(e, true, false);
 						char* str = NULL;
 						e->getString(str);
 						if(str!=NULL){
@@ -767,7 +779,7 @@ namespace GIL
 
 					}
 					else {
-						cond = m_pDCMDataSet->insert(seq, OFTrue);
+						cond = m_pDCMSource->getDataset()->insert(seq, OFTrue);
 						GTRACE("raiz << " << seq->getTag().toString());
 					}
 
@@ -798,12 +810,12 @@ namespace GIL
 
 			FindCharset();
 
-			unsigned long elemCount = m_pDCMDataSet->card();
+			unsigned long elemCount = m_pDCMSource->getDataset()->card();
 
 			//si es nulo, queremos cargar toda la jerarquia
 			if(pElementoInicial == NULL) {
 				for (unsigned long i = 0; i < elemCount; i++) {
-					DcmElement *e = m_pDCMDataSet->getElement(i);
+					DcmElement *e = m_pDCMSource->getDataset()->getElement(i);
 					if (e->getGTag() == 0x7fe0 && e->getETag() == 0x0010) {
 						// Excluir pixel data
 					}
@@ -916,7 +928,7 @@ namespace GIL
 				element = (*it).second->ToElement(g,eTemp);
 				if (element != NULL)
 				{
-					cond = m_pDCMDataSet->insert(element, true, false);
+					cond = m_pDCMSource->getDataset()->insert(element, true, false);
 					if (cond.bad()) {
 						std::cerr << "error al almacenar los tags privados, error al escribir en el dataset: (" << g << ","<<eTemp<<")" <<std::endl;
 						return 0;
@@ -967,7 +979,7 @@ namespace GIL
 					return 0;
 				}
 
-				cond = m_pDCMDataSet->findAndGetElement(key,element,false);
+				cond = m_pDCMSource->getDataset()->findAndGetElement(key,element,false);
 
 				if (element!=NULL && cond.good()){
 					if (element->getVR() == EVR_LT) {
@@ -1009,7 +1021,7 @@ namespace GIL
 
 			for(;e<=0x00FF;e++){
 				DcmTagKey key(g,e);
-				cond = m_pDCMDataSet->findAndGetElement(key,element,false);
+				cond = m_pDCMSource->getDataset()->findAndGetElement(key,element,false);
 				if(element==NULL){
 					//esta libre el slot
 					//se introduce el uid
@@ -1037,7 +1049,7 @@ namespace GIL
 						return 0;
 					}
 
-					cond = m_pDCMDataSet->insert(element, true, false);
+					cond = m_pDCMSource->getDataset()->insert(element, true, false);
 					break;
 				}
 
@@ -1075,11 +1087,11 @@ namespace GIL
 
 			std::string Charset;
 
-			if (m_pDCMDataSet->findAndGetOFString(DCM_SpecificCharacterSet, OFCharSet).good()) {
+			if (m_pDCMSource->getDataset()->findAndGetOFString(DCM_SpecificCharacterSet, OFCharSet).good()) {
 				Charset.assign(OFCharSet.c_str());
 			}
 			else {
-				m_pDCMDataSet->putAndInsertOFStringArray(DCM_SpecificCharacterSet, "ISO_IR 192");
+				m_pDCMSource->getDataset()->putAndInsertOFStringArray(DCM_SpecificCharacterSet, "ISO_IR 192");
 			}
 
 			if (Charset == "ISO_IR 192" || Charset == "ISO_IR 6" || Charset == "ISO_IR 138") {
@@ -1118,5 +1130,13 @@ namespace GIL
 
 		}
 
+		
+		void DICOMManager::CreateTempFile()
+		{
+		}
+
+		void DICOMManager::CleanupTempFile()
+		{
+		}
 	}
 }
