@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dicommanager.h 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: dicommanager.h 4305 2011-10-18 11:28:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -17,6 +17,7 @@
 
 class DcmMetaInfo;
 class DcmDataset;
+class DcmFileFormat;
 class DcmElement;
 class OFCondition;
 class DcmItem;
@@ -78,7 +79,7 @@ namespace GIL
 			virtual std::string GetNewUID();
 //endregion
 
-//region "Helpers internos"
+//region "External helpers"
 			/*Comprueba el numero magico si es dicom*/
 			static bool EsDicom(const std::string& inputFile);
 
@@ -102,11 +103,17 @@ namespace GIL
 
 //endregion
 
-		protected:
+//region "Internal helpers"
 
+		private:
 			void FindCharset();
+			void CreateTempFile();
+			void CleanupTempFile();
+//endregion
 
-			DcmDataset*  m_pDCMDataSet;
+		private:
+
+			DcmFileFormat*  m_pDCMSource;
 			wxCSConv* m_pConv;
 		};
 
