@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: dicomstoreassociation.cpp 3784 2011-04-27 12:07:33Z tovar $
+ *  $Id: dicomstoreassociation.cpp 3921 2011-07-06 11:36:02Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -24,8 +24,8 @@
 #endif
 
 #include "dicomstoreassociation.h"
-#include <api/idicommanager.h>
-#include <api/internacionalizacion.h>
+#include <api/dicom/imodelodicom.h>
+
 #include <api/iproxynotificadorprogreso.h>
 #include <main/controllers/controladorpermisos.h>
 #include <main/entorno.h>
@@ -783,6 +783,7 @@ namespace GIL {
 					os<< "Error al enviar el archivo";
 					if(statusDetail!=NULL)
 						statusDetail->print(os);
+					os << ": " << cond.text();
 					errorEncontrado = os.str();
 					LOG_ERROR(LOGGER, errorEncontrado);
 				}
