@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: pacscontroller.cpp 4103 2011-08-31 06:33:25Z tovar $
+*  $Id: pacscontroller.cpp 4351 2011-10-31 09:15:33Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -615,6 +615,10 @@ namespace GIL {
 
 		bool PACSController::ObtenerEstudio(void* connectionKey, const std::string& serverId, const std::string& uidEstudio, const std::string& AccNumber, IModeloDicom* pModelo, GNC::IProxyNotificadorProgreso* pNotificador)
 		{
+			//ESTO ES PARA QUE FUNCIONE EL PACS DE SIEMENS, VER SI SE PUEDE QUITAR...
+			ReleaseConnection(connectionKey);
+			GetConnection(connectionKey);
+
 			GTRACE("PACSController::ObtenerEstudio( " << serverId.c_str() << ", " << uidEstudio.c_str() << ", " << uidSerie.c_str());
 
 			if (pModelo == NULL) {
@@ -644,25 +648,104 @@ namespace GIL {
 			e = newDicomElement(DCM_StudyID);
 			query.insert(e);
 
-			e = newDicomElement(DCM_StudyInstanceUID);
-			if (uidEstudio != "") {				
-				e->putString(uidEstudio.c_str());				
+			if (!AccNumber.empty()){
+				e = newDicomElement(DCM_AccessionNumber);
+				e->putString(AccNumber.c_str());
+			    query.insert(e);
 			}
-			query.insert(e);
-
-			e = newDicomElement(DCM_AccessionNumber);
-			if (AccNumber != ""){
-				e->putString(AccNumber.c_str());				
-			}
-			query.insert(e);
 
 			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
 			DicomServer* server = listaServidores->GetServer(serverId);
-			if (server->GetRetrieveWithMove()) {
+			if (server->GetRetrieveSeries()) {
+				//buscar + descargar series...
+				//we have to know the series uids and obtain series by series
+				e = newDicomElement(DCM_QueryRetrieveLevel);
+				e->putString("SERIES");
+				query.insert(e);
+
+				if (!uidEstudio.empty()) {		
+					e = newDicomElement(DCM_StudyInstanceUID);
+					e->putString(uidEstudio.c_str());
+					query.insert(e);
+				}
+
+				e = newDicomElement(DCM_SeriesInstanceUID);
+				query.insert(e);
+
+				e = newDicomElement(DCM_Modality);
+				query.insert(e);
+
+				std::list<std::string> listOfUIDS;
+				std::list<std::string> listOfModalities;
+				{
+					NetClient<FindAssociation> f(connectionKey, "C-GET/FIND", pNotificador);
+					f.SetMaxResults(-1);
+
+					std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
+
+					DicomServer* server = listaServidores->GetServer(serverId);
+					if (server->useTLS) {
+						f.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
+					}
+					if (server->GetPACSUser() != "") {
+						f.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
+					}
+
+					f.QueryServer(&query, server, pModelo, localAET, CT_None);
+
+					if (f.Stopped()){
+						return false;
+					}
+					DcmStack* stack = f.GetResultStack();
+
+					unsigned int numResults = 0;
+
+					numResults = stack->card();
+					
+
+					for (unsigned int i = 0; i < numResults; i++) {
+
+						if (stack->elem(i)->ident() == EVR_dataset) {
+							DcmDataset* dset = dynamic_cast<DcmDataset*>(stack->elem(i));
+							if (dset) {
+								OFString OFSSeriesInstanceUID;
+								OFString OFSeriesModality;
+								if ( dset->findAndGetOFString(DCM_SeriesInstanceUID, OFSSeriesInstanceUID).good() && dset->findAndGetOFString(DCM_Modality, OFSeriesModality).good() )
+								{
+									std::string seriesInstanceUID(OFSSeriesInstanceUID.c_str());
+									std::string seriesModality(OFSeriesModality.c_str());
+
+									listOfUIDS.push_back(seriesInstanceUID);
+									listOfModalities.push_back(seriesModality);
+								}
+							}
+
+						}
+					}
+				}
+				
+				for (std::list<std::string>::iterator itUIDS = listOfUIDS.begin(), itModalities = listOfModalities.begin();
+					itUIDS != listOfUIDS.end(); itUIDS++, itModalities++) 
+				{
+//ESTO ES PARA QUE FUNCIONE EL PACS DE SIEMENS, VER SI SE PUEDE QUITAR...
+					ReleaseConnection(connectionKey);
+					GetConnection(connectionKey);
+//
+					ObtenerSerie(connectionKey, serverId, (*itUIDS), pModelo, pNotificador, (*itModalities));
+				}
+
+				query.clear();	
+			} else if (server->GetRetrieveWithMove()) {
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("STUDY");
 				query.insert(e);
+				
+				if (!uidEstudio.empty()) {		
+					e = newDicomElement(DCM_StudyInstanceUID);
+					e->putString(uidEstudio.c_str());
+					query.insert(e);
+				}
 
 				int puerto = 11112;
 				{
@@ -698,12 +781,15 @@ namespace GIL {
 				//we have to know the series uids and obtain series by series
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("SERIES");
-				query.insert(e);
-
+				
+				//needed to make find
 				e = newDicomElement(DCM_StudyInstanceUID);
+				if (uidEstudio.empty()) {
+					//throw GIL::DICOM::PACSException(_Std("Invalid study query: No StudyInstanceUID provided"));
+				}
 				e->putString(uidEstudio.c_str());
 				query.insert(e);
-
+				
 				e = newDicomElement(DCM_SeriesInstanceUID);
 				query.insert(e);
 
@@ -719,7 +805,7 @@ namespace GIL {
 				if (server->useTLS) {
 					f.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
 				}
-				if (server->GetPACSUser() != "") {
+				if (!server->GetPACSUser().empty()) {
 					f.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
 				}
 
@@ -753,7 +839,7 @@ namespace GIL {
 					}
 				}
 
-				query.clear();				
+				query.clear();
 
 			}
 
@@ -786,6 +872,9 @@ namespace GIL {
 				e = newDicomElement(DCM_QueryRetrieveLevel);
 				e->putString("SERIES");
 				query.insert(e);
+				
+				e = newDicomElement(DCM_StudyInstanceUID);
+				query.insert(e);
 
 				e = newDicomElement(DCM_SeriesInstanceUID);
 				e->putString(uidSerie.c_str());
@@ -852,8 +941,10 @@ namespace GIL {
 			e->putString("SERIES");
 			query.insert(e);
 
+			/* WARNING YOU CANT INSERT EMPTY STUDY INSTANCE UID AT SERIES LEVEL
 			e = newDicomElement(DCM_StudyInstanceUID);
 			query.insert(e);
+			*/
 
 			e = newDicomElement(DCM_SeriesInstanceUID);
 			e->putString(uidSerie.c_str());
@@ -1290,4 +1381,4 @@ namespace GIL {
 		}
 		//endregion
 	};
-};
+};
\ No newline at end of file
