@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parserxmlenglish.cpp 3963 2011-07-11 14:03:51Z tovar $
+ *  $Id: parserxmlenglish.cpp 4034 2011-07-21 09:44:05Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -232,7 +232,7 @@ void GIL::HL7::ParserXMLEnglish::ParseIntegrationXML(GNC::GCS::IEntorno::ListaMo
 				models.push_back(modelo);
 			} //fin gnkworkflow
 		} //fin de parseo de gnkworkflows
-	} else if (pRoot->GetName().CmpNoCase(wxT("plantilla")) == 0) {
+	} else if (pRoot->GetName().CmpNoCase(wxT("gnkworkflow")) == 0) {
 		GIL::IModeloIntegracion* modelo = ParseGnkWorkflow(pRoot, servers);
 		models.push_back(modelo);
 	} else {
@@ -329,7 +329,7 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 		if(hijo->GetName().CmpNoCase(wxT("query-retrieve-level")) == 0){
 			propVal = hijo->GetPropVal(wxT("value"), wxEmptyString);
 			if ( !propVal.empty() ) {
-				modelo->ambitoDIMSE = propVal.ToUTF8();
+				modelo->ambitoDIMSE = propVal.Upper().ToUTF8();
 			}
 			else {
 				throw HL7XMLException(_Std("\"value\" attribute expected at \"query-retrieve-level\" scope"), xpp, "CONF/template");
@@ -478,9 +478,6 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode*
 		modelo->Metadatos.push_back(IModeloTupla("DICOM","0010|0020", modelo->Paciente.GetIdentificadorPreferido().valor,""));
 	}
 	if (modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
-		if (modelo->idPlantilla == "") {
-			throw HL7XMLException(_Std("\"tid\" attribute omitted"), xpp, "CONF/template");
-		}
 		if (modelo->idAmbitoPeticion == "") {
 			throw HL7XMLException(_Std("\"scope\" attribute expected at \"gnkworkflow\" scope"), xpp, "CONF/template");
 		}
