@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parserxmlenglish.h 3664 2011-04-08 11:38:02Z tovar $
+ *  $Id: parserxmlenglish.h 3963 2011-07-11 14:03:51Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -20,11 +20,13 @@ namespace GIL {
 	namespace HL7 {
 		class ParserXMLEnglish : public GIL::HL7::IXMLIntegrationParser {
 		public:
+			typedef std::map<std::string, GIL::IModeloPACSServer> MapaServers;
 
 			ParserXMLEnglish();
 			~ParserXMLEnglish();
-			virtual std::string GetKey();
-			virtual void ParseIntegrationXML(GNC::GCS::IEntorno::ListaModelosIntegracion& models, wxXmlNode* pRoot);			
+			virtual std::list<std::string> GetKeys();
+			virtual void ParseIntegrationXML(GNC::GCS::IEntorno::ListaModelosIntegracion& models, wxXmlNode* pRoot);	
+			virtual GIL::IModeloIntegracion* ParseGnkWorkflow(wxXmlNode* pNode, MapaServers& servers);		
 		protected:
 		};
 	}
