@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parserxmlspanish.cpp 3963 2011-07-11 14:03:51Z tovar $
+ *  $Id: parserxmlspanish.cpp 4034 2011-07-21 09:44:05Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -513,9 +513,6 @@ GIL::IModeloIntegracion* GIL::HL7::ParserXMLSpanish::ParsePlantilla(wxXmlNode* n
 	{
 		modelo->Metadatos.push_back(IModeloTupla("DICOM","0010|0020", modelo->Paciente.GetIdentificadorPreferido().valor,""));
 	}
-	if (modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar && modelo->idPlantilla == "") {
-		throw HL7XMLException(_Std("\"tid\" attribute omitted"), xpp, "CONF/template");
-	}
 	if(modelo->HCE.Sid == "") {
 		throw HL7XMLException(_Std("id_application expected"), xpp, "CONF/template");
 	}
