@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: streamingloader.cpp 3921 2011-07-06 11:36:02Z tovar $
+ *  $Id: streamingloader.cpp 4314 2011-10-19 09:44:46Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -162,7 +162,7 @@ GNC::StreamingLoader::StreamingLoader()
 	m_IO = ImageIO::New();
 	m_IO->SetLoadPrivateTags(false);
 	//Esto da leaks no activar
-	//m_IO->SetLoadSequences(false);
+	m_IO->SetLoadSequences(false);
 	m_IO->SetUseStreamedReading(true);
 	m_IO->SetMaxSizeLoadEntry(1024); // No permitir cargar campos de mas de 1K
 	m_pOutput = vtkSmartPointer<vtkImageChangeInformation>::New();
@@ -638,7 +638,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 		m_CurrentComponentType      = ImageIO::UNKNOWNCOMPONENTTYPE;
 		m_CurrentPixelType          = ImageIO::SCALAR;
 		m_CurrentDimensions[0]      = 800;
-		m_CurrentDimensions[1]      = 600;
+		m_CurrentDimensions[1]      = 800;
 		m_CurrentDimensions[2]      = 1;
 		m_pReader = NULL;
 		m_pPipelineJoiner = NULL;
@@ -657,7 +657,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 		TypedImageType::SizeType size;
 		TypedImageType::IndexType index;
 		size[0] = 800;
-		size[1] = 600;
+		size[1] = 800;
 		size[2] = 1;
 		index[0] = index[1] = index[2] = 0;
 		TypedImageType::RegionType region;
