@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: xmlrpccontroller.cpp 3712 2011-04-15 11:29:44Z carlos $
+*  $Id: xmlrpccontroller.cpp 3893 2011-06-21 13:01:56Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,12 +15,13 @@
 #include <wx/file.h>
 #include <wx/filename.h>
 #include <wx/dir.h>
-#include <wx/config.h>
+#include <main/controllers/configurationcontroller.h>
 #include <wx/wxsqlite3/wxsqlite3.h>
 
 #include "xmlrpccontroller.h"
 #include <api/globals.h>
-#include <api/internacionalizacion.h>
+#include <api/threads/thread.h>
+
 #define LOGGER "XMLRPCController"
 #include "controladorlog.h"
 #include "../entorno.h"
@@ -228,18 +229,14 @@ namespace XmlRpc {
 				wxRemoveFile(pathFicheroPrueba);
 			}
 
-			wxConfigBase * config = wxConfigBase::Get();
-			//update path stored in the ini file
-			config->SetPath(wxT("/GinkgoCore/Estacion"));
+			std::string oldPath;
+			GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion","DicomDir", oldPath);
 
-			wxString oldPath;
-			config->Read(wxT("DicomDir"), &oldPath, wxEmptyString);
-
-			wxFileName dirAnterior(oldPath);
+			wxFileName dirAnterior(wxString::FromUTF8(oldPath.c_str()));
 			wxFileName dirNuevo(newPath);
 			if(dirAnterior != dirNuevo)
 			{
-				config->Write(wxT("DicomDir"),newPath);
+				GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Estacion","DicomDir", std::string(newPath.ToUTF8()));
 				//command is thrown to make update
 				GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("Closing windows..."), new ChangeDicomDirCommand(), NULL);
 			}
@@ -407,12 +404,7 @@ namespace XmlRpc {
 			}
 			std::string codigoAplicacion;
 			//se extrae de la configuracion el codigo de aplicacion
-			wxString valor;
-			wxConfigBase* config = wxConfigBase::Get();
-			config->SetPath(wxT("/GinkgoCore/HCE"));
-
-			config->Read(wxT("CodigoAplicacion"), &valor, wxEmptyString);
-			pModelo->CodigoAplicacion = valor.ToUTF8();
+			GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","CodigoAplicacion", pModelo->CodigoAplicacion);
 
 			try {
 				GIL::HL7::ControladorHL7 controlador;
@@ -612,11 +604,9 @@ void GIL::XMLRPC::XMLRPCController::FreeInstance()
 
 void GIL::XMLRPC::XMLRPCController::StartServer()
 {
-	wxConfigBase * config = wxConfigBase::Get();
-	//se actualiza el fichero de configuracion
-	config->SetPath(wxT("/GinkgoCore/HCE"));
 	bool boolValue;
-	config->Read(wxT("XMLRPCServerEnabled"),&boolValue,false);
+	GNC::GCS::ConfigurationController::Instance()->readBoolGeneral("/GinkgoCore/HCE", "XMLRPCServerEnabled", boolValue, false);
+
 	if (boolValue) {
 		wxCriticalSectionLocker locker(m_criticalSection);		
 		if (m_pInstance == NULL) {
@@ -678,15 +668,9 @@ void* GIL::XMLRPC::XMLRPCController::Entry()
 //	XmlRpc::XmlRpcLogHandler::setLogHandler(m_pLogHandler);
 	XmlRpc::XmlRpcLogHandler::setVerbosity(5);
 
-	
-	wxConfigBase * config = wxConfigBase::Get();
-	//se actualiza el fichero de configuracion
-	config->SetPath(wxT("/GinkgoCore/HCE"));
-	wxString wxTmp;
-	config->Read(wxT("XMLRPCServerPort"),&wxTmp,wxEmptyString);
-
-	long port;
-	if (wxTmp.ToLong(&port)) {
+	int port;
+	if (GNC::GCS::ConfigurationController::Instance()->readIntGeneral("/GinkgoCore/HCE","XMLRPCServerPort", port))
+	{
 		//register methods
 		XmlRpc::CloseAllWindows closeAll(m_pServer);
 		XmlRpc::OpenDB openDB(m_pServer);
