@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: entorno.h 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: entorno.h 4327 2011-10-25 06:55:31Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -66,8 +66,9 @@ namespace GNC {
 		virtual const std::string GetGinkgoRegisteredOrganization();
 
 		virtual const std::string& GetGinkgoVersion();
-		virtual void GetGinkgoVersionAsTuple(int* version, int* subversion, int* relase, int* build, std::string* codename);
+		virtual void GetGinkgoVersionAsTuple(int* version, int* subversion, int* release, int* build, std::string* codename);
 		virtual const std::string& GetGinkgoCopyRight();
+		virtual int ParseSVNBuild(const char* str);
 		virtual std::string GetGinkgoDicomDir(bool barraAlFinal = false);
 		virtual void RefrescarDicomDir();
 
@@ -77,6 +78,7 @@ namespace GNC {
 		virtual const std::string& GetPluginsPath();
 		virtual const std::string& GetGinkgoUserDir();
 		virtual const std::string& GetGinkgoTempDir();
+		virtual std::string CreateGinkgoTempDir();
 		virtual const std::string& GetGinkgoLanguageDir();
 		virtual const std::string& GetGinkgoResourcesDir();
 		virtual std::string CrearDirectorioTemporal();
