@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: dialogoadquisicion.cpp 4076 2011-08-11 06:37:52Z carlos $
+*  $Id: dialogoadquisicion.cpp 4402 2011-11-11 13:44:34Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -104,30 +104,6 @@ GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdq
 	m_pZonaDescargas->Layout();
 
 	if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits", "patient_scope")) {
-		m_HardCodedPatientSearch = true;
-		bool first = true;
-		std::ostringstream os;
-
-		GNC::GCS::IEntorno::ListaModelosIntegracion& modelos = GNC::Entorno::Instance()->GetModelosIntegracion();
-
-		for (GNC::GCS::IEntorno::ListaModelosIntegracion::iterator it = modelos.begin(); it != modelos.end(); it++) {
-
-			GIL::IModeloIntegracion* modelo = *it;
-			GIL::TListaIdentificadores& ids = modelo->Paciente.listaIdentificadores;
-
-			for (GIL::TListaIdentificadores::iterator it = ids.begin(); it != ids.end(); it++)
-			{
-				if (first) {
-					first = false;
-				}
-				else {
-					os << "/";
-				}
-				os << (*it).valor;
-			}
-
-		}
-
 		int tmpIndex = m_pFieldCombo->FindString(_("Id"));
 		if (tmpIndex > 0) {
 			m_pFieldCombo->Remove(tmpIndex,tmpIndex);
@@ -136,8 +112,16 @@ GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdq
 		if (tmpIndex > 0) {
 			m_pFieldCombo->Remove(tmpIndex,tmpIndex);
 		}
+		m_pTextControlField->SetEditable(false);
+		m_pTextControlField->Enable(false);
+		m_pFieldCombo->Enable(false);
+		m_pPACSListaServidores->Enable(false);
 
-		m_HardCodedPatientId = os.str();
+		m_pTextControlField->Show(false);
+		m_pFieldCombo->Show(false);
+		m_pPatientLabelStr->Show(false);
+		m_pLabelRestricted->Show(true);
+		m_pPanelPACS->Layout();
 	}
 	else {
 		int tmpIndex = m_pFieldCombo->FindString(_("Name"));
@@ -148,7 +132,6 @@ GNC::GUI::DialogoAdquisicion::DialogoAdquisicion(wxWindow* pParent) : DialogoAdq
 		if (tmpIndex < 0) {
 			m_pFieldCombo->Insert(_("Id"),0);
 		}
-		m_HardCodedPatientSearch = false;
 	}
 	m_pFieldCombo->Select(0);
 
@@ -183,6 +166,28 @@ GNC::GUI::DialogoAdquisicion::~DialogoAdquisicion()
 	m_pAnimation->Destroy();
 }
 
+bool GNC::GUI::DialogoAdquisicion::Show(const std::string& idPatient, const std::string& idPACS)
+{
+	m_pTextControlField->Show(true);
+	m_pFieldCombo->Show(true);
+	m_pPatientLabelStr->Show(true);
+	m_pLabelRestricted->Show(false);
+
+	m_pTextControlField->Enable(true);
+	m_pTextControlField->SetValue(wxString::FromUTF8(idPatient.c_str()));
+
+	m_pPanelPACS->Layout();
+
+	GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Adquisicion", "PACSDefecto", idPACS);
+
+	//load pacs list and select pacs..
+	bool retVal = Show(true);
+
+	Search();
+
+	return retVal;
+}
+
 bool GNC::GUI::DialogoAdquisicion::Show(bool show)
 {
 	//se recarga la lista de servidores pacs
@@ -301,7 +306,11 @@ void GNC::GUI::DialogoAdquisicion::OnCancelClick( wxCommandEvent&  )
 
 void GNC::GUI::DialogoAdquisicion::OnBusquedaClick( wxCommandEvent&  )
 {
+	Search();
+}
 
+void GNC::GUI::DialogoAdquisicion::Search()
+{
 	if (m_AutoAddSeries)  {
 		m_AutoAddSeries = false;
 		m_AutoAddSeriesItem = NULL;
@@ -333,13 +342,13 @@ void GNC::GUI::DialogoAdquisicion::OnBusquedaClick( wxCommandEvent&  )
 	std::string timeTo("");
 	if (m_pBetween->GetValue()){
 		if(m_pTextControlFechaDesde->GetValue().IsValid()){
-			fechaDesde =  std::string(m_pTextControlFechaDesde->GetValue().Format(wxT("%Y/%m/%d")).ToUTF8());
+			fechaDesde =  std::string(m_pTextControlFechaDesde->GetValue().Format(wxT("%Y%m%d")).ToUTF8());
 		}
 		if(m_pTextControlFechaHasta->GetValue().IsValid()){
-			fechaHasta =  std::string(m_pTextControlFechaHasta->GetValue().Format(wxT("%Y/%m/%d")).ToUTF8());
+			fechaHasta =  std::string(m_pTextControlFechaHasta->GetValue().Format(wxT("%Y%m%d")).ToUTF8());
 		}
 	} else if (m_pToday->GetValue() || m_pTodayAM->GetValue() || m_pTodayPM->GetValue()) {
-		fechaDesde = fechaHasta = wxDateTime::Now().Format(wxT("%Y/%m/%d")).ToUTF8();
+		fechaDesde = fechaHasta = wxDateTime::Now().Format(wxT("%Y%m%d")).ToUTF8();
 		if (m_pTodayAM->GetValue()) {
 			timeFrom = "000000";
 			timeTo = "115959";
@@ -348,17 +357,16 @@ void GNC::GUI::DialogoAdquisicion::OnBusquedaClick( wxCommandEvent&  )
 			timeTo = "235959";
 		}
 	} else if (m_pYesterday->GetValue()) {
-		fechaHasta = fechaDesde = wxDateTime::Now().Add(wxDateSpan(0,0,0,-1)).Format(wxT("%Y/%m/%d")).ToUTF8();
+		fechaDesde = wxDateTime::Now().Add(wxDateSpan(0,0,0,-1)).Format(wxT("%Y%m%d")).ToUTF8();
 	} else if (m_pLastWeek->GetValue()) {
-		fechaDesde = wxDateTime::Now().Add(wxDateSpan(0,0,-1,0)).Format(wxT("%Y/%m/%d")).ToUTF8();
+		fechaDesde = wxDateTime::Now().Add(wxDateSpan(0,0,-1,0)).Format(wxT("%Y%m%d")).ToUTF8();
 	} else if (m_pLastMonth->GetValue()) {
-		fechaDesde = wxDateTime::Now().Add(wxDateSpan(0,-1,0,0)).Format(wxT("%Y/%m/%d")).ToUTF8();
+		fechaDesde = wxDateTime::Now().Add(wxDateSpan(0,-1,0,0)).Format(wxT("%Y%m%d")).ToUTF8();
 	} else if (m_pLastThreeMonths->GetValue()) {
-		fechaDesde = wxDateTime::Now().Add(wxDateSpan(0,-3,0,0)).Format(wxT("%Y/%m/%d")).ToUTF8();
+		fechaDesde = wxDateTime::Now().Add(wxDateSpan(0,-3,0,0)).Format(wxT("%Y%m%d")).ToUTF8();
 	}
 
-	if(fechaDesde == "" && fechaHasta == "" && m_pTextControlField->GetValue().size() == 0
-		&& (m_HardCodedPatientSearch && m_HardCodedPatientId.size() == 0) )
+	if(fechaDesde == "" && fechaHasta == "" && m_pTextControlField->GetValue().size() == 0)
 	{
 		int answer = wxMessageBox(_("Search without parameters could take al long time\nWould you like to continue?"),_("Search"), wxYES_NO , this);
 		if (answer == wxNO) {
@@ -368,11 +376,6 @@ void GNC::GUI::DialogoAdquisicion::OnBusquedaClick( wxCommandEvent&  )
 
 	std::string idPaciente, nombrePaciente, studyUID, accNumber;
 
-	if (m_HardCodedPatientSearch) {
-		idPaciente = m_HardCodedPatientId;
-		nombrePaciente = "";
-	}
-
 	if (m_pFieldCombo->GetValue() == _("Id")) {
 		idPaciente = m_pTextControlField->GetValue().ToUTF8();
 	} else if (m_pFieldCombo->GetValue() == _("Name")) {
@@ -383,6 +386,7 @@ void GNC::GUI::DialogoAdquisicion::OnBusquedaClick( wxCommandEvent&  )
 		studyUID = m_pTextControlField->GetValue().ToUTF8();
 	}
 
+
 	//modalities checked
 
 
@@ -872,7 +876,11 @@ void GNC::GUI::DialogoAdquisicion::ShowProperties()
 			listaMapas.push_back(mapaPropiedades);
 		}
 
-		GNC::GUI::wxPropiedades* pProp = new GNC::GUI::wxPropiedades(this, _Std("Search Results"), listaMapas);
+		GNC::GUI::wxPropiedades* pProp = new GNC::GUI::wxPropiedades(this, _Std("search results"), listaMapas);
+		//increments width
+		wxSize size = pProp->GetSize();
+		size.x = 500;
+		pProp->SetSize(size);
 		pProp->Show();
 
 	}
@@ -1022,7 +1030,12 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 							}
 
 
-							wxTreeItemId serieTreeId = m_pTreeListResultados->AppendItem(estudioTreeId, descripcionSerie);
+							wxTreeItemId serieTreeId;
+							if (descripcionSerie.IsEmpty()) {
+								serieTreeId = m_pTreeListResultados->AppendItem(estudioTreeId, _("Untitled"));
+							} else {
+								serieTreeId = m_pTreeListResultados->AppendItem(estudioTreeId, descripcionSerie);
+							}
 							m_pTreeListResultados->SetItemText(serieTreeId, COLUMNA_MODALIDAD, tipoSerie);
 
 							m_pTreeListResultados->SetItemText(serieTreeId, COLUMNA_FECHA, fechaStr);
@@ -1133,8 +1146,6 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 				return;
 			}
 
-
-
 			{
 
 				wxWindowDisabler disableAll;
@@ -1212,14 +1223,14 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 								fecha.SetMinute(hora.GetMinute());
 								fecha.SetSecond(hora.GetSecond());
 
-								fechaStr = wxString(fecha.Format(_("%m/%d/%Y %H:%M:%S"), wxDateTime::TimeZone(wxDateTime::GMT1)));
+								fechaStr = wxString(fecha.Format(wxT("%m/%d/%Y %H:%M:%S"), wxDateTime::TimeZone(wxDateTime::GMT1)));
 							}
 							else {
-								fechaStr = wxString(fecha.Format(_("%m/%d/%Y 00:00:00"), wxDateTime::TimeZone(wxDateTime::GMT1)));
+								fechaStr = wxString(fecha.Format(wxT("%m/%d/%Y 00:00:00"), wxDateTime::TimeZone(wxDateTime::GMT1)));
 							}
 						}
 						else {
-							fechaStr = _("00/00/0000 00:00:00");
+							fechaStr = wxT("00/00/0000 00:00:00");
 						}
 
 						std::list<wxTreeItemId> e_items = m_pTreeListResultados->GetPublicChildren(pacienteTreeId);
@@ -1241,7 +1252,11 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 
 						if (notfound) {
 							//columnas
-							estudioTreeId = m_pTreeListResultados->AppendItem(pacienteTreeId, descripcionEstudio);
+							if (descripcionEstudio.IsEmpty()) {
+								estudioTreeId = m_pTreeListResultados->AppendItem(pacienteTreeId, _("Untitled"));
+							} else {
+								estudioTreeId = m_pTreeListResultados->AppendItem(pacienteTreeId, descripcionEstudio);
+							}
 							m_pTreeListResultados->SetItemText(estudioTreeId, COLUMNA_MODALIDAD, modalidadEstudio);
 							m_pTreeListResultados->SetItemText(estudioTreeId, COLUMNA_FECHA, fechaStr);
 
@@ -1284,14 +1299,14 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 										fechaSerie.SetMinute(horaSerie.GetMinute());
 										fechaSerie.SetSecond(horaSerie.GetSecond());
 
-										fechaSerieStr = wxString(fechaSerie.Format(_("%m/%d/%Y %H:%M:%S"), wxDateTime::TimeZone(wxDateTime::GMT1)));
+										fechaSerieStr = wxString(fechaSerie.Format(wxT("%m/%d/%Y %H:%M:%S"), wxDateTime::TimeZone(wxDateTime::GMT1)));
 									}
 									else {
-										fechaSerieStr = wxString(fechaSerie.Format(_("%m/%d/%Y 00:00:00"), wxDateTime::TimeZone(wxDateTime::GMT1)));
+										fechaSerieStr = wxString(fechaSerie.Format(wxT("%m/%d/%Y 00:00:00"), wxDateTime::TimeZone(wxDateTime::GMT1)));
 									}
 								}
 								else {
-									fechaSerieStr = _("00/00/0000 00:00:00");
+									fechaSerieStr = wxT("00/00/0000 00:00:00");
 								}
 
 								std::list<wxTreeItemId> s_items = m_pTreeListResultados->GetPublicChildren(estudioTreeId);
@@ -1335,6 +1350,9 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 							}
 						}//end TD_SERIES
 					}
+					if (pModelo->ListaPacientes().size() < 2) {
+						m_pTreeListResultados->Expand(pacienteTreeId);
+					}
 				}
 				m_pTreeListResultados->SortChildren(m_pTreeListResultados->GetRootItem());
 				Thaw();
