@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionextensiones.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: panelconfiguracionextensiones.h 4072 2011-08-10 13:45:52Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -44,14 +44,12 @@ namespace GNC {
 				void Importar(wxXmlNode* pNodo);
 				//endregion
 
+				virtual void OnPropiedadCambiada();
+
+				virtual void OnObtainExtensions(wxCommandEvent& event);
 
 			protected:
-				virtual void OnListaPACSChoice(wxCommandEvent &event);
-				virtual void OnShowActivationDialog(wxCommandEvent& event);
-				virtual void OnActivateItem(wxTreeEvent &event);
-
-				void ShowActivation();
-
+								
 				void OnSize(wxSizeEvent &);
 
 				bool m_hasBeenChanged;
