@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguraciongeneral.h 3673 2011-04-11 13:49:47Z carlos $
+ *  $Id: panelconfiguraciongeneral.h 4409 2011-11-17 14:03:02Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -18,6 +18,7 @@
 #include <api/iconfiguracion.h>
 #include "panelesconfiguracionginkgobase.h"
 
+class wxProxySettings;
 namespace GNC {
 	namespace GUI {
 
@@ -54,9 +55,12 @@ namespace GNC {
 				void OnIdiomaCambiado(wxCommandEvent &event);
 				void OnSeleccionarDirectorio(wxCommandEvent &event);
 				void OnSize(wxSizeEvent& event);
+				virtual void OnProxySettings(wxCommandEvent &event);
+				virtual void OnCheckEnableProxySettings(wxCommandEvent &event);
 				bool m_idiomaCambiado;
 				typedef std::map<std::string, int> TMapLanguages;
 				TMapLanguages m_mapLanguages;
+				wxProxySettings* pProxySettings;
 		};
 	}
 }
