@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionpacs.cpp 4023 2011-07-19 13:01:58Z tovar $
+ *  $Id: panelconfiguracionpacs.cpp 4386 2011-11-07 13:49:39Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -490,7 +490,7 @@ namespace GNC {
 						{
 						}
 						if(pNetwork != NULL) {
-							as.SetTimeout(5);
+							as.SetTimeout(10);
 							pNetwork->InitializeNetwork(as.GetTimeout());
 							cond = pNetwork->ConnectAssociation(&as, pdu);
 							if (cond.good()) {
@@ -546,7 +546,7 @@ namespace GNC {
 		PanelConfiguracionPACS::PanelConfiguracionPACS(wxWindow* pParent,IDialogoConfiguracion* pDialogo): PanelConfiguracionPACSBase(pParent), IPasoConfiguracion(pDialogo)
 		{
 			this->m_pTreeListPACS->AddColumn(_("Name"), 200, wxALIGN_LEFT, -1, true, false);
-			this->m_pTreeListPACS->AddColumn(_("Default"), 50, wxALIGN_LEFT, -1, true, false);
+			this->m_pTreeListPACS->AddColumn(_("Default PACS"), 70, wxALIGN_LEFT, -1, true, false);
 			Recargar();
 			
 			m_pHelpBitmap->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoHelp());
