@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelconfiguracionpermisos.cpp 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: panelconfiguracionpermisos.cpp 3901 2011-06-29 11:20:49Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -18,7 +18,7 @@
 #include <wx/msgdlg.h>
 #include <wx/msgout.h>
 #include <wx/filename.h>
-#include <wx/confbase.h>
+#include <main/controllers/configurationcontroller.h>
 #include <wx/valtext.h>
 #include <wx/ginkgostyle/ginkgostyle.h>
 #include <wx/mstream.h>
@@ -29,7 +29,7 @@
 #include <wx/busyinfo.h>
 #include <wx/xml/xml.h>
 #include <wx/log.h>
-#include <api/internacionalizacion.h>
+
 #include <wx/tokenzr.h>
 
 #include "panelconfiguracionpermisos.h"
@@ -306,35 +306,27 @@ namespace GNC {
 
 		void PanelConfiguracionPermisos::Recargar()
 		{
-			wxConfigBase * config = wxConfigBase::Get();
+			GNC::GCS::ConfigurationController::TListGroups profiles;
+			GNC::GCS::ConfigurationController::Instance()->readGroupGeneral("/GinkgoCore/Profiles", profiles);
 
+			std::string strTmp, xml;
+			bool apply;
+			bool primero =true;
 			m_pTreeListProfiles->DeleteRoot();
 			wxTreeItemId idRoot = m_pTreeListProfiles->AddRoot(wxT("Root"));
 
-			config->SetPath(wxT("/GinkgoCore/Profiles"));
-			wxString str;
-			bool aplicar;
-			long dummy;
+			for (GNC::GCS::ConfigurationController::TListGroups::iterator it = profiles.begin(); it != profiles.end(); ++it) {
+				(*it).readStringValue("Name", strTmp);
+				wxTreeItemId idItem = m_pTreeListProfiles->AppendItem(idRoot,wxString::FromUTF8(strTmp.c_str()));
+				(*it).readBoolValue("Apply", apply, false);
+				(*it).readStringValue("XML", xml);
 
-			bool primero = true;
-
-			bool bCont = config->GetFirstGroup(str, dummy);
-			while ( bCont ) {
-				config->SetPath(str);
-				config->Read(wxT("Name"),&str);
-				wxTreeItemId idItem = m_pTreeListProfiles->AppendItem(idRoot,str);
-				std::string nombre(str.ToUTF8());
-				config->Read(wxT("XML"),&str);
-				std::string xml(str.ToUTF8());
-				config->Read(wxT("Apply"),&aplicar);
-
-				if(aplicar) {
+				if(apply) {
 					m_pTreeListProfiles->SetItemText(idItem, 1, _("Yes"));
 				} else {
 					m_pTreeListProfiles->SetItemText(idItem, 1, _("No"));
 				}
-				m_profiles.push_back(TipoProfile(nombre,xml,aplicar));
-
+				m_profiles.push_back(TipoProfile(strTmp,xml,apply));
 				if(primero) {
 					m_pTreeListProfiles->SelectItem(idItem);
 					m_pBEdit->Enable(true);
@@ -342,9 +334,6 @@ namespace GNC {
 					m_pBActive->Enable(true);
 					primero = false;
 				}
-
-				config->SetPath(wxT(".."));
-				bCont = config->GetNextGroup(str, dummy);
 			}
 		}
 
@@ -376,26 +365,17 @@ namespace GNC {
 
 		bool PanelConfiguracionPermisos::Guardar()
 		{
-			wxConfigBase * config = wxConfigBase::Get();
-			//se actualiza el fichero de configuracion
+			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Profiles");
+			GNC::GCS::ConfigurationController::TListGroups profiles;
 
-			config->DeleteGroup(wxT("/GinkgoCore/Profiles"));
-			config->SetPath(wxT("/GinkgoCore/Profiles"));
-			int i=0;
-			wxString clave;
-			wxString valor;
-			for(TipoListaProfiles::iterator it = m_profiles.begin(); it!= m_profiles.end(); it++,i++){
-				clave = wxString::Format(wxT("Profile%d/Name"),i);
-				valor = wxString::FromUTF8((*it).nombre.c_str());
-				config->Write(clave,valor);
-
-				clave = wxString::Format(wxT("Profile%d/Apply"),i);
-				config->Write(clave,(*it).aplicar);
-
-				clave = wxString::Format(wxT("Profile%d/XML"),i);
-				valor = wxString::FromUTF8((*it).xml.c_str());
-				config->Write(clave,valor);
+			for(TipoListaProfiles::iterator it = m_profiles.begin(); it!= m_profiles.end(); it++){
+				GNC::GCS::ConfigurationController::TMapValues profile;
+				profile["Name"] = (*it).nombre;
+				profile.insertBool("Apply", (*it).aplicar);
+				profile["XML"] = (*it).xml;
+				profiles.push_back(profile);
 			}
+			GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Profiles", profiles, "Profile");
 
 			return true;
 		}
@@ -427,11 +407,9 @@ namespace GNC {
 
 		void PanelConfiguracionPermisos::Importar(wxXmlNode* pNodo)
 		{
-			wxConfigBase * config = wxConfigBase::Get();
 			//se actualiza el fichero de configuracion
 
-			config->DeleteGroup(wxT("/GinkgoCore/Profiles"));
-			config->SetPath(wxT("/GinkgoCore/Profiles"));
+			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Profiles");
 
 			wxXmlNode* pProfiles = NULL;
 			for(pProfiles = pNodo->GetChildren(); pProfiles != NULL; pProfiles = pProfiles->GetNext()) {
@@ -440,9 +418,9 @@ namespace GNC {
 				}
 			}
 			if(pProfiles != NULL) {
-				int i=0;
 				wxString clave;
-				for(wxXmlNode* pTag=pProfiles->GetChildren(); pTag!=NULL; pTag = pTag->GetNext(),i++) {
+				GNC::GCS::ConfigurationController::TListGroups profiles;
+				for(wxXmlNode* pTag=pProfiles->GetChildren(); pTag!=NULL; pTag = pTag->GetNext()) {
 					wxString nombre;
 					pTag->GetPropVal(wxT("Name"),&nombre);
 					wxString xml;
@@ -451,16 +429,13 @@ namespace GNC {
 					pTag->GetPropVal(wxT("Apply"),&aplicar);
 					wxString puerto;
 
-					clave = wxString::Format(wxT("Profile%d/Name"),i);
-					config->Write(clave,nombre);
-
-					clave = wxString::Format(wxT("Profile%d/XML"),i);
-					config->Write(clave,xml);
-
-					bool bAplicar = aplicar == wxT("Yes");
-					clave = wxString::Format(wxT("Profile%d/Apply"),i);
-					config->Write(clave,bAplicar);
+					GNC::GCS::ConfigurationController::TMapValues profile;
+					profile["Name"] = nombre.ToUTF8();
+					profile["XML"] = xml.ToUTF8();
+					profile.insertBool("Apply", aplicar == wxT("Yes"));
+					profiles.push_back(profile);
 				}
+				GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Profiles", profiles, "Profile");
 			}
 		}
 
