@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionubicaciones.cpp 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: panelconfiguracionubicaciones.cpp 4044 2011-07-22 12:21:07Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -67,7 +67,7 @@ namespace Ubicaciones {
 		}
 		virtual int GetNumberCols()
 		{
-			return 3;
+			return 6;
 		}
 
 		int FindUbicacion(const std::string& title)
@@ -81,7 +81,7 @@ namespace Ubicaciones {
 			return pos;
 		}
 
-		virtual bool AddUbicacion(const std::string& title, const std::string& path, const std::string& desc)
+		virtual bool AddUbicacion(const std::string& title, const std::string& path, const std::string& desc, bool monitorize, bool cleanbefore, bool cleanafter)
 		{
 
 			if (title.empty() || path.empty()) {
@@ -93,7 +93,7 @@ namespace Ubicaciones {
 				return false;
 			}
 
-			m_Ubicaciones[title] = GIL::Ubicacion(title, path, desc);
+			m_Ubicaciones[title] = GIL::Ubicacion(title, path, desc, monitorize, cleanbefore, cleanafter);
 			wxGridTableMessage msg1( this, wxGRIDTABLE_NOTIFY_ROWS_INSERTED,
 	                        m_Ubicaciones.size() - 1, 1);
 			GetView()->ProcessTableMessage( msg1 );
@@ -147,7 +147,7 @@ namespace Ubicaciones {
 			}
 		}
 
-		virtual void UpdateUbicacion(int pos, const std::string& title, const std::string& path, const std::string& desc)
+		virtual void UpdateUbicacion(int pos, const std::string& title, const std::string& path, const std::string& desc, bool monitorize, bool cleanbefore, bool cleanafter)
 		{
 			if (pos >= 0 && pos < (int)m_Ubicaciones.size()) {
 				GNC::GCS::IEntorno::MapaUbicaciones::iterator it;
@@ -159,12 +159,12 @@ namespace Ubicaciones {
 						m_Ubicaciones.erase(  it );
 					/*	wxGridTableMessage msg1( this, wxGRIDTABLE_NOTIFY_ROWS_DELETED, pos, 1);
 						GetView()->ProcessTableMessage( msg1 );*/
-						m_Ubicaciones[title] = GIL::Ubicacion(title, path, desc);
+						m_Ubicaciones[title] = GIL::Ubicacion(title, path, desc, monitorize, cleanbefore, cleanafter);
 						/*wxGridTableMessage msg2( this, wxGRIDTABLE_NOTIFY_ROWS_INSERTED,
 	                        m_Ubicaciones.size() - 1, 1);
 						GetView()->ProcessTableMessage( msg1 );*/
 					} else {
-						d.Update(path, desc);
+						d.Update(path, desc, monitorize, cleanbefore, cleanafter);
 					}
 					
 					wxGridTableMessage msg( this, wxGRIDTABLE_REQUEST_VIEW_GET_VALUES,
@@ -213,12 +213,16 @@ namespace Ubicaciones {
 			{
 				case 0:
 					return wxString::FromUTF8( u.Titulo.c_str() );
-
 				case 1:
-					return wxString::FromUTF8( u.Ruta.c_str() );
-
+					return u.Monitorize ? _("Yes") : _("No");
 				case 2:
-					return wxString::FromUTF8( u.Descripcion.c_str() );
+					return u.CleanBefore ? _("Yes") : _("No");
+				case 3:
+					return u.CleanAfter ? _("Yes") : _("No");		
+				case 4:
+					return wxString::FromUTF8( u.Descripcion.c_str() );			
+				case 5:
+					return wxString::FromUTF8( u.Ruta.c_str() );
 			}
 
 			return wxEmptyString;
@@ -233,12 +237,16 @@ namespace Ubicaciones {
 			{
 				case 0:
 					return _("Title");
-
 				case 1:
-					return _("Path");
-
+					return _("Monitorize");
 				case 2:
+					return _("Clean before");
+				case 3:
+					return _("Clean after");
+				case 4:
 					return _("Description");
+				case 5:
+					return _("Path");
 			}
 
 			wxFAIL_MSG(_("unknown column"));
@@ -259,6 +267,15 @@ namespace Ubicaciones {
 
 				case 2:
 					return wxGRID_VALUE_STRING;
+
+				case 3:
+					return wxGRID_VALUE_STRING;
+
+				case 4:
+					return wxGRID_VALUE_STRING;
+
+				case 5:
+					return wxGRID_VALUE_STRING;
 			}
 
 			wxFAIL_MSG(_("unknown column"));
@@ -299,6 +316,9 @@ namespace GNC {
 				m_pTETitle->SetValue( wxString::FromUTF8( m_Ubicacion.Titulo.c_str() ) );
 				m_pTELocation->SetValue( wxString::FromUTF8( m_Ubicacion.Ruta.c_str() ) );
 				m_pTEDesc->SetValue( wxString::FromUTF8( m_Ubicacion.Descripcion.c_str() ) );
+				m_pMonitorize->SetValue(m_Ubicacion.Monitorize);
+				m_pCleanBefore->SetValue(m_Ubicacion.CleanBefore);
+				m_pCleanAfter->SetValue(m_Ubicacion.CleanAfter);
 
 			}
 
@@ -355,12 +375,18 @@ namespace GNC {
 						m_Ubicacion = GIL::Ubicacion(
 							title,
 							std::string(m_pTELocation->GetValue().ToUTF8()),
-							std::string(m_pTEDesc->GetValue().ToUTF8()) );
+							std::string(m_pTEDesc->GetValue().ToUTF8()),
+							m_pMonitorize->GetValue(),
+							m_pCleanBefore->GetValue(),
+							m_pCleanAfter->GetValue());
 					}
 					else {
 						m_Ubicacion.Update(
 							std::string(m_pTELocation->GetValue().ToUTF8()),
-							std::string(m_pTEDesc->GetValue().ToUTF8()));
+							std::string(m_pTEDesc->GetValue().ToUTF8()),
+							m_pMonitorize->GetValue(),
+							m_pCleanBefore->GetValue(),
+							m_pCleanAfter->GetValue());
 						m_Ubicacion.Titulo = title;
 					}
 
@@ -401,6 +427,7 @@ namespace GNC {
 			m_pGridUbicaciones->Connect(wxEVT_GRID_RANGE_SELECT, wxGridRangeSelectEventHandler(PanelConfiguracionUbicaciones::OnGridSelectionChanged), NULL, this);
 			m_pGridUbicaciones->Connect(wxEVT_GRID_CELL_LEFT_DCLICK, wxGridEventHandler(PanelConfiguracionUbicaciones::OnGridDClick), NULL, this);
 			Recargar();
+			m_pUbicaciones->Layout();
 			Layout();
 			AutoSizeGrid();
 			m_pGridUbicaciones->EnableDragColSize(true);
@@ -422,10 +449,14 @@ namespace GNC {
 			m_pUbicacionesGridTable->Clear();
 			for (GNC::GCS::ConfigurationController::TListGroups::iterator it = locations.begin(); it != locations.end(); ++it) {
 				std::string title, path, descr;
+				bool monitorize, cleanbefore, cleanafter;
 				(*it).readStringValue("Title", title);
 				(*it).readStringValue("Path", path);
 				(*it).readStringValue("Description", descr);
-				m_pUbicacionesGridTable->AddUbicacion(title, path, descr);
+				(*it).readBoolValue("Monitorize", monitorize, false);
+				(*it).readBoolValue("CleanBefore", cleanbefore, false);
+				(*it).readBoolValue("CleanAfter", cleanafter, false);
+				m_pUbicacionesGridTable->AddUbicacion(title, path, descr, monitorize, cleanbefore, cleanafter);
 			}
 		}
 
@@ -467,6 +498,9 @@ namespace GNC {
 				location["Title"] = u.Titulo;
 				location["Path"] = u.Ruta;
 				location["Description"] = u.Descripcion;
+				location.insertBool("Monitorize", u.Monitorize);
+				location.insertBool("CleanBefore", u.CleanBefore);
+				location.insertBool("CleanAfter", u.CleanAfter);
 				locations.push_back(location);
 			}
 			GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Locations", locations, "Location");
@@ -495,6 +529,9 @@ namespace GNC {
 				pTag->AddProperty(wxT("Title"),wxString::FromUTF8(u.Titulo.c_str()));
 				pTag->AddProperty(wxT("Path"),wxString::FromUTF8(u.Ruta.c_str()));
 				pTag->AddProperty(wxT("Description"),wxString::FromUTF8(u.Descripcion.c_str()));
+				pTag->AddProperty(wxT("Monitorize"),u.Monitorize?wxT("true"):wxT("false"));
+				pTag->AddProperty(wxT("CleanBefore"),u.CleanBefore?wxT("true"):wxT("false"));
+				pTag->AddProperty(wxT("CleanAfter"),u.CleanAfter?wxT("true"):wxT("false"));
 			}
 		}
 
@@ -524,14 +561,23 @@ namespace GNC {
 					pTag->GetPropVal(wxT("Path"),&ruta);
 					wxString descripcion;
 					pTag->GetPropVal(wxT("Description"),&descripcion);
+					wxString monitorize;
+					pTag->GetPropVal(wxT("Monitorize"),&monitorize);
+					wxString cleanbefore;
+					pTag->GetPropVal(wxT("CleanBefore"),&cleanbefore);
+					wxString cleanafter;
+					pTag->GetPropVal(wxT("CleanAfter"),&cleanafter);
 
-					GIL::Ubicacion u (std::string(titulo.ToUTF8()), std::string(ruta.ToUTF8()), std::string(descripcion.ToUTF8()));
+					GIL::Ubicacion u (std::string(titulo.ToUTF8()), std::string(ruta.ToUTF8()), std::string(descripcion.ToUTF8()), monitorize==wxT("true"), cleanbefore == wxT("true"), cleanafter == wxT("true"));
 					mapa[u.Titulo] = u;
 
 					GNC::GCS::ConfigurationController::TMapValues location;
 					location["Title"] = u.Titulo;
 					location["Path"] = u.Ruta;
 					location["Description"] = u.Descripcion;
+					location.insertBool("Monitorize",u.Monitorize);
+					location.insertBool("CleanBefore", u.CleanBefore);
+					location.insertBool("CleanBefore", u.CleanAfter);
 					locations.push_back(location);
 				}
 				GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Locations", locations, "Location");
@@ -580,7 +626,7 @@ namespace GNC {
 			dlg.ShowModal();
 			if (dlg.m_Ok) {
 				GIL::Ubicacion& u = dlg.m_Ubicacion;
-				m_pUbicacionesGridTable->AddUbicacion(u.Titulo, u.Ruta, u.Descripcion);
+				m_pUbicacionesGridTable->AddUbicacion(u.Titulo, u.Ruta, u.Descripcion, u.Monitorize, u.CleanBefore, u.CleanAfter);
 				OnPropiedadCambiada();
 			}
 		}
@@ -596,7 +642,7 @@ namespace GNC {
 					DialogoAddLocationDialog dlg(this, m_pUbicacionesGridTable, u, false);
 					dlg.ShowModal();
 					if (dlg.m_Ok) {
-						m_pUbicacionesGridTable->UpdateUbicacion(sel, dlg.m_Ubicacion.Titulo, dlg.m_Ubicacion.Ruta, dlg.m_Ubicacion.Descripcion);
+						m_pUbicacionesGridTable->UpdateUbicacion(sel, dlg.m_Ubicacion.Titulo, dlg.m_Ubicacion.Ruta, dlg.m_Ubicacion.Descripcion, dlg.m_Ubicacion.Monitorize, dlg.m_Ubicacion.CleanBefore, dlg.m_Ubicacion.CleanAfter);
 						OnPropiedadCambiada();
 					}
 				}
@@ -630,7 +676,7 @@ namespace GNC {
 
 		void PanelConfiguracionUbicaciones::AutoSizeGrid()
 		{
-			wxSize s = m_pGridUbicaciones->GetClientSize();
+		/*	wxSize s = m_pGridUbicaciones->GetClientSize();
 
 			float prop = 1.0f / ( (float)m_pGridUbicaciones->GetNumberCols() );
 
@@ -646,6 +692,9 @@ namespace GNC {
 			if ( i < m_pGridUbicaciones->GetNumberCols()) {
 				m_pGridUbicaciones->SetColSize(i, cw - aw );
 			}
+		*/	
+			m_pGridUbicaciones->AutoSize();
+			m_pGridUbicaciones->AutoSizeColumns(true);
 			m_pGridUbicaciones->Refresh();
 		}
 	//endregion
