@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: dicombrowsercomponent.cpp 3893 2011-06-21 13:01:56Z tovar $
+*  $Id: dicombrowsercomponent.cpp 4368 2011-11-04 11:12:33Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -256,7 +256,12 @@ namespace GNC {
 					wxString AccNumber = wxString::FromUTF8(e.GetAccNumber().c_str());
 
 					//columnas
-					wxTreeItemId estudioTreeId = m_pTreeListIzq->AppendItem(pacienteTreeId, descripcionEstudio);
+					wxTreeItemId estudioTreeId;
+					if (descripcionEstudio.IsEmpty()) {
+						estudioTreeId = m_pTreeListIzq->AppendItem(pacienteTreeId, _("Untitled"));
+					} else {
+						estudioTreeId = m_pTreeListIzq->AppendItem(pacienteTreeId, descripcionEstudio);
+					}
 					m_pTreeListIzq->SetItemText(estudioTreeId, COLUMNA_DCMDIR_MODALIDAD, modalidadEstudio);
 					if(fecha.IsValid()){
 						m_pTreeListIzq->SetItemText(estudioTreeId, COLUMNA_DCMDIR_FECHA, wxString(
@@ -285,7 +290,12 @@ namespace GNC {
 							fechaSerie.ParseFormat(wxString::FromUTF8(e.GetFecha().c_str()).GetData(), wxT("%Y-%m-%d"), wxDefaultDateTime);
 						}
 
-						wxTreeItemId serieTreeId = m_pTreeListIzq->AppendItem(estudioTreeId, descripcionSerie);
+						wxTreeItemId serieTreeId;
+						if (descripcionSerie.IsEmpty()) {
+							serieTreeId = m_pTreeListIzq->AppendItem(estudioTreeId, _("Untitled"));
+						} else {
+							serieTreeId = m_pTreeListIzq->AppendItem(estudioTreeId, descripcionSerie);
+						}
 
 						m_pTreeListIzq->SetItemText(serieTreeId, COLUMNA_DCMDIR_MODALIDAD, tipoSerie);
 						if(fechaSerie.IsValid()){
@@ -315,7 +325,8 @@ namespace GNC {
 				}
 			}
 
-			m_pTreeListIzq->Expand(topTreeId);
+			m_pTreeListIzq->ExpandAll(topTreeId);
+			m_pTreeListDer->ExpandAll(m_pTreeListDer->GetRootItem());
 
 			m_pTreeListIzq->SetAutoLayout(true);
 			m_pTreeListDer->SetAutoLayout(true);
@@ -413,6 +424,7 @@ namespace GNC {
 			wxArrayTreeItemIds idsSeleccionados;
 			HelperGetAllPatients(m_pTreeListIzq,idsSeleccionados);
 			AddItemsSeleccionados(idsSeleccionados);
+			m_pTreeListDer->ExpandAll(m_pTreeListDer->GetRootItem());
 		}
 
 		void DicomBrowserComponent::OnDicomDirDerDelAll(wxCommandEvent& )
