@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parametrosprincipales.cpp 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: parametrosprincipales.cpp 4404 2011-11-15 09:41:03Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -85,14 +85,6 @@ namespace GNC {
 			GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Exportacion", "ValorDefectoAnonimizacion", strTmp);
 			m_valorAnonimizado = wxString::FromUTF8(strTmp.c_str());
 
-			//por defecto el check de configuracion esta checkeado
-			wxCommandEvent evt;
-			OnCheckConfiguracion(evt);
-
-			m_pPanelCampos->Enable(false);
-			m_pPanelCampos->Refresh(false);
-			m_pListaAtributos->Refresh(false);
-
 			//diagnosticos
 			std::vector<std::string> listaDiagnosticos = m_pDatosPersistentes->m_pVista->GetRutasDiagnosticos();
 			if(listaDiagnosticos.size()==0) {
@@ -213,11 +205,6 @@ namespace GNC {
 			}
 		}
 
-		void ParametrosPrincipales::OnCheckAnonimizar(wxCommandEvent &){
-			m_pPanelCampos->Enable(m_pCheckAnonimizar->GetValue());
-			Layout();
-		}
-
 		void ParametrosPrincipales::OnCheckNombreApellidos(wxCommandEvent &){
 			//se anonimiza 0010|0010 (nombre del paciente)
 			std::string clave("0010|0010");
@@ -236,6 +223,13 @@ namespace GNC {
 			Anonimizar(clave,m_pCheckInstituciones->IsChecked());
 		}
 
+		void ParametrosPrincipales::OnCheckPhysician(wxCommandEvent &)
+		{
+			//referring physician name
+			std::string clave("0008|0090");
+			Anonimizar(clave,m_pReferringPhysician->IsChecked());
+		}
+
 		void ParametrosPrincipales::OnCheckComentarios(wxCommandEvent &){
 			//descripcion del estudio, serie e imagenes
 			//estudio
@@ -255,31 +249,6 @@ namespace GNC {
 			}
 		}
 
-		void ParametrosPrincipales::OnCheckConfiguracion(wxCommandEvent &){
-			//se cargan los tags y se anonimizan...
-			GNC::GCS::ConfigurationController::TListGroups tags;
-			GNC::GCS::ConfigurationController::Instance()->readGroupGeneral("/GinkgoCore/Exportacion/TagsAnonimizacion", tags);
-			for (GNC::GCS::ConfigurationController::TListGroups::iterator it = tags.begin(); it != tags.end(); ++it) {
-				std::string group, element;
-				(*it).readStringValue("Grupo",group);
-				(*it).readStringValue("Elemento",element);
-				std::ostringstream ostr;
-				ostr << "group" << "|" << element;
-				std::string clave = ostr.str();
-
-				if(clave == std::string("0010|0010")){
-					m_pCheckNombrePaciente->SetValue(m_pCheckConfiguracion->IsChecked());
-				}else if(clave == std::string("0010|0020")){
-					m_pCheckIdPaciente->SetValue(m_pCheckConfiguracion->IsChecked());
-				} else if(clave == std::string("0008|0080")){
-					m_pCheckIdPaciente->SetValue(m_pCheckInstituciones->IsChecked());
-				}
-
-				Anonimizar(clave,m_pCheckConfiguracion->IsChecked());
-			}
-
-		}
-
 		void ParametrosPrincipales::Anonimizar(std::string& clave, bool anonimizar)
 		{
 			wxString value = m_valorAnonimizado;
@@ -309,37 +278,24 @@ namespace GNC {
 		}
 
 		void ParametrosPrincipales::OnPropertyChanged(wxPropertyGridEvent& event) {
-			if(m_pCheckAnonimizar->IsChecked()){
+			/*if(m_pCheckAnonimizar->IsChecked()){*/
 				wxPGProperty* selected= event.GetProperty();
 				m_pListaAtributos->SetPropertyCell(selected->GetId(),0,selected->GetLabel(),wxNullBitmap,*wxWHITE,*wxRED);
 				m_pListaAtributos->SetPropertyCell(selected->GetId(),1,selected->GetValue(),wxNullBitmap,*wxWHITE,*wxRED);
-			} else {
+			/*} else {
 				std::string clave(event.GetProperty()->GetHelpString().ToUTF8());
 				Anonimizar(clave,false);
-			}
+			}*/
 		}
 
 		void ParametrosPrincipales::OnPropertyDobleClick(wxPropertyGridEvent& event){
-			if(m_pCheckAnonimizar->IsChecked()){
+			//if(m_pCheckAnonimizar->IsChecked()){
 				std::string clave(event.GetProperty()->GetHelpString().ToUTF8());
 				Anonimizar(clave,!event.GetProperty()->IsFlagSet(wxPG_PROP_MODIFIED));
-			} 
+			//} 
 		}
 
 //region "Metodos heredados de Ipasowizard"
-
-		void ParametrosPrincipales::Attach(wxSizer *sizer){
-			Show(true);
-			sizer->Add(this,10, wxEXPAND);
-			this->GetParent()->Layout();
-		}
-
-		void ParametrosPrincipales::Detach(wxSizer *sizer){
-			Hide();
-			sizer->Detach(this);
-			sizer->GetContainingWindow()->Layout();
-		}
-
 		std::string ParametrosPrincipales::GetTitle(){
 			return _Std("DICOM Export");
 		}
