@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: parametrosprincipales.h 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: parametrosprincipales.h 4333 2011-10-25 12:01:02Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -51,8 +51,6 @@ namespace GNC {
 				void GetTagsAnonimizados(GIL::DICOM::TipoJerarquia & base);
 
 			protected:
-				void OnCheckAnonimizar(wxCommandEvent &event);
-
 				void OnCheckNombreApellidos(wxCommandEvent &event);
 
 				void OnCheckIdPaciente(wxCommandEvent &event);
@@ -61,8 +59,6 @@ namespace GNC {
 
 				void OnCheckComentarios(wxCommandEvent &event);
 
-				void OnCheckConfiguracion(wxCommandEvent &event);
-
 				void Anonimizar(std::string& clave, bool anonimizar);
 
 				void OnPropertyChanged(wxPropertyGridEvent& event);
