@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelhistorial2.cpp 4044 2011-07-22 12:21:07Z tovar $
+ *  $Id: panelhistorial2.cpp 4367 2011-11-04 10:58:44Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -98,8 +98,8 @@ namespace GNC {
 			INodoHistorial(NULL,"")
 		{
 			m_pTimerRecargar = new TimerRecargarHistorial(this);
-			m_pacienteActual = _Std("All");
-			m_modalidadActual = _Std("All");
+			m_pacienteActual = _Std("All patients");
+			m_modalidadActual = _Std("All modalities");
 			m_fromActual = wxDateTime::Now();
 			m_toActual = wxInvalidDateTime;
 			//titulo
@@ -186,8 +186,9 @@ namespace GNC {
 
 			m_pComboBoxPaciente->Clear();
 
-			m_pComboBoxPaciente->AppendString(_("All"));
-			if (m_pacienteActual == _Std("All")) {
+			m_pComboBoxPaciente->Append(_("All patients"), GinkgoResourcesManager::PanelHistorial::GetIcoAllPatients());
+
+			if (m_pacienteActual == _Std("All patients")) {
 				m_pComboBoxPaciente->Select(0);
 			}
 			m_pComboBoxPaciente->AppendString(wxT("-----------------------------"));
@@ -216,8 +217,8 @@ namespace GNC {
 
 			//combo box modalidades
 			m_pComboModalidad->Clear();
-			m_pComboModalidad->AppendString(_("All"));
-			if (m_modalidadActual == _Std("All")) {
+			m_pComboModalidad->AppendString(_("All modalities"));
+			if (m_modalidadActual == _Std("All modalities")) {
 				m_pComboModalidad->Select(0);
 			}
 			m_pComboModalidad->AppendString(wxT("-----------------------------"));
@@ -578,8 +579,8 @@ namespace GNC {
 
 		void PanelHistorial2::ForzarCargarTodos()
 		{
-			m_pComboBoxPaciente->SetSelection(m_pComboBoxPaciente->FindString(_("All")) );
-			m_pacienteActual = _Std("All");
+			m_pComboBoxPaciente->SetSelection(m_pComboBoxPaciente->FindString(_("All patients")) );
+			m_pacienteActual = _Std("All patients");
 			//se eliminan todos los estudios que no están abiertos
 			Freeze();
 			//se eliminan los nodos que ya no van a valer
@@ -748,7 +749,7 @@ namespace GNC {
 					}
 				} else if (m_pComboBoxPaciente->GetSelection() == 0) {
 					wxString stringSeleccionado = m_pComboBoxPaciente->GetString(m_pComboBoxPaciente->GetSelection());
-					if (stringSeleccionado == _("All") && m_pacienteActual != _Std("All")) {
+					if (stringSeleccionado == _("All patients") && m_pacienteActual != _Std("All patients")) {
 						m_pacienteActual = std::string(stringSeleccionado.ToUTF8());
 						cambio = true;
 					}
@@ -765,17 +766,7 @@ namespace GNC {
 					}
 				}
 			}
-			/*if (!m_fromActual.IsValid() || m_fromActual != m_pDatePickerFrom->GetValue()) {
-					m_fromActual = m_pDatePickerFrom->GetValue();
-					cambio = true;
-				}
-				if (m_fromActual.IsValid()) {
-					m_fromActual = wxInvalidDateTime;
-					cambio = true;
-				}
-
-			*/
-
+			
 			wxDateTime newFechaDesde = wxInvalidDateTime, newFechaHasta = wxInvalidDateTime;
 			std::string timeFrom(""), timeTo("");
 			if (m_pComboDate->GetValue() == _("Between:")) {
@@ -848,7 +839,7 @@ namespace GNC {
 				//#1 eliminamos los estudios de pacientes que sobran
 				{
 					std::list<GNC::GUI::INodoHistorial*> listaEliminar;
-					bool todosLosPacientes = m_pacienteActual == _Std("All");
+					bool todosLosPacientes = m_pacienteActual == _Std("All patients");
 					if (!todosLosPacientes) {
 						for(TMapaHijos::iterator it=m_mapaHijos.begin(); it!= m_mapaHijos.end(); it++) {
 							if (ignoreActual) {
@@ -869,7 +860,7 @@ namespace GNC {
 				//#2 eliminamos las series que sobran por modalidad
 				{
 					std::list<GNC::GUI::INodoHistorial*> listaEliminar;
-					bool todosLasModalidades = m_modalidadActual == _Std("All");
+					bool todosLasModalidades = m_modalidadActual == _Std("All modalities");
 					if (!todosLasModalidades) {
 						for (TMapaAbribles::iterator it = m_mapaUIDsAbribles.begin(); it != m_mapaUIDsAbribles.end(); ++it) {
 							PanelSerie* pPanel = (*it).second->GetSeries((*it).first);
@@ -977,9 +968,9 @@ namespace GNC {
 			wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 1, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
 			menu.Connect(1,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelHistorial2::OnLimpiarHistorial),NULL,this);
 			#ifdef __WXMSW__
-			pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+			pMenuEliminar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
 			#else
-			pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+			pMenuEliminar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
 			#endif
 			menu.Append(pMenuEliminar);
 			if(m_mapaHijos.size() == 0) {
@@ -1089,7 +1080,7 @@ namespace GNC {
 		void PanelHistorial2::PreProcesarEvento(GNC::GCS::Eventos::IEvento * evt, GNC::GCS::IControladorEventos::TipoListaPunterosEventos& lista)
 		{
 			if (evt == NULL) {
-				std::cerr << "Error: Evento nulo" << std::endl;
+				std::cerr << "Error: null event" << std::endl;
 				return;
 			}
 			switch (evt->GetCodigoEvento()) {
@@ -1253,7 +1244,7 @@ namespace GNC {
 						GNC::GUI::Eventos::EventoAddModeloHistorial* pEvtAdd = dynamic_cast<GNC::GUI::Eventos::EventoAddModeloHistorial*>(evt);
 						if(pEvtAdd != NULL) {
 
-							bool todos = m_pacienteActual == _Std("All");
+							bool todos = m_pacienteActual == _Std("All patients");
 							GNC::GCS::ControladorHistorial::ListaModelosDCM listaPacienteActual;
 							for(GNC::GCS::ControladorHistorial::ListaModelosDCM::iterator it = pEvtAdd->GetListaModelos()->begin(); it!= pEvtAdd->GetListaModelos()->end(); it++) {
 								if (todos || (*it).m_idPaciente == m_pacienteActual || pEvtAdd->GetAbrirDespuesDeCargar()) {
