@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelserie.cpp 4121 2011-09-02 10:30:20Z tovar $
+ *  $Id: panelserie.cpp 4334 2011-10-26 07:00:01Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -346,8 +346,8 @@ namespace GNC {
 			wxMenuItem* pMenuLimpiar = new wxMenuItem(&menu, 6, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
 			menu.Connect(6,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnLimpiarHistorial),NULL,this);
 			#ifdef __WXMSW__
-			pMenuLimpiar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			pMenuLimpiar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+			pMenuLimpiar->SetBitmaps(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
+			pMenuLimpiar->SetBitmap(GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll());
 			#endif
 			menu.Append(pMenuLimpiar);
 
