@@ -16,6 +16,7 @@
 
 #include <main/controllers/controladorenviohl7.h>
 #include <main/controllers/controladorbbddhl7.h>
+#include <main/controllers/configurationcontroller.h>
 
 #include <resources/ginkgoresourcemanager.h>
 #define LOGGER "VentanaControlHL7"
@@ -304,10 +305,11 @@ namespace GNC {
 		{
 			m_pBArrancarParar->Disable();
 			if (m_pBArrancarParar->GetLabel() == _("Stop") ) {
-
+				GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/HCE", "HL7MonitorEnabled", false);
 				GIL::HL7::ControladorEnvioHl7::FreeInstance();
 			}
 			else {
+				GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/HCE", "HL7MonitorEnabled", true);
 				GIL::HL7::ControladorEnvioHl7::Arrancar();
 			}
 			ActualizarEstadoControlador();
