@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: pasoperfilimportacion.cpp 3920 2011-07-06 06:12:31Z tovar $
+ *  $Id: pasoperfilimportacion.cpp 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -59,18 +59,6 @@ namespace GNC {
 
 //region "Metodos heredados de Ipasowizard"
 
-		void PasoPefilImportacion::Attach(wxSizer *sizer){
-			Show(true);
-			sizer->Add(this,10, wxEXPAND);
-			this->GetParent()->Layout();
-		}
-
-		void PasoPefilImportacion::Detach(wxSizer *sizer){
-			Hide();
-			sizer->Detach(this);
-			sizer->GetContainingWindow()->Layout();
-		}
-
 		std::string PasoPefilImportacion::GetTitle(){
 			return _Std("Selecting Import Profile");
 		}
