@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: pasoperfilimportacion.h 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: pasoperfilimportacion.h 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -46,10 +46,6 @@ namespace GNC {
 				GNC::GCS::IControladorModulo* m_pControladorModulo;
 
 			//region "Metodos heredados de IPasoWizard"
-				virtual void Attach(wxSizer *sizer);
-
-				virtual void Detach(wxSizer *sizer);
-
 				virtual std::string GetTitle();
 
 				virtual std::string GetSubTitle();
