@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: selectimagesimportation.cpp 4076 2011-08-11 06:37:52Z carlos $
+ *  $Id: selectimagesimportation.cpp 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -167,7 +167,7 @@ namespace GNC {
 
 		////////////////////////////////////////////////////////
 
-		SelectImagesImportation::SelectImagesImportation(wxWindow* pParent,std::string& dirTemp, IWizard* pWizard, GnkPtr<GIL::IModeloIntegracion>& pModeloIntegracion, const std::list<std::string>& fileSpecs, const wxString& defaultFilter) : SelectImagesImportationBase(pParent), IPasoWizard(pWizard)
+		SelectImagesImportation::SelectImagesImportation(wxWindow* pParent, const std::string& dirTemp, IWizard* pWizard, GnkPtr<GIL::IModeloIntegracion>& pModeloIntegracion, const std::list<std::string>& fileSpecs, const wxString& defaultFilter) : SelectImagesImportationBase(pParent), IPasoWizard(pWizard)
 		{			
 			SetScrollbars(10, 10, 50, 50, 0, 0, false);
 			AdjustScrollbars();
@@ -602,7 +602,8 @@ namespace GNC {
 
 //region "Metodos heredados de Ipasowizard"
 
-		void SelectImagesImportation::Attach(wxSizer *sizer){
+		bool SelectImagesImportation::Attach()
+		{
 			if (m_firstAttach) {
 				//maybe an ubication, maybe a normal path...
 				std::string lastLocation;
@@ -629,16 +630,14 @@ namespace GNC {
 			if (pUbicacion != NULL && pUbicacion->Monitorize) {
 				m_pTimerDirectory->Start(100,true);
 			}
-			Show(true);
-			sizer->Add(this, 1, wxEXPAND);
-			this->GetParent()->Layout();
+			
+			return true;
 		}
 
-		void SelectImagesImportation::Detach(wxSizer *sizer){
+		bool SelectImagesImportation::Detach()
+		{
 			m_pTimerDirectory->Stop();
-			Hide();
-			sizer->Detach(this);
-			sizer->GetContainingWindow()->Layout();
+			return true;
 		}
 
 		std::string SelectImagesImportation::GetTitle(){
@@ -654,7 +653,7 @@ namespace GNC {
 		}
 
 		bool SelectImagesImportation::Anterior(){
-			return false;
+			return true;
 		}
 
 		bool SelectImagesImportation::Cancelar(){
