@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: ventanaprincipal.cpp 4168 2011-09-21 09:14:16Z tovar $
+ *  $Id: ventanaprincipal.cpp 4406 2011-11-16 09:53:14Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -52,10 +52,10 @@
 #include <main/gui/acquisition/dialogoadquisicion.h>
 #include <main/gui/export/wxwizardexportacionginkgo.h>
 #include <main/gui/history/panelhistorial2.h>
-#include <main/gui/paneltags/paneltags.h>
 #include <main/gui/progress/statusbarprogreso.h>
 #include <main/gui/configuration/dialogoconfiguracion.h>
 #include <main/gui/pacsupload/wxwizarduploadpacs.h>
+#include <main/gui/dicomdirexport/wxwizarddicomdirexport.h>
 #include <main/gui/hl7controlwindow/ventanacontrolhl7.h>
 #include <main/gui/logcontrolwindow/ventanacontrollogs.h>
 #include <main/gui/startup/startupview.h>
@@ -124,6 +124,7 @@
 #define ID_PRIMER_FILTRO 1080
 #define ID_EXTENSIONS_SUPPORT 1081
 #define ID_START_PAGE 1082
+#define ID_DICOMDIR_EXPORT 1083
 
 
 EventoProgreso::EventoProgreso(TipoProgreso tipo, long threadId)
@@ -671,7 +672,7 @@ void VentanaPrincipal::OnOnlineSupport(wxCommandEvent& /*event*/)
 
 void VentanaPrincipal::OnExtensionsSupport(wxCommandEvent& /*event*/)
 {
-	GNC::GCS::Permisos::EstadoPermiso updates = GNC::GCS::ControladorPermisos::Instance()->Get("core.help","extensions_support");
+	GNC::GCS::Permisos::EstadoPermiso updates = GNC::GCS::ControladorPermisos::Instance()->Get("core.help","extensions_support_1");
 	wxString urlSupport = wxString::FromUTF8(updates.ObtenerValor<std::string>().c_str());
 	if (urlSupport != wxEmptyString) {
 		wxLaunchDefaultBrowser(urlSupport);
@@ -866,6 +867,12 @@ void VentanaPrincipal::OnExportar(wxCommandEvent& WXUNUSED(event))
 	adWiz.ShowModal();
 }
 
+void VentanaPrincipal::OnDicomDirExport( wxCommandEvent& WXUNUSED(event))
+{
+	GNC::GUI::wxWizardDicomDirExport adWiz(this);
+	adWiz.ShowModal();
+}
+
 /* Evento de exportado de un subir al pacs */
 void VentanaPrincipal::OnSubirPACS(wxCommandEvent& )
 {
@@ -1428,24 +1435,6 @@ void VentanaPrincipal::EliminarVentana(wxWindow *WXUNUSED(pVentana))
 
 void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &) 
 {	
-	//esto esta aqui porque hasta este punto no esta registrada la herramienta...
-	//panel tags
-	GNC::GCS::IHerramientaPanelTags* pHerramienta = GNC::ControladorHerramientas::Instance()->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaPanelTags>(GNC::GCS::IHerramientaPanelTags::ID);
-	if (pHerramienta != NULL)
-	{
-		wxString wxCaption = _("DICOM tags");
-		GNC::GUI::PanelTags* pPanelTags = new GNC::GUI::PanelTags(m_pPanelCentral);
-		pPanelTags->Connect(wxEVT_KEY_DOWN, wxKeyEventHandler(VentanaPrincipal::OnKeyDown), NULL, this);
-		AUI_NAMESPACE wxAuiPaneInfo pi(AUI_NAMESPACE wxAuiPaneInfo().Caption(wxCaption).Layer(0).Bottom().BestSize(200,-1).MinSize(200,100).Position(0).Resizable(true).Floatable(true).CloseButton(true).Show(false));
-		pi.dock_proportion=4;
-		pi.DestroyOnClose(false);
-		m_mgr.AddPane(pPanelTags, pi);
-		//se conecta con la herramienta
-		pHerramienta->SetVentanaTags(pPanelTags);
-		//
-		m_mgr.Update();
-	}
-	
 	//parameters parsing...
 	bool aceptedLicense = false;
 	bool versionParameter = false;
@@ -1582,8 +1571,17 @@ void VentanaPrincipal::EjecutarParametro(const wxString cadena, bool doLogin)
 				//si no es un xml pues sera un dicom...
 				std::list<std::string> rutas;
 				rutas.push_back(std::string(TOPATH(path.GetFullPath()) ));
-				GNC::GCS::Eventos::EventoAddFicheroHistorial* pEvt = new GNC::GCS::Eventos::EventoAddFicheroHistorial(rutas,true);
-				GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(pEvt);
+				bool esDicomDir = false;
+				if (GIL::DICOM::PACSController::Instance()->EsDICOM(rutas.front(),true,false)) {
+					esDicomDir = true;
+				}
+				if (esDicomDir) {
+					GNC::GUI::Abrir::AbrirFichero(this, &rutas);
+				}
+				else {
+					GNC::GCS::Eventos::EventoAddFicheroHistorial* pEvt = new GNC::GCS::Eventos::EventoAddFicheroHistorial(rutas,true);
+					GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(pEvt);
+				}				
 			} else {
 				//se lee el modelo
 				wxXmlDocument documento;
@@ -1676,22 +1674,45 @@ void VentanaPrincipal::EjecutarParametro(const wxString cadena, bool doLogin)
 				}
 				else if(modelo->accion == GIL::IModeloIntegracion::TA_Obtener) {
 					GADAPI::ComandoPACSParams * pParams = NULL;
-					GIL::DICOM::TipoJerarquia base;
-					//insert query/retrieve level
-					base.tags["0008|0052"] = modelo->ambitoDIMSE;
-					for (GIL::IModeloIntegracion::ListaTuplas::iterator it = modelo->Metadatos.begin(); it != modelo->Metadatos.end(); ++it)
-					{
-						if(it->codigo == std::string("DICOM")) {
-							base.tags[it->clave] = it->valor;
+					if (modelo->ambitoDIMSE.empty()) {
+						//show only acquisition form
+						if (!m_Iniciada){
+							m_Iniciada = true;
+							MostrarVentana();
 						}
-					}
-					pParams = new GADAPI::ComandoPACSParams(modelo->PACSObtencion, base);
+						std::ostringstream ostr;
+						bool first = true;
+						GIL::TListaIdentificadores& ids = modelo->Paciente.listaIdentificadores;
+						for (GIL::TListaIdentificadores::iterator itIds = ids.begin(); itIds != ids.end(); itIds++)
+						{
+							if (first) {
+								first = false;
+							}
+							else {
+								ostr << "/";
+							}
+							ostr << (*itIds).valor;
+						}
+						GNC::GUI::DialogoAdquisicion::Instance()->Show(ostr.str(), modelo->PACSObtencion);
+					} else {
+						GIL::DICOM::TipoJerarquia base;
+						//insert query/retrieve level
+						base.tags["0008|0052"] = modelo->ambitoDIMSE;
+						for (GIL::IModeloIntegracion::ListaTuplas::iterator it = modelo->Metadatos.begin(); it != modelo->Metadatos.end(); ++it)
+						{
+							if(it->codigo == std::string("DICOM")) {
+								base.tags[it->clave] = it->valor;
+							}
+						}
+						pParams = new GADAPI::ComandoPACSParams(modelo->PACSObtencion, base);
+						pParams->m_informar = true;
 
-					GADAPI::ComandoPACS* pComandoPACS = new GADAPI::ComandoPACS(pParams);
-					GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync("Descargando PACS...",pComandoPACS, NULL);
-					if (!m_Iniciada){
-						m_Iniciada = true;
-						MostrarVentana();
+						GADAPI::ComandoPACS* pComandoPACS = new GADAPI::ComandoPACS(pParams);
+						GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync("Descargando PACS...",pComandoPACS, NULL);
+						if (!m_Iniciada){
+							m_Iniciada = true;
+							MostrarVentana();
+						}
 					}
 				}
 			}
@@ -1780,17 +1801,19 @@ void VentanaPrincipal::RefrescarMenus()
 
 	{
 		//menu archivo
-		wxMenuItem* m_pMenuAdquirir = new wxMenuItem( pMenuArchivo, ID_ADQUIRIR, wxString( _("DICOM &Acquisition") ) + wxT("\tAlt+a"), _("Acquire a DICOM study"), wxITEM_NORMAL );
-		wxMenuItem* pMenuAbrirFichero = new wxMenuItem( pMenuArchivo, ID_ABRIR_FICHERO, wxString( _("Open File")) + wxT("\tAlt+f"), _("Open a DICOM file"), wxITEM_NORMAL );
-		wxMenuItem* pMenuAbrirDirectorio = new wxMenuItem( pMenuArchivo, ID_ABRIR_DIRECTORIO, wxString( _("Open Folder")) + wxT("\tAlt+d"), _("Acquire from a local folder"), wxITEM_NORMAL );
-		wxMenuItem* m_pMenuImportar = new wxMenuItem( pMenuArchivo, ID_IMPORTAR, wxString( _("&Import Images ...") ) + wxT("\tAlt+i"), _("Import Images"), wxITEM_NORMAL );
+		wxMenuItem* m_pMenuAdquirir = new wxMenuItem( pMenuArchivo, ID_ADQUIRIR, wxString( _("DICOM &acquisition") ) + wxT("\tAlt+a"), _("Acquire a DICOM study"), wxITEM_NORMAL );
+		wxMenuItem* pMenuAbrirFichero = new wxMenuItem( pMenuArchivo, ID_ABRIR_FICHERO, wxString( _("Open file")) + wxT("\tAlt+f"), _("Open a DICOM file"), wxITEM_NORMAL );
+		wxMenuItem* pMenuAbrirDirectorio = new wxMenuItem( pMenuArchivo, ID_ABRIR_DIRECTORIO, wxString( _("Open folder")) + wxT("\tAlt+d"), _("Acquire from a local folder"), wxITEM_NORMAL );
+		wxMenuItem* m_pMenuImportar = new wxMenuItem( pMenuArchivo, ID_IMPORTAR, wxString( _("&Import images...") ) + wxT("\tAlt+i"), _("Import images"), wxITEM_NORMAL );
 		wxMenuItem* m_pCerrar = new wxMenuItem( pMenuArchivo, ID_CERRAR, wxString( _("Close") ) + wxT("\tAlt+w"), _("Close current view"), wxITEM_NORMAL );
-		wxMenuItem* m_pCerrarTodas = new wxMenuItem( pMenuArchivo, ID_CERRAR_TODAS, wxString( _("Close All") ) , _("Close all views"), wxITEM_NORMAL );
-		wxMenuItem* m_pMenuGuardar = new wxMenuItem( pMenuArchivo, ID_GUARDAR, wxString( _("&Save") ) + wxT("\tAlt+g"), _("Save the active study."), wxITEM_NORMAL );
-		wxMenuItem* m_pMenuExportar = new wxMenuItem( pMenuArchivo, ID_EXPORTAR, wxString( _("Export ...") ) + wxT("\tAlt+e"), _("Export the active study to other formats"), wxITEM_NORMAL );
-		wxMenuItem* m_pMenuSubirPacs = new wxMenuItem( pMenuArchivo, ID_SUBIR_PACS, wxString( _("Send to PACS ...") ) , wxEmptyString, wxITEM_NORMAL );
-		wxMenuItem* m_pMenuImprimir = new wxMenuItem( pMenuArchivo, ID_IMPRIMIR, wxString( _("Print ...") ) + wxT("\tAlt+p"), wxEmptyString, wxITEM_NORMAL );
-		wxMenuItem* m_pMenuSalir = new wxMenuItem( pMenuArchivo, ID_SALIR, wxString( _("&Exit") ) + wxT("\tAlt+s"), _("Exit Application"), wxITEM_NORMAL );
+		wxMenuItem* m_pCerrarTodas = new wxMenuItem( pMenuArchivo, ID_CERRAR_TODAS, wxString( _("Close all") ) , _("Close all views"), wxITEM_NORMAL );
+		wxMenuItem* m_pMenuGuardar = new wxMenuItem( pMenuArchivo, ID_GUARDAR, wxString(_("&Save")) + wxT("\tAlt+g"), _("Save the active study."), wxITEM_NORMAL );
+		wxMenu* m_pExportMenu = new wxMenu( );
+		wxMenuItem* m_pExportAsImage = new wxMenuItem( m_pExportMenu, ID_EXPORTAR, wxString( _("Export opened series...") ) + wxT("\tAlt+e"), _("Export the active study to other formats"), wxITEM_NORMAL );
+		wxMenuItem* m_pDicomDirExport = new wxMenuItem( m_pExportMenu, ID_DICOMDIR_EXPORT, _("Export to DICOM Dir"), _("Export to DICOM Dir"), wxITEM_NORMAL );
+		wxMenuItem* m_pMenuSubirPacs = new wxMenuItem( pMenuArchivo, ID_SUBIR_PACS, wxString( _("Send to PACS...") ) , wxEmptyString, wxITEM_NORMAL );
+		wxMenuItem* m_pMenuImprimir = new wxMenuItem( pMenuArchivo, ID_IMPRIMIR, wxString( _("Print...") ) + wxT("\tAlt+p"), wxEmptyString, wxITEM_NORMAL );
+		wxMenuItem* m_pMenuSalir = new wxMenuItem( pMenuArchivo, ID_SALIR, wxString( _("&Exit") ) + wxT("\tAlt+s"), _("Exit application"), wxITEM_NORMAL );
 #ifdef __WXMSW__
 		m_pMenuGuardar->SetBitmaps( GinkgoResourcesManager::IconosMenus::GetIcoGuardar());
 		m_pMenuAdquirir->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoAbrir());
@@ -1799,7 +1822,8 @@ void VentanaPrincipal::RefrescarMenus()
 		m_pMenuImportar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoImportar());
 		m_pCerrar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoCerrarTab());
 		m_pMenuSalir->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoSalir());
-		m_pMenuExportar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoExportar());
+		m_pExportAsImage->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoExportar());
+		m_pDicomDirExport->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoDicomDir());
 		m_pMenuImprimir->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoImpresora());
 		m_pMenuSubirPacs->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
 #else
@@ -1810,7 +1834,8 @@ void VentanaPrincipal::RefrescarMenus()
 		m_pMenuImportar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoImportar());
 		m_pCerrar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoCerrarTab());
 		m_pMenuSalir->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoSalir());
-		m_pMenuExportar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoExportar());
+		m_pExportAsImage->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoExportar());
+		m_pDicomDirExport->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoDicomDir());
 		m_pMenuImprimir->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoImpresora());
 		m_pMenuSubirPacs->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
 #endif
@@ -1835,8 +1860,15 @@ void VentanaPrincipal::RefrescarMenus()
 		} else { 
 			delete m_pMenuSubirPacs;
 		}
-		pMenuArchivo->Append( m_pMenuExportar );
-		pMenuArchivo->AppendSeparator();
+		
+		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.restrictions","export")) {
+			pMenuArchivo->AppendSubMenu( m_pExportMenu, _("Export ...")  );
+			m_pExportMenu->Append(m_pExportAsImage);
+			m_pExportMenu->Append( m_pDicomDirExport );
+			pMenuArchivo->AppendSeparator();
+		} else {
+			delete m_pExportMenu;
+		}
 		pMenuArchivo->Append( m_pMenuImprimir );
 		pMenuArchivo->AppendSeparator();
 		pMenuArchivo->Append( m_pMenuSalir );
@@ -1852,8 +1884,9 @@ void VentanaPrincipal::RefrescarMenus()
 		this->Connect( m_pMenuGuardar->GetId(), wxEVT_UPDATE_UI, wxUpdateUIEventHandler( VentanaPrincipal::OnUpdateGuardar ) );
 		this->Connect( m_pMenuSubirPacs->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnSubirPACS ) );
 		this->Connect( m_pMenuSubirPacs->GetId(), wxEVT_UPDATE_UI, wxUpdateUIEventHandler( VentanaPrincipal::OnUpdateSubirPACS ) );
-		this->Connect( m_pMenuExportar->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnExportar ) );
-		this->Connect( m_pMenuExportar->GetId(), wxEVT_UPDATE_UI, wxUpdateUIEventHandler( VentanaPrincipal::OnUpdateExportar ) );
+		this->Connect( m_pExportAsImage->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnExportar ) );
+		this->Connect( m_pExportAsImage->GetId(), wxEVT_UPDATE_UI, wxUpdateUIEventHandler( VentanaPrincipal::OnUpdateExportar ) );
+		this->Connect( m_pDicomDirExport->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnDicomDirExport ) );
 
 		this->Connect( m_pMenuImprimir->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMenuImprimir ) );
 		this->Connect( m_pMenuImprimir->GetId(), wxEVT_UPDATE_UI, wxUpdateUIEventHandler( VentanaPrincipal::OnMenuImprimirUpdateUI ) );
@@ -1861,11 +1894,11 @@ void VentanaPrincipal::RefrescarMenus()
 		this->Connect( m_pMenuSalir->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnSalir ) );
 
 		//ayuda
-		wxMenuItem*  pMenuOnlineHelp = new wxMenuItem( pMenuAyuda, ID_ONLINE_MANUAL, wxString( _("Ginkgo CADx Online Manual ...") ), _("Ginkgo CADx Online Manual ..."), wxITEM_NORMAL );
+		wxMenuItem*  pMenuOnlineHelp = new wxMenuItem( pMenuAyuda, ID_ONLINE_MANUAL, wxString( _("Ginkgo CADx online manual ...") ), _("Ginkgo CADx online manual ..."), wxITEM_NORMAL );
 		wxMenuItem*  m_pMenuCheckUpdates = new wxMenuItem( pMenuAyuda, ID_CHECK_UPDATES, wxString( _("Check for updates") ), _("Check for newest versions"), wxITEM_NORMAL );
 		wxMenuItem*  pMenuOnlineSupport = new wxMenuItem( pMenuAyuda, ID_ONLINE_SUPPORT, wxString( _("Need support ...") ), _("Need support ..."), wxITEM_NORMAL );
-		wxMenuItem*  pMenuExtSupport = new wxMenuItem( pMenuAyuda, ID_EXTENSIONS_SUPPORT, wxString( _("Get Extensions ...") ), _("Get Extensions ..."), wxITEM_NORMAL );
-		wxMenuItem*  pMenuStartPage = new wxMenuItem( pMenuAyuda, ID_START_PAGE, wxString( _("Start page ...") ), _("Ginkgo CADx Start Page ..."), wxITEM_NORMAL );
+		wxMenuItem*  pMenuExtSupport = new wxMenuItem( pMenuAyuda, ID_EXTENSIONS_SUPPORT, wxString( _("Get extensions ...") ), _("Get extensions ..."), wxITEM_NORMAL );
+		wxMenuItem*  pMenuStartPage = new wxMenuItem( pMenuAyuda, ID_START_PAGE, wxString( _("Start page ...") ), _("Ginkgo CADx start page ..."), wxITEM_NORMAL );
 		wxMenuItem*  m_pMenuAcercaDe = new wxMenuItem( pMenuAyuda, ID_ACERCA_DE, wxString( _("About &Ginkgo CADx ...") ), _("About Ginkgo CADx ..."), wxITEM_NORMAL );
 
 		#ifdef __WXMSW__
@@ -1898,11 +1931,11 @@ void VentanaPrincipal::RefrescarMenus()
 
 	//PANTALLA COMPLETA, y distintos layouts
 	{
-		wxMenuItem*  pPantallaCompleta = new wxMenuItem( pMenuVer, ID_PANTALLA_COMPLETA, wxString(_("Full Screen"))+ wxT("\tF11"), _("Show full screen"), wxITEM_NORMAL );
+		wxMenuItem*  pPantallaCompleta = new wxMenuItem( pMenuVer, ID_PANTALLA_COMPLETA, wxString(_("Full screen"))+ wxT("\tF11"), _("Show full screen"), wxITEM_NORMAL );
 		wxMenu* subMenuPestanias = new wxMenu();
-		wxMenuItem* pMosaicoRestaurar = new wxMenuItem(subMenuPestanias, ID_MOSAICO_RESTAURAR, wxString( _("Tab Grouping") ), _("Tab Grouping"), wxITEM_NORMAL );
-		wxMenuItem*  pMosaicoHorizontal = new wxMenuItem( subMenuPestanias, ID_MOSAICO_HORIZONTAL, _("Horizontal Mosaic"), _("Horizontal Mosaic"), wxITEM_NORMAL );
-		wxMenuItem*  pMosaicoVertical = new wxMenuItem( subMenuPestanias, ID_MOSAICO_VERTICAL, _("Vertical Mosaic"), _("Vertical Mosaic"), wxITEM_NORMAL );
+		wxMenuItem* pMosaicoRestaurar = new wxMenuItem(subMenuPestanias, ID_MOSAICO_RESTAURAR, wxString( _("Tab grouping") ), _("Tab grouping"), wxITEM_NORMAL );
+		wxMenuItem*  pMosaicoHorizontal = new wxMenuItem( subMenuPestanias, ID_MOSAICO_HORIZONTAL, _("Horizontal mosaic"), _("Horizontal mosaic"), wxITEM_NORMAL );
+		wxMenuItem*  pMosaicoVertical = new wxMenuItem( subMenuPestanias, ID_MOSAICO_VERTICAL, _("Vertical mosaic"), _("Vertical mosaic"), wxITEM_NORMAL );
 
 		wxMenu* subMenuGrid = new wxMenu();
 		wxMenuItem*  pGrid2Col = new wxMenuItem( subMenuGrid, ID_GRID_2_COLUMNAS, _("Grid (two columns)"), _("Grid (two columns)"), wxITEM_NORMAL );
@@ -1934,8 +1967,8 @@ void VentanaPrincipal::RefrescarMenus()
 		pMenuVer->Append( pPantallaCompleta );
 		pMenuVer->AppendSeparator();
 
-		pMenuVer->AppendSubMenu(subMenuPestanias,_("Tabbed Organization"));
-		pMenuVer->AppendSubMenu(subMenuGrid,_("Grid Organization"));
+		pMenuVer->AppendSubMenu(subMenuPestanias,_("Tabbed organization"));
+		pMenuVer->AppendSubMenu(subMenuGrid,_("Grid organization"));
 
 		this->Connect( pPantallaCompleta->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnPantallaCompleta ) );
 		this->Connect( pMosaicoHorizontal->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMosaicoHorizontal ) );
@@ -2046,9 +2079,9 @@ void VentanaPrincipal::RefrescarMenus()
 		wxMenuItem*  pMenuHL7 = NULL;
 		wxMenuItem*  pMenuLogs = NULL;
 		//herramientas
-		pMenuConfiguracion = new wxMenuItem( pMenuHerramientas, ID_CONFIGURACION, wxString(_("Settings")) + wxT("\tAlt+c"), _("Ginkgo CADx Settings"), wxITEM_NORMAL );
-		pMenuHL7 = new wxMenuItem( pMenuHerramientas, ID_CONTROLHL7, wxString(_("HL7 Monitor")) + wxT(""), _("HL7 Message Control"), wxITEM_NORMAL );
-		pMenuLogs = new wxMenuItem( pMenuHerramientas, ID_CONTROLLOGS, wxString(_("Log Monitor")) + wxT("\tAlt+r"), _("Log monitored"), wxITEM_NORMAL );
+		pMenuConfiguracion = new wxMenuItem( pMenuHerramientas, ID_CONFIGURACION, wxString(_("Settings")) + wxT("\tAlt+c"), _("Ginkgo CADx settings"), wxITEM_NORMAL );
+		pMenuHL7 = new wxMenuItem( pMenuHerramientas, ID_CONTROLHL7, wxString(_("HL7 monitor")) + wxT(""), _("HL7 message control"), wxITEM_NORMAL );
+		pMenuLogs = new wxMenuItem( pMenuHerramientas, ID_CONTROLLOGS, wxString(_("Log monitor")) + wxT("\tAlt+r"), _("Log monitored"), wxITEM_NORMAL );
 
 #ifdef __WXMSW__
 		pMenuConfiguracion->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoConfiguracion());
@@ -2461,10 +2494,10 @@ void VentanaPrincipal::OnNotebookMenuTab(AUI_NAMESPACE wxAuiNotebookEvent& )
 	subMenuPestanias->AppendSeparator();
 	subMenuPestanias->Append(pMosaicoHorizontal);
 	subMenuPestanias->Append(pMosaicoVertical);
-	menu->AppendSubMenu(subMenuPestanias,_("Tab Organization"));
+	menu->AppendSubMenu(subMenuPestanias,_("Tabbed organization"));
 	subMenuGrid->Append(pGrid2Col);
 	subMenuGrid->Append(pGrid3Col);
-	menu->AppendSubMenu(subMenuGrid,_("Grid Organization"));
+	menu->AppendSubMenu(subMenuGrid,_("Grid organization"));
 	menu->AppendSeparator();
 	menu->Append(pMenuCerrarActiva);
 	menu->Append(pMenuCerrarTodas);
