@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ventanaprincipal.h 4158 2011-09-19 13:25:20Z tovar $
+ *  $Id: ventanaprincipal.h 4391 2011-11-10 13:24:05Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -149,7 +149,7 @@ public:
 	/* Evento de lanzamiento de ventana "Online Help" */
 	virtual void OnOnlineHelp(wxCommandEvent& event);
 
-	/* Evento de lanzamiento de ventana "Online Support" */
+	/* Evento de lanzamiento de ventana "Online support" */
 	virtual void OnOnlineSupport(wxCommandEvent& event);
 	
 	/* Launch event window "Extensions Support" */
@@ -184,6 +184,8 @@ public:
 	/* Evento de exportado de un estudio */
 	virtual void OnExportar(wxCommandEvent& event);
 
+	virtual void OnDicomDirExport(wxCommandEvent& event);
+
 	/* Evento de exportado de un subir al pacs */
 	virtual void OnSubirPACS(wxCommandEvent& event);
 
