@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: abrir.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: abrir.h 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -12,7 +12,7 @@
  *
  */
 #pragma once
-#include <main/controllers/controladorimportacionpacs.h>
+#include <main/controllers/pacscontroller.h>
 #include <string>
 #include <vector>
 
