@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: selectfiles.cpp 3985 2011-07-13 12:01:17Z tovar $
+ *  $Id: selectfiles.cpp 4403 2011-11-14 10:59:24Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -132,20 +132,8 @@ namespace GNC {
 
 		//region "Metodos heredados de Ipasowizard"
 
-		void SelectFiles::Attach(wxSizer *sizer){
-			Show(true);
-			sizer->Add(this,10, wxEXPAND);
-			this->GetParent()->Layout();
-		}
-
-		void SelectFiles::Detach(wxSizer *sizer){
-			Hide();
-			sizer->Detach(this);
-			sizer->GetContainingWindow()->Layout();
-		}
-
 		std::string SelectFiles::GetTitle(){
-			return _Std("Select the DICOM files you wish to upload");
+			return _Std("Upload to PACS");
 		}
 
 		std::string SelectFiles::GetSubTitle(){
