@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: licencia.h 4180 2011-09-23 07:21:29Z tovar $
+ *  $Id: licencia.h 4425 2011-11-18 12:27:41Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -18,14 +18,14 @@
 	#define GINKGO_VERSION     2
 #endif
 #if !defined(GINKGO_SUB_VERSION)
-	#define GINKGO_SUB_VERSION 5
+	#define GINKGO_SUB_VERSION 6
 #endif
 #if !defined(GINKGO_SUB_RELEASE)
-	#define GINKGO_SUB_RELEASE 4
-#endif
-#if !defined(GINKGO_BUILD)
-	#define GINKGO_BUILD       1
+	#define GINKGO_SUB_RELEASE 0
 #endif
+
+#define GINKGO_BUILD           "$Revision: 4425 $"
+
 #if !defined(GINKGO_CODENAME)
 	#define GINKGO_CODENAME    "final"
 #endif
