@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientamarcado.cpp 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: herramientamarcado.cpp 4051 2011-08-01 09:41:38Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -138,7 +138,8 @@ GNC::HerramientaMarcado::HerramientaMarcado() {
 	m_pContratoActivo = NULL;
 	m_pBuilder = NULL;
 	m_MarcadoActivo = TW_Punto;
-	m_Descripcion = _Std("Marking Tools");
+	m_Descripcion = _Std("Marking Tools\tCtrl+M");
+	m_AcceleratorCode = m_Descripcion[m_Descripcion.size() - 1];
 	m_Icono = GinkgoResourcesManager::IconosHerramientas::GetIcoMarcado();
 }
 
