@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientascore.h 3508 2011-03-15 14:44:49Z tovar $
+ *  $Id: herramientascore.h 4394 2011-11-11 09:45:22Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,6 +13,7 @@
  */
 #include "herramientaangulo.h"
 #include "herramientapuntero.h"
+#include "herramientaslider.h"
 #include "herramientaregla.h"
 #include "herramientaelevacion.h"
 #include "herramientanota.h"
@@ -26,3 +27,4 @@
 #include "herramientalayoutventana.h"
 #include "herramientadesencajar.h"
 #include "herramientadeshacer.h"
+#include "herramientainterpolate.h"
