@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: herramientawindowlevel.cpp 3917 2011-07-05 09:30:55Z tovar $
+ *  $Id: herramientawindowlevel.cpp 4051 2011-08-01 09:41:38Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -286,8 +286,8 @@ namespace GNC {
 
 GNC::HerramientaWindowLevel::HerramientaWindowLevel()
 {
-
-	m_Descripcion = _Std("Window/Level");
+	m_Descripcion = _Std("Window/Level\tCtrl+W");
+	m_AcceleratorCode = m_Descripcion[m_Descripcion.size() - 1];
 
 	m_Icono = GinkgoResourcesManager::IconosHerramientas::GetIcoWindowLevel();
 }
