@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ginkgohttp.cpp 3814 2011-05-01 11:36:06Z carlos $
+ *  $Id: ginkgohttp.cpp 4158 2011-09-19 13:25:20Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -211,6 +211,50 @@ namespace GIL {
 
 				return salida;
 			}
+
+			int GinkgoHTTP::ParseResponseBinary(char* buffer, int sizeOfBuffer, MapaHeaders& headers, int& positionEndOfHeaders)
+			{
+				int httpResponse = 0;
+
+				int indice;
+
+				std::string responseString = std::string((char*)buffer, sizeOfBuffer);
+
+				std::string tmpString;
+				indice = GetLinea(responseString,tmpString,0);
+				if(indice == (int)std::string::npos) {
+					return -1;
+				}
+
+				if(tmpString.find_first_of("HTTP/")==std::string::npos) {
+					return -1;
+				}
+
+				if(tmpString.find_first_of(' ') != std::string::npos) {
+					std::string tmpSubString = tmpString.substr(tmpString.find_first_of(' ')+1);
+					std::istringstream isstream(tmpSubString);
+					isstream >> httpResponse;
+					if(tmpSubString.at(0) != '2'){
+						return httpResponse;
+					}
+				}
+
+				std::string strLinea;
+
+				do {
+					indice = GetLinea(responseString,strLinea,indice);
+					int puntos = strLinea.find_first_of(':');
+					if(puntos>0) {
+						std::string cabecera = strLinea.substr(0,puntos);
+						headers[cabecera] = strLinea.substr(puntos+1,strLinea.size()-1);
+					} else {
+						positionEndOfHeaders = indice;
+						break;
+					}
+				}while (indice != (int)std::string::npos);
+
+				return httpResponse;
+			}
 		};
 	};
 };
