@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ginkgoresourcemanager.cpp 4072 2011-08-10 13:45:52Z tovar $
+ *  $Id: ginkgoresourcemanager.cpp 4394 2011-11-11 09:45:22Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -112,7 +112,8 @@ const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoFicheroClave(){retu
 const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoPlegar(){return wxMEMORY_BITMAP(ico_plegar); }
 const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoDesplegar(){return wxMEMORY_BITMAP(ico_desplegar); }
 const wxBitmap GinkgoResourcesManager::PanelHistorial::GetMoviePreview(){return wxMEMORY_BITMAP(ico_movie_preview); }
-
+const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoCleanAll() {return wxMEMORY_BITMAP(ico_clean_all);}
+const wxBitmap GinkgoResourcesManager::PanelHistorial::GetIcoAllPatients() {return wxMEMORY_BITMAP(ico_all_patients);}
 // Iconos de herramientas
 const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoAngulo(){return wxMEMORY_BITMAP(ico_angulo); }
 const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoAnotacion(){return wxMEMORY_BITMAP(ico_anotacion); }
@@ -133,6 +134,7 @@ const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoMostrarOcultarT
 const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoDesencajar(){return wxMEMORY_BITMAP(ico_desencajar); }
 const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoCornerAnnotations(){return wxMEMORY_BITMAP(ico_corner_annotations); }
 const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoInforme(){return wxMEMORY_BITMAP(ico_informe); }
+const wxBitmap GinkgoResourcesManager::IconosHerramientas::GetIcoSlider(){return wxMEMORY_BITMAP(ico_slider); }
 
 // Iconos de menus
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoAbrir(){return wxMEMORY_BITMAP(ico_abrir); }
@@ -145,12 +147,14 @@ const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoExportar(){return wxME
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoFiltrado(){return wxMEMORY_BITMAP(ico_filtrado); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoGuardar(){return wxMEMORY_BITMAP(ico_guardar); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoImportar(){return wxMEMORY_BITMAP(ico_importar); }
+const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoDicomDir(){return wxMEMORY_BITMAP(ico_dicom_dir); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoReset(){return wxMEMORY_BITMAP(ico_reset); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoSalir(){return wxMEMORY_BITMAP(ico_salir); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoImpresora(){return wxMEMORY_BITMAP(ico_impresora); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoVistaPreliminar(){return wxMEMORY_BITMAP(ico_vista_preliminar); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoCalibrarImagen(){return wxMEMORY_BITMAP(ico_calibrar_imagen); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoEliminar(){return wxMEMORY_BITMAP(ico_eliminar_widget); }
+const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoEliminarTodo(){return wxMEMORY_BITMAP(ico_eliminar_todo); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoEditar(){return wxMEMORY_BITMAP(ico_editar); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS(){return wxMEMORY_BITMAP(ico_send_to_pacs); }
 const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoEliminarWidget(){return wxMEMORY_BITMAP(ico_eliminar_widget); }
@@ -162,11 +166,13 @@ const wxBitmap GinkgoResourcesManager::IconosMenus::GetIcoObtainExtensions(){ret
 
 
 // Logos
-const wxBitmap GinkgoResourcesManager::Logos::GetLogoGinkgo48x48() {return wxMEMORY_BITMAP(ginkgo_logo48x48); } // Not used
+const wxBitmap GinkgoResourcesManager::Logos::GetLogoGinkgo48x48() {return wxMEMORY_BITMAP(ginkgo48x48); } // Not used
 const wxBitmap GinkgoResourcesManager::Logos::GetLogoGinkgo16x16() {return wxMEMORY_BITMAP(ico_ginkgo16x16); }
 const wxBitmap GinkgoResourcesManager::Logos::GetLogoGinkgo32x32() {return wxMEMORY_BITMAP(ico_ginkgo32x32); }
 const wxBitmap GinkgoResourcesManager::Logos::GetLogoSplash(){return wxMEMORY_BITMAP(ico_logo_splash); }
 const wxBitmap GinkgoResourcesManager::Logos::GetLogoBackground(){return wxMEMORY_BITMAP(ico_logo_background); }
+const wxBitmap GinkgoResourcesManager::Logos::GetExtensionsLogo(){return wxMEMORY_BITMAP(extensions_logo); }
+const wxBitmap GinkgoResourcesManager::Logos::GetExtensionsErrorLogo(){return wxMEMORY_BITMAP(ico_extension_error); }
 
 //cursores
 const wxImage GinkgoResourcesManager::Cursores::GetCursorTransparente()
