@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ginkgoresourcemanager.h 4072 2011-08-10 13:45:52Z tovar $
+ *  $Id: ginkgoresourcemanager.h 4394 2011-11-11 09:45:22Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -95,6 +95,8 @@
 		static const wxBitmap GetIcoPlegar();
 		static const wxBitmap GetIcoDesplegar();
 		static const wxBitmap GetMoviePreview();
+		static const wxBitmap GetIcoCleanAll();
+		static const wxBitmap GetIcoAllPatients();
  	};
 
  	class EXTAPI IconosHerramientas {
@@ -118,6 +120,7 @@
 		static const wxBitmap GetIcoDesencajar();
 		static const wxBitmap GetIcoCornerAnnotations();
 		static const wxBitmap GetIcoInforme();
+		static const wxBitmap GetIcoSlider();
 	};
 
  	class EXTAPI IconosMenus {
@@ -132,12 +135,14 @@
  		static const wxBitmap GetIcoFiltrado();
  		static const wxBitmap GetIcoGuardar();
  		static const wxBitmap GetIcoImportar();
+		static const wxBitmap GetIcoDicomDir();
  		static const wxBitmap GetIcoReset();
  		static const wxBitmap GetIcoSalir();
 		static const wxBitmap GetIcoImpresora();
 		static const wxBitmap GetIcoVistaPreliminar();
 		static const wxBitmap GetIcoCalibrarImagen();
 		static const wxBitmap GetIcoEliminar();
+		static const wxBitmap GetIcoEliminarTodo();
 		static const wxBitmap GetIcoEditar();
 		static const wxBitmap GetIcoSendToPACS();
 		static const wxBitmap GetIcoEliminarWidget();
@@ -155,6 +160,8 @@
 		static const wxBitmap GetLogoGinkgo32x32();
 		static const wxBitmap GetLogoSplash();
 		static const wxBitmap GetLogoBackground();
+		static const wxBitmap GetExtensionsLogo();
+		static const wxBitmap GetExtensionsErrorLogo();
  	};
 
 	class EXTAPI Cursores {
