@@ -1,5 +1,5 @@
 /*
- *  $Id: iconos.h 3192 2011-01-28 09:50:29Z tovar $
+ *  $Id: iconos.h 4369 2011-11-04 11:55:00Z tovar $
  *  Proyecto Ginkgo
  *
  *  Copyright 2008 MetaEmotion S.L. All rights reserved.
@@ -9,6 +9,8 @@
 
 #include "ico_ginkgo16x16.h"
 #include "ico_ginkgo32x32.h"
-#include "ginkgo_logo48x48.h"
+#include "ginkgo48x48.h"
 #include "ico_logo_splash.h"
 #include "ico_logo_background.h"
+#include "extensions_logo.h"
+#include "ico_extension_error.h"
