@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: vtkginkgoimageviewer.cpp 4090 2011-08-25 12:17:45Z tovar $
+ *  $Id: vtkginkgoimageviewer.cpp 4375 2011-11-04 13:49:41Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -76,7 +76,7 @@
 
 #include <hackimageactor.h>
 
-#define VTK_GINKGO_ZOOM_MIN 0.5f
+#define VTK_GINKGO_ZOOM_MIN 0.25f
 #define VTK_GINKGO_ZOOM_MAX 200
 
 extern int vtkrint(double a);
@@ -755,7 +755,6 @@ void vtkGinkgoImageViewer::UpdateDisplayExtent()
 
 void vtkGinkgoImageViewer::UpdateOrientation()
 {
-
 	//GNC::GCS::Timer t;
 	//t.start();
 
@@ -1046,7 +1045,9 @@ void vtkGinkgoImageViewer::SetupPipeline()
     if (!mantenerVista)
     {
 
-        UpdateOrientation();
+		 double focal[3], pos[3];
+		 GetRelativePositionOfCamera(focal, pos);
+       UpdateOrientation();
 
         //se comprueba si han cambiado las dimensiones o el spacing
         bool mantenerZoom = true;
@@ -1057,6 +1058,9 @@ void vtkGinkgoImageViewer::SetupPipeline()
             }
         }
         ResetZoom(mantenerZoom);
+		  if (mantenerZoom) {
+			  SetRelativePositionOfCamera(focal, pos);
+		  }
     }
 }
 
@@ -1817,6 +1821,10 @@ void vtkGinkgoImageViewer::CopyCameraStatus(vtkGinkgoImageViewer* w)
 		e.RollOffset     = eo.RollOffset;
 		e.FlipHorizontal = eo.FlipHorizontal;
 		e.FlipVertical   = eo.FlipVertical;
+
+		double focal[3], pos[3];
+		w->GetRelativePositionOfCamera(focal, pos);
+		this->SetRelativePositionOfCamera(focal,pos);
 	}
 }
 
@@ -1998,7 +2006,41 @@ void vtkGinkgoImageViewer::ResetToDefaultWindowLevel()
 
 void vtkGinkgoImageViewer::SyncSetCameraFocalAndPosition(double* /*focal*/, double* /*pos*/)
 {
-	;
+	//propagate event
+	this->InvokeEvent (vtkGinkgoImageViewer::ViewImagePositionChangeEvent, NULL);
+}
+
+void vtkGinkgoImageViewer::GetRelativePositionOfCamera(double focal[3], double pos[3])
+{	
+	//relative position of camera
+	Propiedades& pr = members->Propiedades;
+	Pipeline& p = members->Pipeline;
+
+	vtkCamera *camera = p.Renderer->GetActiveCamera();
+	double focal_c[3], pos_c[3];
+	camera->GetPosition(pos_c);
+	camera->GetFocalPoint(focal_c);
+
+	for (int i = 0; i < 3; i++) {
+		focal[i] = pr.CameraFocalPoint[i] - focal_c[i];
+		pos[i] = pr.CameraPosition[i] - pos_c[i];
+	}
+}
+
+void vtkGinkgoImageViewer::SetRelativePositionOfCamera(const double focal[3], const double pos[3])
+{
+	Propiedades& pr = members->Propiedades;
+	Pipeline& p = members->Pipeline;
+
+	double focal_c[3], pos_c[3];
+	for (int i = 0; i < 3; i++) {
+		focal_c[i] = pr.CameraFocalPoint[i] - focal[i];
+		pos_c[i] = pr.CameraPosition[i] - pos[i];
+	}
+
+	vtkCamera *camera = p.Renderer->GetActiveCamera();
+	camera->SetPosition(pos_c);
+	camera->SetFocalPoint(focal_c);
 }
 
 void vtkGinkgoImageViewer::SetLookupTable(vtkSmartPointer<vtkScalarsToColors> lut, int idLookupTable)
@@ -2047,17 +2089,47 @@ void vtkGinkgoImageViewer::ResetZoom(bool mantenerZoom)
 {
 	Pipeline& p = members->Pipeline;
 	Estado& e = members->Estado;
-	p.Renderer->ResetCamera();
+	Propiedades& pr = members->Propiedades;
 
-	e.InitialParallelScale = p.Renderer->GetActiveCamera()->GetParallelScale();
+	double bounds[6];
+	p.Renderer->ComputeVisiblePropBounds(bounds);
+	p.Renderer->ResetCamera(members->Pipeline.ImageActor->GetBounds());
+	double w1 = bounds[1] - bounds[0];
+	double w2 = bounds[3] - bounds[2];
+	double w3 = bounds[5] - bounds[4];
+	double radius = 0.5 * (std::max(w1, std::max(w2, w3)));
+	vtkCamera *camera = p.Renderer->GetActiveCamera();
+
+	camera->SetParallelScale(radius);
+
+	double focal_c[3], pos_c[3];
+	camera->GetPosition(pos_c);
+	camera->GetFocalPoint(focal_c);
+	//save initial focal point and position
+	pr.CameraFocalPoint[0] = focal_c[0];
+	pr.CameraFocalPoint[1] = focal_c[1];
+	pr.CameraFocalPoint[2] = focal_c[2];
+
+	pr.CameraPosition[0] = pos_c[0];
+	pr.CameraPosition[1] = pos_c[1];
+	pr.CameraPosition[2] = pos_c[2];
+
+	e.InitialParallelScale = radius;
 	if (mantenerZoom) {
 		SetZoom(e.Zoom);
 	} else {
 		e.Zoom = 1.0;
 	}
-
 }
 
+void vtkGinkgoImageViewer::SetInitialParallelScale(double scale)
+{
+	Estado& e = members->Estado;
+	e.InitialParallelScale = scale;
+	SetZoom(e.Zoom);
+}
+
+
 /** Set the actual zoom factor of the view. */
 void vtkGinkgoImageViewer::SetZoom(double factor)
 {
