@@ -938,6 +938,11 @@ void GinkgoGauge::SetStatus(const wxString& status)
 	Refresh(true);
 }
 
+wxString GinkgoGauge::GetStatus()
+{
+	return m_status;
+}
+
 void GinkgoGauge::SetProgress(float progress)
 {
 	if (progress >= 0.0f && progress <= 1.0f) {
@@ -946,6 +951,11 @@ void GinkgoGauge::SetProgress(float progress)
 	}
 }
 
+float GinkgoGauge::GetProgress()
+{
+	return m_progress;
+}
+
 void GinkgoGauge::OnPaint(wxPaintEvent &event)
 {
 	wxBufferedPaintDC dc(this, m_bufferBitmap);
