@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: thumbnailctrl.cpp 3822 2011-05-04 08:34:50Z carlos $
+ *  $Id: thumbnailctrl.cpp 4056 2011-08-03 09:10:43Z tovar $
  *  Ginkgo CADx Project
  *
  *
@@ -1565,13 +1565,21 @@ bool wxThumbnailItem::DrawBackground(wxDC& dc, wxThumbnailCtrl* ctrl, const wxRe
         fRect.width = rect.width - 2*margin;
         fRect.height = (rect.height - imageRect.height) - margin;
 
+		  wxString tmp;
+		  if (wxFileExists(filename)) {
+			  tmp = wxFileNameFromPath(filename);
+		  } else {
+			  tmp = filename;
+		  }
+
         wxCoord textW, textH;
-        dc.GetTextExtent(filename, & textW, & textH);
+        dc.GetTextExtent(tmp, & textW, & textH);
 
         dc.SetClippingRegion(fRect);
         int x = fRect.x + wxMax(0, (fRect.width - textW)/2);
         int y = fRect.y ;
-        dc.DrawText(filename, x, y);
+		 
+        dc.DrawText(tmp, x, y);
         dc.DestroyClippingRegion();
     }
     if (!filename.IsEmpty())
