@@ -10,6 +10,7 @@
 #include <api/ientorno.h>
 
 #include <iostream>
+#include <sstream>
 #include <wx/config.h>
 #include <wx/msgdlg.h>
 #include "fooextension/license.h"
@@ -20,7 +21,7 @@ IMPLEMENT_PrivateExtension(GnkFooExtension)
 
 //parameters are related with provider, version... sid is the extension id, it's used to know if a file has been imported by this extension
 //this information will be used in viewer open preference
-GnkFooExtension::GnkFooExtension(): PrivateExtension(FOO_EXTENSION_SID, FOO_EXTENSION_PROVIDER, FOO_EXTENSION_DESCRIPTION, FOO_EXTENSION_VERSION, FOO_EXTENSION_SUB_VERSION, FOO_EXTENSION_SUB_RELEASE)
+GnkFooExtension::GnkFooExtension(): PrivateExtension(FOO_EXTENSION_SID, FOO_EXTENSION_PROVIDER, FOO_EXTENSION_DESCRIPTION, FOO_EXTENSION_VERSION, FOO_EXTENSION_SUB_VERSION, FOO_EXTENSION_SUB_RELEASE, FOO_EXTENSION_BUILD, FOO_EXTENSION_CODENAME, FOO_EXTENSION_UPDATEURL)
 {
 }
 
@@ -45,4 +46,3 @@ void GnkFooExtension::ShowActivationDialog(wxWindow* pParent)
 {	
 	wxMessageBox(_("FooExtension is Open Source"), _("Info"));
 }
-
