@@ -158,8 +158,31 @@ namespace FooExtension {
 						base.tags[std::string("0020|0013")] = ostr.str();
 					}
 
-					//insert tags
+					// insert tags
 					pI2D->InsertarJerarquia(base);
+					/*
+					
+					
+					if (m_pIntegracionParams->m_pDatosPersistentes->m_pModeloImportacion.IsValid())
+					{
+						//raw data
+						
+						GIL::DICOM::TipoJerarquia override;
+						const GIL::IModeloIntegracion::ListaTuplas& tuplas = m_pIntegracionParams->m_pDatosPersistentes->m_pModeloImportacion->Metadatos;						
+						for (GIL::IModeloIntegracion::ListaTuplas::const_iterator it = tuplas.begin(); it != tuplas.end(); it++) {
+							const GIL::IModeloTupla& tupla = *it;
+							std::locale locale;
+							std::string codigo = tupla.codigo;
+							for (std::string::iterator p = codigo.begin(); p != codigo.end(); ++p) {
+								*p = std::use_facet<std::ctype<char> >(locale).toupper(*p);
+							}
+							if (codigo == "DICOM") {
+								override.tags[tupla.clave] = tupla.valor;
+							}
+						}
+						pI2D->InsertarJerarquia(override);
+					}
+					*/
 
 					//we are going to write dicomized file in temp dir
 					wxFileName inputFileName = wxFileName::FileName(FROMPATH((*it).imagePath));
