@@ -97,6 +97,9 @@ namespace FooExtension {
 
 	FooExtensionController::~FooExtensionController()
 	{
+		for (int i = 0; i < m_ListaModos.size(); ++i) {
+			delete m_ListaModos[i];
+		}
 	}
 
 	//It's mandatory to implement this method, here you have to register views of this module (Controller modes), this will register FooExtensionView .
