@@ -1,5 +1,5 @@
 /*
- *  $Id: lightvisualizatorextension.cpp 4103 2011-08-31 06:33:25Z tovar $
+ *  $Id: lightvisualizatorextension.cpp 4365 2011-11-03 14:01:58Z carlos $
  *  Proyecto Ginkgo
  *
  *  Copyright 2008 MetaEmotion S.L. All rights reserved.
@@ -13,6 +13,7 @@
 #include <wx/config.h>
 #include <wx/msgdlg.h>
 #include "lightvisualizator/license.h"
+#include <lightvisualizator/resources/logo_lightvisualizator.h>
 
 #if defined(_WIN32) && defined(_GINKGO_DEBUG)
 //#include <vld.h>
@@ -23,7 +24,7 @@ IMPLEMENT_PrivateExtension(LightVisualizatorExtension)
 
 //parameters are related with provider, version... sid is the extension id, it's used to know if a file has been imported by this extension
 //this information will be used in viewer open preference
-LightVisualizatorExtension::LightVisualizatorExtension(): PrivateExtension(LIGHT_VISUALIZATOR_SID_EXTENSION, LIGHT_VISUALIZATOR_PROVIDER, LIGHT_VISUALIZATOR_DESCRIPTION, LIGHT_VISUALIZATOR_VERSION, LIGHT_VISUALIZATOR_SUB_VERSION, LIGHT_VISUALIZATOR_SUB_RELEASE)
+LightVisualizatorExtension::LightVisualizatorExtension(): PrivateExtension(EXT_SID, EXT_PROVIDER, EXT_DESCRIPTION, EXT_VERSION, EXT_SUBVERSION, EXT_RELEASE, EXT_BUILD, EXT_CODENAME, EXT_UPDATEURL, logo_lightvisualizator, sizeof(logo_lightvisualizator))
 {
 }
 
