@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: visualizator.cpp 4109 2011-09-01 07:56:03Z tovar $
+ *  $Id: visualizator.cpp 4365 2011-11-03 14:01:58Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -17,6 +17,7 @@
 #include <api/ientorno.h>
 #include <iostream>
 #include <wx/msgdlg.h>
+#include <visualizator/resources/logo_visualizator.h>
 
 #if defined(_WIN32) && defined(_GINKGO_DEBUG)
 //#include <vld.h>
@@ -25,9 +26,10 @@
 IMPLEMENT_PrivateExtension(GNKVisualizatorExtension)
 
 
-GNKVisualizatorExtension::GNKVisualizatorExtension():PrivateExtension(VISUALIZATOR_SID, VISUALIZATOR_PROVIDER, VISUALIZATOR_DESCRIPTION, VISUALIZATOR_VERSION, VISUALIZATOR_SUB_VERSION, VISUALIZATOR_SUB_RELEASE)
+GNKVisualizatorExtension::GNKVisualizatorExtension():PrivateExtension(EXT_SID, EXT_PROVIDER, EXT_DESCRIPTION, EXT_VERSION, EXT_SUBVERSION, EXT_RELEASE, EXT_BUILD, EXT_CODENAME, EXT_UPDATEURL, logo_visualizator, sizeof(logo_visualizator))
 {
 }
+
 GNKVisualizatorExtension::~GNKVisualizatorExtension()
 {
 }
