@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: visualizatorcontroller.cpp 4166 2011-09-21 08:05:46Z tovar $
+ *  $Id: visualizatorcontroller.cpp 4365 2011-11-03 14:01:58Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -36,6 +36,7 @@
 #include <api/dicom/imodelodicom.h>
 #include <api/icontroladorcarga.h>
 #include <main/controllers/controladorhistorial.h>
+#include <visualizator/dialogos/importacion/selectimagesimportationvisualizator.h>
 
 #include <api/icontroladorpermisos.h>
 
@@ -55,12 +56,12 @@
 #include <iostream>
 
 #include <api/icontroladorinternacionalizacion.h>
-#include "../../recursos/aprimresourcemanager.h"
+#include <visualizator/resources/aprimresourcemanager.h>
 #include "../exportacion/tagsprivados.h"
 
 
 /* Constructor */
-GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::GCS::IEntorno* pEntorno) : GNC::GCS::IControladorModulo(pEntorno, SID_APRIM,0)
+GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::GCS::IEntorno* pEntorno) : GNC::GCS::IControladorModulo(pEntorno, EXT_SID, 0)
 {
 	//primero de todo registramos nuestro catalogo para la internacionalizacion de las cadenas
 	{
@@ -71,28 +72,28 @@ GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::G
 	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"), "dicomizador",_Std("Simple importation of images"),false, "", true);
 	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"),"vista2d",_Std("Medical viewer"), false, "", true);
 	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"),"waveform",_Std("Waveform viewer"), false, "", true);
-	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"),"reconstruction",_Std("3D Reconstruction"), false, "", true);
+	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"),"reconstruction",_Std("3D reconstruction"), false, "", true);
 
-	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D Reconstruction"),"orthogonalmpr3d",_Std("3D Orthogonal Multi-Planar Reconstruction (MPR)"), false, "", false);
-	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D Reconstruction"),"mip3d",_Std("3D Maximun Intensity Projection (MIP)"), false, "", false);
-	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D Reconstruction"),"volumerengering3d",_Std("3D Volume Rendering"), false, "", true);
-	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D Reconstruction"),"surfacerendering3d",_Std("3D Surface Rendering"), false, "", true);
-	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D Reconstruction"),"endoscopy3d",_Std("3D Endoscopy"), false, "", false);
+	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D reconstruction"),"orthogonalmpr3d",_Std("3D orthogonal multi-planar reconstruction (MPR)"), false, "", false);
+	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D reconstruction"),"mip3d",_Std("3D maximun intensity projection (MIP)"), false, "", false);
+	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D reconstruction"),"volumerengering3d",_Std("3D volume rendering"), false, "", true);
+	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D reconstruction"),"surfacerendering3d",_Std("3D surface rendering"), false, "", true);
+	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.reconstruction",_Std("3D reconstruction"),"endoscopy3d",_Std("3D endoscopy"), false, "", false);
 
-	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.vista2d",_Std("Medical viewer"),"guardar cambios",_Std("Save changes with Medical viewer"), true, "", true);
+	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria.vista2d",_Std("Medical viewer"),"guardar cambios",_Std("Save changes with medical viewer"), true, "", true);
 
 
 	m_pEntorno = pEntorno;
-	m_Nombre = VISUALIZATOR_DESCRIPTION;
+	m_Nombre = EXT_DESCRIPTION;
 	m_ImporterDescription = _Std("Default importer");
 	m_CopyRight = "(c) 2009 MetaEmotion S.L.";
 	m_Author = "MetaEmotion S.L.";
-	m_VersionMayor   = VISUALIZATOR_VERSION;
-	m_VersionMinor   = VISUALIZATOR_SUB_VERSION;
-	m_VersionRelease = VISUALIZATOR_SUB_RELEASE;
-	m_CodeName       = VISUALIZATOR_CODENAME;
+	m_VersionMayor   = EXT_VERSION;
+	m_VersionMinor   = EXT_SUBVERSION;
+	m_VersionRelease = EXT_RELEASE;
+	m_CodeName       = EXT_CODENAME;
 	std::ostringstream oversion;
-	oversion << VISUALIZATOR_VERSION << "."<< VISUALIZATOR_SUB_VERSION << "." << VISUALIZATOR_SUB_RELEASE;
+	oversion << EXT_VERSION << "."<< EXT_SUBVERSION << "." << EXT_RELEASE;
 	m_Version = oversion.str();
 
 	// Codigos LOINC de los informes de A. Primaria.
@@ -219,7 +220,7 @@ void GNKVisualizator::ControladorAtencionPrimaria::RegistrarVistas()
 	listaModalidades.push_back(std::string("BMD")); //Bone Densitometry (X-Ray)
 
 	GNC::GCS::ModoControlador::TipoListaUIDsImportacion listaUIDsImportacion;
-	listaUIDsImportacion.push_back(UID_APRIM);
+	listaUIDsImportacion.push_back(EXT_IMPORTER_SID);
 
 	if(m_pEntorno->GetControladorPermisos()->Get("atencionprimaria", "vista2d")) {
 		m_ListaModos.push_back(new GNC::GCS::ModoControlador(idModo++, _Std("Medical Image Viewer"), listaModalidades, listaUIDsImportacion, true));
@@ -238,7 +239,7 @@ void GNKVisualizator::ControladorAtencionPrimaria::RegistrarVistas()
 
 bool GNKVisualizator::ControladorAtencionPrimaria::SupportsImportationUID(const std::string &importationUID)
 {
-	return (importationUID == UID_APRIM);
+	return (importationUID == EXT_IMPORTER_SID);
 }
 
 /* Abre un estudio de manera no interactiva desde un directorio y devuelve su controlador específico */
@@ -402,10 +403,13 @@ bool GNKVisualizator::ControladorAtencionPrimaria::SoportaImportacion() const
 }
 
 void GNKVisualizator::ControladorAtencionPrimaria::GetPasosImportacion(IWizard* pWizard,std::list<IPasoWizard*> &listaPasos, wxWindow* pParent, std::string &dirTemporal, GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion){
-	GNKVisualizator::GUI::TipoWizardImportacion* datosPersistentes = new GNKVisualizator::GUI::TipoWizardImportacion(pModeloIntegracion);
+	GnkPtr<GNKVisualizator::GUI::TipoWizardImportacion> datosPersistentes(new GNKVisualizator::GUI::TipoWizardImportacion(pModeloIntegracion));
 
 	IPasoWizard* paso=new GNKVisualizator::GUI::PasoDatosGenerales(pParent,pWizard,datosPersistentes,dirTemporal,m_pEntorno);
 	listaPasos.push_back(paso);
+
+	paso = new GNKVisualizator::GUI::SelectImagesImportationVisualizator(pParent,pWizard,datosPersistentes,dirTemporal);
+	listaPasos.push_back(paso);				
 }
 
 //region "Manipulacion de paneles extra (Herramientas, etc.)"
