@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: datospersistentesimportacion.h 3830 2011-05-06 13:30:18Z carlos $
+ *  $Id: datospersistentesimportacion.h 4303 2011-10-18 10:31:44Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -85,27 +85,11 @@ namespace GNKVisualizator {
 					PacienteApellido2 = pModeloIntegracion->Paciente.apellido2;
 
 					PacienteIdentificador = pModeloIntegracion->Paciente.GetIdentificadorPreferido().valor;
-					
-					for(GIL::IModeloIntegracion::ListaTuplas::iterator it = pModeloIntegracion->Metadatos.begin(); it!= pModeloIntegracion->Metadatos.end(); it++){
-						if(it->codigo == std::string("DICOM")) {
-							if(it->clave == std::string("0008|0020")) {
-								EstudioFecha = it->valor;
-							} else if(it->clave == std::string("0008|0030")) {
-								EstudioHora = it->valor;
-							} else if(it->clave == std::string("0008|1030")) {
-								EstudioDescripcion = it->valor;
-							} else if(it->clave == std::string("0010|1010")) {
-								PacienteEdad = it->valor;
-							} else if(it->clave == std::string("0010|0040")) {
-								PacienteSexo = it->valor;
-							} 
-						} else {
-							//TODO movidas no dicom q tendremos que tener en cuenta
-
-						}
-					}
 				} 
 			}
+			~TipoWizardImportacion()
+			{
+			}
 			
 		}TipoWizardImportacion;
 	};
