@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: pasodatosgenerales.cpp 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: pasodatosgenerales.cpp 4303 2011-10-18 10:31:44Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -44,7 +44,7 @@
 namespace GNKVisualizator {
 	namespace GUI {
 
-		PasoDatosGenerales::PasoDatosGenerales(wxWindow* pParent,IWizard* pWizard,GnkPtr<TipoWizardImportacion> datosPersistentes,const std::string &dirTemporal,GNC::GCS::IEntorno * pEntorno):PanelDatosGeneralesBase(pParent),IPasoWizard(pWizard)
+		PasoDatosGenerales::PasoDatosGenerales(wxWindow* pParent,IWizard* pWizard,const GnkPtr<TipoWizardImportacion>& datosPersistentes,const std::string &dirTemporal,GNC::GCS::IEntorno * pEntorno):PanelDatosGeneralesBase(pParent),IPasoWizard(pWizard)
 		{
 /*			SetScrollbars(10, 10, 50, 50, 0, 0, false);
 			AdjustScrollbars();*/
@@ -72,13 +72,53 @@ namespace GNKVisualizator {
 
 //region "Metodos heredados de Ipasowizard"
 
-		void PasoDatosGenerales::Attach(wxSizer *sizer){
+		void PasoDatosGenerales::Attach(wxSizer *sizer)
+		{
 			//se mira a ver si los ficheros del panel estan correctamente etiquetados...
 			if(m_pDatosPersistentes->m_pModeloImportacion.IsValid()) {
 				m_pPacienteId->Enable(false);				
 				m_pPacienteNombre->Enable(false);
 				m_pPacienteApellido1->Enable(false);
 				m_pPacienteApellido2->Enable(false);
+
+				const GIL::IModeloIntegracion::ListaTuplas& tuplas = m_pDatosPersistentes->m_pModeloImportacion->Metadatos;						
+				for (GIL::IModeloIntegracion::ListaTuplas::const_iterator it = tuplas.begin(); it != tuplas.end(); it++) {
+					const GIL::IModeloTupla& tupla = *it;
+					const std::string& key = tupla.clave;
+					if (tupla.codigo == "DICOM") {
+						if (key == "0008|1030") {
+							m_pDatosPersistentes->EstudioDescripcion = tupla.valor;
+							m_pEstudioDescripcion->Enable(false);
+						} else if (key == "0008|0020") {
+							m_pDatosPersistentes->EstudioFecha = tupla.valor;
+							m_pEstudioFecha->Enable(false);
+						} else if (key == "0008|0030") {
+							m_pDatosPersistentes->EstudioHora = tupla.valor;
+							m_pEstudioTime->Enable(false);
+						} else if (key == "0008|103e") {
+							m_pDatosPersistentes->SerieDescripcion = tupla.valor;
+							m_pSerieDescripcion->Enable(false);
+						} else if (key == "0008|0022") {
+							m_pDatosPersistentes->SerieFecha = tupla.valor;
+							m_pSerieFecha->Enable(false);
+						} else if (key == "0008|0032") {
+							m_pDatosPersistentes->SerieHora = tupla.valor;
+							m_pSerieTime->Enable(false);
+						} else if (key == "0010|0030") {
+							m_pDatosPersistentes->PacienteFechaNacimiento = tupla.valor;
+							m_pPacienteFechaNacimiento->Enable(false);
+						} else if (key == "0010|1020") {
+							m_pDatosPersistentes->PacienteAltura = tupla.valor;
+							m_pPacienteAltura->Enable(false);
+						} else if (key == "0010|1030") {
+							m_pDatosPersistentes->PacientePeso = tupla.valor;
+							m_pPacientePeso->Enable(false);
+						} else if (key == "0010|0040") {
+							m_pDatosPersistentes->PacienteSexo = tupla.valor;
+							m_pPacienteSexo->Enable(false);
+						}
+					}
+				}
 			} else {
 				m_pPacienteId->SetBackgroundColour(wxColor(255, 213, 213));
 				m_pPacienteId->SetFocus();
@@ -200,7 +240,7 @@ namespace GNKVisualizator {
 		}
 
 		bool PasoDatosGenerales::Anterior(){
-			return true;
+			return false;
 		}
 
 		bool PasoDatosGenerales::Cancelar(){
@@ -208,20 +248,6 @@ namespace GNKVisualizator {
 		}
 
 		bool PasoDatosGenerales::Validar(){
-			bool correcto =  true;
-			if(ValidarDatosGenerales())
-			{
-				if(!m_dicomizado) {
-					m_dicomizado = Dicomizar();
-					correcto = m_dicomizado;
-				}
-			} else {
-				correcto = false;
-			}
-			return correcto;
-		}
-
-		bool PasoDatosGenerales::ValidarDatosGenerales() {
 			wxString mensaje = wxEmptyString;
 
 			if (m_pPacienteId->GetValue().IsEmpty()) {
@@ -268,109 +294,6 @@ namespace GNKVisualizator {
 			}
 		}
 
-		bool PasoDatosGenerales::Dicomizar() 
-		{
-			for(ListaFicheros::const_iterator it=m_pListaFicheros->begin(); it!= m_pListaFicheros->end(); it++) {
-				std::string rutaFichero = (*it);
-				GNKVisualizator::GUI::TipoWizardImportacion::TFicheroDicomizacionGNKVisualizator ficheroADicomizar;
-				ficheroADicomizar.pathImagen = rutaFichero;
-
-				m_pDatosPersistentes->m_listaFicherosADicomizar.push_back(ficheroADicomizar);
-			}
-
-			RellenarTagsComunes(m_pDatosPersistentes->baseImagenes);
-			GADAPI::ComandoDicomizacionIntegracionParams* pDicomParams = new GADAPI::ComandoDicomizacionIntegracionParams(m_pDatosPersistentes,m_pEntorno,m_dirTemporal);
-			GADAPI::ComandoDicomizacionIntegracion* pDicomCmd = new GADAPI::ComandoDicomizacionIntegracion(pDicomParams);
-			m_pEntorno->GetControladorComandos()->ProcessAsync(_Std("Performing tasks of integration ..."),pDicomCmd,NULL);
-			//se limpia la lista porque ya avisaremos de los nuevos ficheros
-			m_pListaFicheros->clear();
-			//
-			return true;
-			
-		}
-
-		void PasoDatosGenerales::RellenarTagsComunes(GIL::DICOM::TipoJerarquia& base)
-		{
-			std::string tag;
-
-			//institucion
-			if(m_pDatosPersistentes->NombreCentro == "" ){
-				if (GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",tag)) {
-					base.tags[std::string("0008|0080")] = tag;
-				}
-			} else {
-				base.tags[std::string("0008|0080")] = m_pDatosPersistentes->NombreCentro;
-			}
-
-			//nombre del medico responsable de la institucion
-			if(m_pDatosPersistentes->NombreMedico == ""){
-				if (GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion","NombreMedico",tag)) {
-					base.tags[std::string("0008|0090")] = tag;
-				}
-			} else {
-				base.tags[std::string("0008|0090")] = m_pDatosPersistentes->NombreMedico;
-			}
-
-			base.tags[std::string("0008|0070")] = std::string("Metaemotion S.L.");
-
-			base.tags[std::string("0008|1090")] = std::string("Ginkgo Atención Primaria");
-
-			//uid de aprimaria
-			base.tags[std::string("0018|1030")] = UID_APRIM;
-
-			base.tags[std::string("0008|0020")] = m_pDatosPersistentes->EstudioFecha;
-
-			base.tags[std::string("0008|0030")] =  m_pDatosPersistentes->EstudioHora;
-
-			base.tags[std::string("0008|1030")] = m_pDatosPersistentes->EstudioDescripcion;
-
-			//uid de la serie
-			if(m_pDatosPersistentes->SerieUID!=""){
-				base.tags[std::string("0020|000e")] = m_pDatosPersistentes->SerieUID;
-			}
-
-			//si procede referenciar estudio
-			if(m_pDatosPersistentes->StudyInstanceUID!=""){
-				base.tags[std::string("0020|000d")] = m_pDatosPersistentes->StudyInstanceUID;
-			}
-
-			if(m_pDatosPersistentes->AccessionNumber!="") {
-				base.tags[std::string("0008|0050")] = m_pDatosPersistentes->AccessionNumber;
-			}
-
-			//fecha serie
-			base.tags[std::string("0008|0021")] = m_pDatosPersistentes->SerieFecha;
-
-			//hora serie
-			base.tags[std::string("0008|0031")] = m_pDatosPersistentes->SerieHora;
-
-			//descripcion serie
-			base.tags[std::string("0008|103e")] = m_pDatosPersistentes->SerieDescripcion;
-
-			//fecha imagen
-			base.tags[std::string("0008|0022")] = m_pDatosPersistentes->SerieFecha;
-			//hora imagen
-			base.tags[std::string("0008|0032")] = m_pDatosPersistentes->SerieHora;
-			//descripcion imagen
-			base.tags[std::string("0020|4000")] = m_pDatosPersistentes->SerieDescripcion;
-
-
-			base.tags[std::string("0010|0010")] = m_pDatosPersistentes->PacienteNombre + "^" + m_pDatosPersistentes->PacienteApellido1 + "^" + m_pDatosPersistentes->PacienteApellido2;
-
-			base.tags[std::string("0010|0020")] = m_pDatosPersistentes->PacienteIdentificador;
-
-			base.tags[std::string("0010|1010")] = m_pDatosPersistentes->PacienteEdad;
-
-			base.tags[std::string("0010|0030")] = m_pDatosPersistentes->PacienteFechaNacimiento;
-
-			base.tags[std::string("0010|0040")] = m_pDatosPersistentes->PacienteSexo;
-
-			base.tags[std::string("0010|1020")] = m_pDatosPersistentes->PacienteAltura;
-
-			base.tags[std::string("0010|1030")] = m_pDatosPersistentes->PacientePeso;
-		}
-	//endregion
-
 		std::string PasoDatosGenerales::GetPacienteNombre(){
 			return std::string(m_pPacienteNombre->GetValue().ToUTF8());
 		}
