@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: vista2d.cpp 4122 2011-09-02 12:08:58Z carlos $
+ *  $Id: vista2d.cpp 4401 2011-11-11 13:25:38Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -30,6 +30,7 @@
 #include <eventos/eventosginkgo.h>
 
 #include <export/iherramientapuntero.h>
+#include <export/iherramientaslider.h>
 #include <export/iherramientaregla.h>
 #include <export/iherramientaangulo.h>
 #include <export/iherramientanota.h>
@@ -82,6 +83,7 @@ GNKVisualizator::Vista2D::Vista2D(const GnkPtr<GNKVisualizator::VisualizatorStud
 	GNC::GCS::IControladorHerramientas* cH = VisualizatorStudy->Entorno->GetControladorHerramientas();
 
 	GNC::GCS::IHerramientaPuntero*             hPuntero = NULL;
+	GNC::GCS::IHerramientaSlider*              hSlider = NULL;
 	GNC::GCS::IHerramientaRegla*               hRegla = NULL;
 	GNC::GCS::IHerramientaAngulo*              hAngulo = NULL;
 	GNC::GCS::IHerramientaNota*                hNota = NULL;
@@ -100,43 +102,49 @@ GNKVisualizator::Vista2D::Vista2D(const GnkPtr<GNKVisualizator::VisualizatorStud
 		hPuntero = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaPuntero>(GNC::GCS::IHerramientaPuntero::ID);
 		if (hPuntero != NULL) {
 			GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>* contratablevtk=hPuntero;
-			contratablevtk->Subscribir(this,GVista);
+			contratablevtk->Subscribir(this, GVista);
+		}
+		
+		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaSlider>(GNC::GCS::IHerramientaSlider::ID);
+		if (hSlider != NULL) {
+			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hSlider)->Subscribir(this, GVista);
+			((GNC::GCS::IContratable<GNC::GCS::IContratoSlider>*) hSlider)->Subscribir(this, this);
 		}
 
 		// Subscribimos la vista al contrato de regla
 		hRegla = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaRegla>(GNC::GCS::IHerramientaRegla::ID);
 		if (hRegla != NULL) {
-			hRegla->Subscribir(this,GVista);
+			hRegla->Subscribir(this, GVista);
 		}
 
 		// Subscribimos la vista al contrato de angulo
 		hAngulo = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAngulo>(GNC::GCS::IHerramientaAngulo::ID);
 		if (hAngulo != NULL) {
-			hAngulo->Subscribir(this,GVista);
+			hAngulo->Subscribir(this, GVista);
 		}
 
 		// Subscribimos la vista al contrato de marcado
 		hMarcado = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaMarcado>(GNC::GCS::IHerramientaMarcado::ID);
 		if (hMarcado != NULL) {
-			hMarcado->Subscribir(this,GVista);
+			hMarcado->Subscribir(this, GVista);
 		}
 
 		// Subscribimos la vista al contrato de hNota
 		hNota = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaNota>(GNC::GCS::IHerramientaNota::ID);
 		if (hNota != NULL) {
-			hNota->Subscribir(this,GVista);
+			hNota->Subscribir(this, GVista);
 		}
 
 		// Subscribimos la vista al contrato de Anotaciones ventana
 		hAnotacionesEsquina = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaAnotacionesEsquina>(GNC::GCS::IHerramientaAnotacionesEsquina::ID);
 		if (hAnotacionesEsquina != NULL) {
-			hAnotacionesEsquina->Subscribir(this,GVista);
+			hAnotacionesEsquina->Subscribir(this, GVista);
 		}
 
 		// Subscribimos la vista al contrato de Lupa
 		hLupa = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaLupa>(GNC::GCS::IHerramientaLupa::ID);
 		if (hLupa != NULL) {
-			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hLupa)->Subscribir(this,GVista);
+			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hLupa)->Subscribir(this, GVista);
 		}
 
 		// Subscribimos la vista al contrato de rejilla
@@ -180,6 +188,20 @@ GNKVisualizator::Vista2D::Vista2D(const GnkPtr<GNKVisualizator::VisualizatorStud
 	}
 }
 
+void GNKVisualizator::Vista2D::SetSlice(int slicenum)
+{
+	return GVista->GoToSlice(slicenum, false);
+}
+
+int GNKVisualizator::Vista2D::GetSlice() const
+{
+	return GVista->GetCurrentSlice();
+}
+
+int GNKVisualizator::Vista2D::GetNumberOfSlices() const
+{
+	return VisualizatorStudy->GetNumeroCortes();
+}
 
 GNKVisualizator::Vista2D::~Vista2D()
 {
@@ -189,6 +211,7 @@ GNKVisualizator::Vista2D::~Vista2D()
 
 	GNC::GCS::IControladorHerramientas* cH = VisualizatorStudy->Entorno->GetControladorHerramientas();
 	GNC::GCS::IHerramientaPuntero*            hPuntero = NULL;
+	GNC::GCS::IHerramientaSlider*             hSlider = NULL;
 	GNC::GCS::IHerramientaRegla*              hRegla = NULL;
 	GNC::GCS::IHerramientaAngulo*             hAngulo = NULL;
 	GNC::GCS::IHerramientaNota*               hNota = NULL;
@@ -210,6 +233,13 @@ GNKVisualizator::Vista2D::~Vista2D()
 			GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>* contratablevtk = hPuntero;
 			contratablevtk->DesSubscribirsLosDeLaVista(this);
 		}
+		
+		// Desubscribimos la vista al contrato de slider
+		hSlider = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaSlider>(GNC::GCS::IHerramientaSlider::ID);
+		if (hSlider != NULL) {
+			((GNC::GCS::IContratable<GNC::GCS::IContratoWidgets>*) hSlider)->DesSubscribirsLosDeLaVista(this);
+			((GNC::GCS::IContratable<GNC::GCS::IContratoSlider>*) hSlider)->DesSubscribirsLosDeLaVista(this);
+		}
 
 		// Desubscribimos la vista al contrato de puntero
 		hRegla = cH->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaRegla>(GNC::GCS::IHerramientaRegla::ID);
