@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: waveformview.cpp 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: waveformview.cpp 4316 2011-10-19 14:42:20Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -21,6 +21,7 @@
 #include <wx/utils.h>
 
 #include <api/globals.h>
+#include <api/math/geometria3d.h>
 #include <api/icontroladorherramientas.h>
 #include <api/icontroladorvistas.h>
 #include <api/icontroladorcarga.h>
@@ -60,6 +61,7 @@
 #include <hackimageactor.h>
 #include <vtkAlgorithmOutput.h>
 #include <vtkInformation.h>
+#include <vtkCamera.h>
 
 /* Constructor */
 
@@ -237,10 +239,52 @@ void GNKVisualizator::WaveFormView::IniciarPipeline()
 	//se conecta el evento Ginkgo
 	GNC::GCS::Eventos::EventoModificacionFichero evtModificado;
 	evtModificado.SetVista(this);
-	VisualizatorStudy->CargarWidgets();	
+	VisualizatorStudy->CargarWidgets();
 
 	VisualizatorStudy->IndiceFicheroActivo = 0;
+	
+	typedef GNC::GCS::Vector3D Vec;
 
+	GVista->ViewImage2D->UpdateImage();
+	
+	vtkSmartPointer<vtkCamera> cam = GVista->ViewImage2D->GetRenderer()->GetActiveCamera();
+	
+	Vec focalPoint;
+	Vec camPos;
+	Vec spacing;
+	Vec dims;
+	Vec winsize;
+	int idims[3];
+	int iwinsize[2];
+
+	GVista->ViewInteractor2D->Layout();
+	GVista->ViewInteractor2D->GetParent()->Layout();
+
+	GVista->ViewImage2D->GetSpacing(spacing.v);
+	GVista->ViewImage2D->GetDimensions(idims);
+	GVista->ViewInteractor2D->GetClientSize(&iwinsize[0], &iwinsize[1]);
+	//((wxWindowBase* )GVista->ViewInteractor2D)->GetSize();
+
+	dims.x = idims[0];
+	dims.y = idims[1];
+	winsize.x = iwinsize[0];
+	winsize.y = iwinsize[1];
+	
+	Vec worldViewPort = (spacing * (dims + Vec(1.0, 1.0, 0.0))); // + 1.0 cause pixel centers to pixels edges conversion
+
+	double parallelScale = worldViewPort.y / 2.0;
+
+	GVista->ViewImage2D->SetInitialParallelScale( parallelScale );
+
+	double rel = (winsize.x / winsize.y); // Relacin ancho/alto del viewPort
+	
+	focalPoint = Vec( rel * (parallelScale), parallelScale, 0.0);
+	camPos = focalPoint - Vec(0.0, 0.0, 1.0);
+
+	cam->SetPosition( camPos.v );
+	cam->SetFocalPoint( focalPoint.v );	
+	cam->SetViewUp(0.0, -1.0, 0.0);
+	cam->SetClippingRange(-2.0, 2.0);	
 
 	//lanzo el evento de imagen cargada
 	VisualizatorStudy->Entorno->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Eventos::EventoModificacionImagen(this,GNC::GCS::Eventos::EventoModificacionImagen::ImagenCargada));
