@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: wecg.cpp 3834 2011-05-10 07:42:57Z carlos $
+ *  $Id: wecg.cpp 4316 2011-10-19 14:42:20Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -71,11 +71,11 @@
 #define GRAPH_LINE_WIDTH_FAR 0.3f
 #define GRAPH_LINE_COLOR_FAR 0.0f, 0.0f, 0.0f, 0.9f
 
-#define LEAD_TEXT_COLOR 0.1f, 0.1f, 0.1f, 1.0f
+#define LEAD_TEXT_COLOR 1.0f, 0.1f, 0.1f, 1.0f
 
 
 static GNC::GCS::Vector WinMarginRel[2] = {
-	GNC::GCS::Vector(0.125, 0.0), GNC::GCS::Vector(1.0, 1.0)
+	GNC::GCS::Vector(0.0, 0.0), GNC::GCS::Vector(1.0, 1.0)
 };
 
 //region "Implementacion de WBuilder"
@@ -177,11 +177,12 @@ namespace GNKVisualizator {
 			void Plot(GNC::GCS::Contexto3D* c, GNC::GCS::TexturaCairo* tl, GNC::GCS::TexturaCairo* /*tu*/) {
 				
 				GNC::GCS::Vector sample;
+				GNC::GCS::Vector textSize;
 
 				if (!tl->EsValida() || TamTitle.EsNulo()) {
 					#define m_AnchoMaximo 100.0f
 					std::string Title = Info.GetTitle();
-					GNC::GCS::Vector textSize = GNC::GCS::GLHelper::calcularBoundingBox((*tl), Title, m_AnchoMaximo); // Tamao de la region en pixels
+					textSize = GNC::GCS::GLHelper::calcularBoundingBox((*tl), Title, m_AnchoMaximo); // Tamao de la region en pixels
 
 					tl->Redimensionar(std::ceil(textSize.x), std::ceil(textSize.y));
 					textSize.Asignar(tl->ancho, tl->alto);
@@ -202,7 +203,7 @@ namespace GNKVisualizator {
 				GNC::GCS::Vector pl;
 				GNC::GCS::Vector tSize;
 				
-				pl = Pos - (GNC::GCS::Vector(TamTitle.x, TamTitle.y / 2.0) * c->RefRelacionImagenPantalla());
+				pl = Pos - (GNC::GCS::Vector(-10, TamTitle.y) * c->RefRelacionImagenPantalla());
 
 				/*
 				 * Posicion del Quad
@@ -517,6 +518,18 @@ void GNKVisualizator::Widgets::WECG::Render(GNC::GCS::Contexto3D* c)
 			glVertex2d(win[1].x, y);
 		}
 		glEnd();
+
+		/*
+		glColor4f(0.0f, 0.0f, 0.0f, 1.0f);
+		glLineWidth(2.0f);
+		glBegin(GL_LINE_LOOP);
+		glVertex2d(0.0, 0.0);
+		glVertex2d(dims[0], 0.0);
+		glVertex2d(dims[0], dims[1]);
+		glVertex2d(0.0, dims[1]);
+		glVertex2d(0.0, 0.0);
+		glEnd();
+		*/
 	}
 
 	CData->Plot(c, rec);
