@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: gvistacompleja.cpp 4124 2011-09-02 12:21:20Z carlos $
+ *  $Id: gvistacompleja.cpp 4375 2011-11-04 13:49:41Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,7 +16,7 @@
 #include "gvistasimple.h"
 #include "imprimevistasimple.h"
 #include "../vistas/vista2d.h"
-#include "../../recursos/aprimresourcemanager.h"
+#include <visualizator/resources/aprimresourcemanager.h>
 #include <resources/ginkgoresourcemanager.h>
 
 #include <wx/msgdlg.h>
@@ -1424,6 +1424,9 @@ void GVistaCompleja::SetLayoutVentana(int filas, int columnas)
 			m_VistasSimples.erase(pVista);
 		}
 	} else {
+		for (unsigned int i = 0; i < m_VistasSimples.size(); ++i) {
+			m_VistasSimples[i]->ViewImage2D->ResetZoom();
+		}
 
 		//hay que crear
 		for(unsigned int i = 0; i< (unsigned int) (nuevoTam - tamAnterior) && m_VistasSimples.size() < (unsigned int) maxSlices; i++) {
