@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: gvistasimple.cpp 3901 2011-06-29 11:20:49Z tovar $
+ *  $Id: gvistasimple.cpp 4335 2011-10-26 09:42:35Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,7 +16,7 @@
 #include "gvistasimple.h"
 #include "gvistacompleja.h"
 #include "../vistas/vista2d.h"
-#include "../../recursos/aprimresourcemanager.h"
+#include <visualizator/resources/aprimresourcemanager.h>
 
 #include <wx/msgdlg.h>
 #include <wx/menu.h>
@@ -78,6 +78,18 @@ public:
 			IVista->GetEstudio()->Entorno->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Eventos::EventoRender(IVista));
 			UnLockZoom();
 		}
+
+		if ( event==vtkGinkgoImageViewer::ViewImagePositionChangeEvent && !this->PanLock)
+		{
+			LockPan();
+			if (view->GetRenderer()) {	
+				double pos[3], focal[3];
+				view->GetRelativePositionOfCamera(focal, pos);
+				IVista->GetEstudio()->Entorno->GetControladorEventos()->ProcesarEvento(new AtencionPrimaria::Eventos::ChangePositionEvent(IVista, pos, focal));
+				IVista->GetEstudio()->Entorno->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Eventos::EventoRender(IVista));
+			}
+			UnLockPan();
+		}	
 	}
 
 	void Setup(GNC::GCS::IVista* pIVista)
@@ -135,9 +147,12 @@ GVistaSimple::GVistaSimple(GNKVisualizator::Vista2D* pIVista, wxWindow* parent)
 	m_pObserverVTK->Setup(IVista);
 
 	ViewImage2D->AddObserver ( vtkGinkgoImageViewer::ViewImageZoomChangeEvent, m_pObserverVTK );
+	ViewImage2D->AddObserver ( vtkGinkgoImageViewer::ViewImagePositionChangeEvent, m_pObserverVTK );
 
 	AtencionPrimaria::Eventos::EventoZoom evtZoom(IVista);
+	AtencionPrimaria::Eventos::ChangePositionEvent evtChange(IVista);
 	IVista->GetEstudio()->Entorno->GetControladorEventos()->Registrar(this, evtZoom);
+	IVista->GetEstudio()->Entorno->GetControladorEventos()->Registrar(this, evtChange);
 
 	this->Connect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GVistaSimple::OnFocus),NULL,this);
 	ViewInteractor2D->Connect(wxEVT_KEY_DOWN,wxKeyEventHandler(GVistaSimple::OnKeyDown),NULL,this);
@@ -1092,6 +1107,16 @@ void GVistaSimple::ProcesarEvento(GNC::GCS::Eventos::IEvento *evt)
 			}
 		}
 			break;
+		case ginkgoEVT_GNKVisualizator_ChangePositionEvent:
+		{
+			AtencionPrimaria::Eventos::ChangePositionEvent* pEvt = dynamic_cast<AtencionPrimaria::Eventos::ChangePositionEvent*>(evt);
+			if(pEvt!=NULL){
+				m_pObserverVTK->LockPan();
+				ViewImage2D->SetRelativePositionOfCamera(pEvt->GetFocal(), pEvt->GetPosition());
+				m_pObserverVTK->UnLockPan();
+			}
+		}
+			break;
 		case ginkgoEVT_Core_ModificacionImagen:
 		{
 			GNC::GCS::Eventos::EventoModificacionImagen* pEvt = dynamic_cast<GNC::GCS::Eventos::EventoModificacionImagen*>(evt);
