@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: gwaveformview.cpp 3893 2011-06-21 13:01:56Z tovar $
+*  $Id: gwaveformview.cpp 4350 2011-10-31 08:55:51Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -29,7 +29,7 @@
 #include <export/iherramientaanotacionesesquina.h>
 
 
-#include <recursos/aprimresourcemanager.h>
+#include <visualizator/resources/aprimresourcemanager.h>
 
 
 #define ANNOTATOR_TEXT_COLOR 0.1f, 0.1f, 0.1f, 1.0f
@@ -110,13 +110,15 @@ namespace GNKVisualizator
 
 			m_pButtonBar->Realize();
 			m_pSizerRight->Add(m_pButtonBar,0, wxALIGN_CENTER_VERTICAL|wxEXPAND,0);
-
-			
 			
 			View->GetEstudio()->Entorno->GetControladorEventos()->Registrar(this, ev2);
 			View->GetEstudio()->Entorno->GetControladorEventos()->Registrar(this, ev3);
 			View->GetEstudio()->Entorno->GetControladorEventos()->Registrar(this, ev4);
 
+			bool showMetadata = false;
+		// if metadata is shown at start, zoom will be broken
+		//	GNC::GCS::ConfigurationController::Instance()->readBoolUser("/GNKVisualizator/ECGView", "ShowMetadata", showMetadata, true);
+			ShowMetaData(showMetadata);
 			
 			Layout();
 			Thaw();
@@ -232,15 +234,19 @@ namespace GNKVisualizator
 
 		void GWaveformView::OnShowHideMetadata(wxCommandEvent &)
 		{
-			Freeze();
-			if (!m_pPanelMetadata->IsShown()) {
+			ShowMetaData(!m_pPanelMetadata->IsShown());
+			GNC::GCS::ConfigurationController::Instance()->writeBoolUser("/GNKVisualizator/ECGView", "ShowMetadata", m_pPanelMetadata->IsShown());
+		}
+
+		void GWaveformView::ShowMetaData(bool show)
+		{
+			if (show && ! m_pSplitterPanel->IsSplit()) {
 				//show
 				m_pSplitterPanel->SplitHorizontally(m_pPanelView, m_pPanelMetadata, -100);
-			} else {
+			} else if (!show && m_pSplitterPanel->IsSplit()) {
 				//hide
 				m_pSplitterPanel->Unsplit(m_pPanelMetadata);
 			}
-			Thaw();
 		}
 
 		void GWaveformView::OnShowHideCornerAnnotations(wxCommandEvent &event)
