@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: imprimevistasimple.cpp 3713 2011-04-15 12:55:23Z tovar $
+ *  $Id: imprimevistasimple.cpp 3893 2011-06-21 13:01:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,9 +16,7 @@
 #endif
 //#define _GINKGO_TRACE
 #include <api/globals.h>
-#include <api/internacionalizacion.h>
 
-#include <wx/config.h>
 
 #include <vtkSmartPointer.h>
 #include <vtkImageMapToRGBA.h>
