@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: imprimevistasimple.h 3713 2011-04-15 12:55:23Z tovar $
+ *  $Id: imprimevistasimple.h 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -12,7 +12,7 @@
  *
  */
 #pragma once
-#include <api/icontroladorimportacionpacs.h>
+#include <api/controllers/ipacscontroller.h>
 #include <export/icontratoscore.h>
 #include <api/iimpresion.h>
 
