@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: volume.cpp 3893 2011-06-21 13:01:56Z tovar $
+ *  $Id: volume.cpp 4361 2011-11-02 13:23:30Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -36,7 +36,7 @@
 #include "commands/volumecommand.h"
 #include <eventos/eventosginkgo.h>
 
-#include "../../../recursos/aprimresourcemanager.h"
+#include <visualizator/resources/aprimresourcemanager.h>
 #include <resources/ginkgoresourcemanager.h>
 #include "../../exportacion/tagsprivados.h"
 #include <export/tagsprivadoscomunes.h>
@@ -267,12 +267,12 @@ void MedicalViewer::Reconstruction::GUI::wxVolumeRendering::SaveFrameToSerie()
 		pPersistentData->baseImagenes.tags[std::string("0008|0090")] = tag;
 	}
 
-	pPersistentData->baseImagenes.tags[std::string("0008|0070")] = std::string("Metaemotion S.L.");
+	pPersistentData->baseImagenes.tags[std::string("0008|0070")] = EXT_PROVIDER;
 
-	pPersistentData->baseImagenes.tags[std::string("0008|1090")] = std::string("Ginkgo Atencin Primaria");
+	pPersistentData->baseImagenes.tags[std::string("0008|1090")] = EXT_NAME;
 
 	//uid de aprimaria
-	pPersistentData->baseImagenes.tags[std::string("0018|1030")] = UID_APRIM;
+	pPersistentData->baseImagenes.tags[std::string("0018|1030")] = EXT_IMPORTER_SID;
 
 	//study data
 	//date
